"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addFieldsToForm = void 0;
const tsfun_1 = require("tsfun");
const configuration_errors_1 = require("./configuration-errors");
/**
 *
 * @author Thomas Kleinke
 */
function addFieldsToForm(form, categories, builtInFields, commonFields, relations, parentForm, extendedForm) {
    var _a, _b;
    const fieldNames = getFieldNames(form, categories, extendedForm);
    const clonedForm = tsfun_1.clone(form);
    if (extendedForm)
        Object.assign(clonedForm.fields, extendedForm.fields);
    clonedForm.fields = fieldNames.reduce((fields, fieldName) => {
        const field = getField(fieldName, form, categories, builtInFields, commonFields, relations, parentForm, extendedForm);
        if (field)
            fields[fieldName] = field;
        return fields;
    }, (_a = clonedForm.fields) !== null && _a !== void 0 ? _a : {});
    if (parentForm) {
        if (!clonedForm.valuelists)
            clonedForm.valuelists = {};
        for (let fieldName of Object.keys((_b = parentForm.valuelists) !== null && _b !== void 0 ? _b : {})) {
            clonedForm.valuelists[fieldName] = parentForm.valuelists[fieldName];
        }
    }
    applyFormChanges(clonedForm, form, parentForm, extendedForm);
    return clonedForm;
}
exports.addFieldsToForm = addFieldsToForm;
function getFieldNames(form, categories, extendedForm) {
    var _a, _b;
    if (!form.groups)
        return [];
    const minimalForm = (_a = categories[form.categoryName]) === null || _a === void 0 ? void 0 : _a.minimalForm;
    const parentForm = ((_b = categories[form.categoryName]) === null || _b === void 0 ? void 0 : _b.parent)
        ? categories[categories[form.categoryName].parent].minimalForm
        : form.parent
            ? categories[form.parent].minimalForm
            : undefined;
    return tsfun_1.set(tsfun_1.flatten(form.groups.map(tsfun_1.to('fields')))
        .concat(minimalForm ? tsfun_1.flatten(minimalForm.groups.map(tsfun_1.to('fields'))) : [])
        .concat(parentForm ? tsfun_1.flatten(parentForm.groups.map(tsfun_1.to('fields'))) : [])
        .concat(extendedForm ? tsfun_1.flatten(extendedForm.groups.map(tsfun_1.to('fields'))) : []));
}
/**
 * @returns the field definition or undefined if the field is a relation
 */
function getField(fieldName, form, categories, builtInFields, commonFields, relations, parentForm, extendedForm) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    const parentName = (_a = form.parent) !== null && _a !== void 0 ? _a : (_b = categories[form.categoryName]) === null || _b === void 0 ? void 0 : _b.parent;
    const parentCategoryFields = parentName
        ? categories[parentName].fields
        : {};
    const field = (_j = (_h = (_g = (_e = (_d = (_c = builtInFields[fieldName]) !== null && _c !== void 0 ? _c : commonFields[fieldName]) !== null && _d !== void 0 ? _d : parentCategoryFields[fieldName]) !== null && _e !== void 0 ? _e : (_f = categories[form.categoryName]) === null || _f === void 0 ? void 0 : _f.fields[fieldName]) !== null && _g !== void 0 ? _g : ((parentForm === null || parentForm === void 0 ? void 0 : parentForm.fields) ? parentForm.fields[fieldName] : undefined)) !== null && _h !== void 0 ? _h : ((extendedForm === null || extendedForm === void 0 ? void 0 : extendedForm.fields) ? extendedForm.fields[fieldName] : undefined)) !== null && _j !== void 0 ? _j : (form.fields ? form.fields[fieldName] : undefined);
    if ((!field || !field.inputType) && !relations.find(relation => relation.name === fieldName)) {
        throw [[configuration_errors_1.ConfigurationErrors.FIELD_NOT_FOUND, form.categoryName, fieldName]];
    }
    if (field && !field.name)
        field.name = fieldName;
    return tsfun_1.clone(field);
}
function applyFormChanges(clonedForm, form, parentForm, extendedForm) {
    if (extendedForm === null || extendedForm === void 0 ? void 0 : extendedForm.fields) {
        Object.keys(extendedForm.fields).forEach(fieldName => {
            applyFieldChanges(clonedForm.fields[fieldName], extendedForm.fields[fieldName]);
        });
    }
    if (form.fields) {
        Object.keys(form.fields).forEach(fieldName => {
            applyFieldChanges(clonedForm.fields[fieldName], form.fields[fieldName]);
        });
    }
    if (parentForm === null || parentForm === void 0 ? void 0 : parentForm.fields) {
        Object.keys(parentForm.fields).forEach(fieldName => {
            applyFieldChanges(clonedForm.fields[fieldName], parentForm.fields[fieldName]);
        });
    }
}
function applyFieldChanges(field, changedField) {
    if (!field || !changedField)
        return;
    if (changedField.inputType) {
        field.inputType = changedField.inputType;
    }
    if (changedField.constraintIndexed !== undefined) {
        field.constraintIndexed = changedField.constraintIndexed;
    }
}
//# sourceMappingURL=add-fields-to-form.js.map