"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addRelations = void 0;
const tsfun_1 = require("tsfun");
const relation_1 = require("../../model/configuration/relation");
const named_1 = require("../../tools/named");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
function addRelations(relationsToAdd) {
    return (configuration) => {
        let [forms, relations] = configuration;
        if (!relations)
            return;
        for (let relationToAdd of relationsToAdd) {
            expandInherits(forms, relationToAdd, relation_1.Relation.DOMAIN);
            relations.filter(tsfun_1.on(named_1.Named.NAME)(relationToAdd))
                .forEach((relation) => {
                relation.domain = tsfun_1.subtract(relationToAdd.domain)(relation.domain);
            });
            relations = relations.filter(tsfun_1.not(tsfun_1.on(relation_1.Relation.DOMAIN, tsfun_1.isEmpty)));
            relations.splice(0, 0, relationToAdd);
            expandInherits(forms, relationToAdd, relation_1.Relation.RANGE);
            expandOnEmpty(forms, relationToAdd, relation_1.Relation.RANGE);
            expandOnEmpty(forms, relationToAdd, relation_1.Relation.DOMAIN);
        }
        return [forms, relations];
    };
}
exports.addRelations = addRelations;
function expandInherits(forms, relation, itemSet) {
    if (!relation)
        return;
    if (!relation[itemSet])
        return;
    const newItems = [];
    for (let item of relation[itemSet]) {
        if (item.indexOf(':inherit') !== -1) {
            for (let form of Object.values(forms)) {
                if (form.parent === item.split(':')[0] && !newItems.includes(form.categoryName)) {
                    newItems.push(form.categoryName);
                }
            }
            newItems.push(item.split(':')[0]);
        }
        else {
            newItems.push(item);
        }
    }
    relation[itemSet] = newItems;
}
function expandOnEmpty(forms, relation, itemSet) {
    if (tsfun_1.not(tsfun_1.isEmpty)(relation[itemSet]))
        return;
    let opposite = relation_1.Relation.RANGE;
    if (itemSet === relation_1.Relation.RANGE)
        opposite = relation_1.Relation.DOMAIN;
    relation[itemSet] = [];
    for (let form of Object.values(forms)) {
        if (relation[opposite].indexOf(form.categoryName) === -1) {
            relation[itemSet].push(form.categoryName);
        }
    }
}
//# sourceMappingURL=add-relations.js.map