"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyLanguagesToRelations = exports.applyLanguagesToFields = exports.applyLanguagesToForm = exports.applyLanguagesToCategory = void 0;
const i18n_1 = require("../../tools/i18n");
const language_configuration_1 = require("../model/language/language-configuration");
function applyLanguagesToCategory(languageConfigurations, categoryDefinition) {
    applyLanguagesToFormOrCategory(languageConfigurations, categoryDefinition, 'categories', categoryDefinition.name);
    applyLanguagesToCategoryFields(languageConfigurations, categoryDefinition.fields, categoryDefinition.name, categoryDefinition.parent);
}
exports.applyLanguagesToCategory = applyLanguagesToCategory;
function applyLanguagesToForm(languageConfigurations, formDefinition, parentCategoryName, parentFormName) {
    applyLanguagesToFormOrCategory(languageConfigurations, formDefinition, 'categories', formDefinition.categoryName);
    applyLanguagesToFormOrCategory(languageConfigurations, formDefinition, 'forms', formDefinition.name);
    applyLanguagesToFormOrCategory(languageConfigurations, formDefinition, 'categories', formDefinition.categoryName, true);
    applyLanguagesToCategoryFields(languageConfigurations, formDefinition.fields, formDefinition.categoryName, parentCategoryName);
    applyLanguagesToFormFields(languageConfigurations, formDefinition.fields, formDefinition.name, parentFormName);
    applyLanguagesToCategoryFields(languageConfigurations, formDefinition.fields, formDefinition.categoryName, parentCategoryName, true);
}
exports.applyLanguagesToForm = applyLanguagesToForm;
function applyLanguagesToFields(languageConfigurations, fields, section) {
    for (const fieldName of Object.keys(fields)) {
        const field = fields[fieldName];
        field.label = i18n_1.I18N.mergeI18nStrings(field.label, language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.complete, section, fieldName, false, 'label'));
        field.description = i18n_1.I18N.mergeI18nStrings(field.description, language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.complete, section, fieldName, false, 'description'));
        field.defaultLabel = i18n_1.I18N.mergeI18nStrings(field.defaultLabel, language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, section, fieldName, false, 'label'));
        field.defaultDescription = i18n_1.I18N.mergeI18nStrings(field.defaultDescription, language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, section, fieldName, false, 'description'));
    }
}
exports.applyLanguagesToFields = applyLanguagesToFields;
function applyLanguagesToRelations(languageConfigurations, relations) {
    for (const relation of relations) {
        relation.label = language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.complete, 'relations', relation.name, false, 'label');
        relation.defaultLabel = language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, 'relations', relation.name, false, 'label');
        relation.description = language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.complete, 'relations', relation.name, false, 'description');
        relation.defaultDescription = language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, 'relations', relation.name, false, 'description');
    }
}
exports.applyLanguagesToRelations = applyLanguagesToRelations;
function applyLanguagesToCategoryFields(languageConfigurations, fields, categoryName, parentCategoryName, onlyCustom) {
    applyLanguagesToFormOrCategoryFields(languageConfigurations, fields, categoryName, 'categories', parentCategoryName, onlyCustom);
}
function applyLanguagesToFormFields(languageConfigurations, fields, formName, parentFormName, onlyCustom) {
    applyLanguagesToFormOrCategoryFields(languageConfigurations, fields, formName, 'forms', parentFormName, onlyCustom);
}
function applyLanguagesToFormOrCategory(languageConfigurations, definition, section, name, onlyCustom = false) {
    definition.label = i18n_1.I18N.mergeI18nStrings(definition.label, language_configuration_1.LanguageConfiguration.getI18nString(onlyCustom ? languageConfigurations.custom : languageConfigurations.complete, section, name, false, 'label'));
    if (!onlyCustom) {
        definition.defaultLabel = i18n_1.I18N.mergeI18nStrings(definition.defaultLabel, language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, section, name, false, 'label'));
    }
    if (!definition.description) {
        definition.description = language_configuration_1.LanguageConfiguration.getI18nString(onlyCustom ? languageConfigurations.custom : languageConfigurations.complete, section, name, false, 'description');
        if (!onlyCustom) {
            definition.defaultDescription = language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, section, name, false, 'description');
        }
    }
}
function applyLanguagesToFormOrCategoryFields(languageConfigurations, fields, formOrCategoryName, section, parentName, onlyCustom) {
    for (const fieldName of Object.keys(fields)) {
        const field = fields[fieldName];
        applyLanguagesToFormOrCategoryField(languageConfigurations, field, fieldName, formOrCategoryName, section, parentName, onlyCustom);
        if (field.subfields) {
            for (const subfield of field.subfields) {
                applyLanguagesToFormOrCategoryField(languageConfigurations, subfield, fieldName, formOrCategoryName, section, parentName, onlyCustom, subfield.name);
            }
        }
    }
}
function applyLanguagesToFormOrCategoryField(languageConfigurations, field, fieldName, formOrCategoryName, section, parentName, onlyCustom, subfieldName) {
    applyLanguagesToField(languageConfigurations, field, fieldName, formOrCategoryName, section, onlyCustom, subfieldName);
    if (parentName) {
        applyLanguagesToField(languageConfigurations, field, fieldName, parentName, section, onlyCustom, subfieldName);
    }
}
function applyLanguagesToField(languageConfigurations, field, fieldName, formOrCategoryName, section, onlyCustom = false, subfieldName) {
    field.label = i18n_1.I18N.mergeI18nStrings(field.label, language_configuration_1.LanguageConfiguration.getI18nString(onlyCustom ? languageConfigurations.custom : languageConfigurations.complete, section, fieldName, true, 'label', formOrCategoryName, subfieldName));
    field.description = i18n_1.I18N.mergeI18nStrings(field.description, language_configuration_1.LanguageConfiguration.getI18nString(onlyCustom ? languageConfigurations.custom : languageConfigurations.complete, section, fieldName, true, 'description', formOrCategoryName, subfieldName));
    if (!onlyCustom) {
        field.defaultLabel = i18n_1.I18N.mergeI18nStrings(field.defaultLabel, language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, section, fieldName, true, 'label', formOrCategoryName, subfieldName));
        field.defaultDescription = i18n_1.I18N.mergeI18nStrings(field.defaultDescription, language_configuration_1.LanguageConfiguration.getI18nString(languageConfigurations.default, section, fieldName, true, 'description', formOrCategoryName, subfieldName));
    }
}
//# sourceMappingURL=apply-languages-configurations.js.map