"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildRawProjectConfiguration = void 0;
const tsfun_1 = require("tsfun");
const add_relations_1 = require("./add-relations");
const add_source_field_1 = require("./add-source-field");
const assertions_1 = require("./assertions");
const helpers_1 = require("./helpers");
const hide_fields_1 = require("./hide-fields");
const make_category_forest_1 = require("./make-category-forest");
const merge_with_custom_forms_1 = require("./merge-with-custom-forms");
const set_group_labels_1 = require("./set-group-labels");
const valuelist_1 = require("../../model/configuration/valuelist");
const merge_built_in_with_library_categories_1 = require("./merge-built-in-with-library-categories");
const get_available_forms_1 = require("./get-available-forms");
const forest_1 = require("../../tools/forest");
const sort_struct_array_1 = require("../../tools/sort-struct-array");
const utils_1 = require("../../tools/utils");
const category_forest_1 = require("../category-forest");
const field_1 = require("../../model/configuration/field");
const apply_languages_configurations_1 = require("./apply-languages-configurations");
const merge_valuelists_1 = require("./merge-valuelists");
const get_parent_form_1 = require("./get-parent-form");
const CATEGORIES = 0;
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
function buildRawProjectConfiguration(builtInCategories, libraryCategories, libraryForms, customForms, commonFieldDefinitions = {}, libraryValuelists = {}, customValuelists = {}, builtInFieldDefinitions = {}, relationDefinitions = [], languageConfigurations = { default: {}, custom: {}, complete: {} }, projectLanguages = [], categoriesOrder = [], validateFields = tsfun_1.identity, // TODO Check if this has to be a parameter
selectedParentForms, includeAllRelations = false) {
    const valuelists = merge_valuelists_1.mergeValuelists(libraryValuelists, customValuelists);
    assertions_1.Assertions.performAssertions(builtInCategories, libraryCategories, libraryForms, commonFieldDefinitions, valuelists, customForms);
    add_source_field_1.addSourceField(builtInCategories, libraryCategories, libraryForms, commonFieldDefinitions, customForms);
    const categories = buildCategories(builtInCategories, libraryCategories, languageConfigurations, valuelists);
    const builtInFields = buildFields(builtInFieldDefinitions, languageConfigurations, valuelists, 'fields');
    const commonFields = buildFields(commonFieldDefinitions, languageConfigurations, valuelists, 'commons');
    apply_languages_configurations_1.applyLanguagesToRelations(languageConfigurations, relationDefinitions);
    setDefaultConstraintIndexed(categories, builtInFields, commonFields);
    const selectedForms = selectedParentForms !== null && selectedParentForms !== void 0 ? selectedParentForms : Object.keys(customForms !== null && customForms !== void 0 ? customForms : {});
    const [forms, relations] = tsfun_1.flow(get_available_forms_1.getAvailableForms(categories, libraryForms, builtInFields, commonFields, relationDefinitions, selectedForms), tsfun_1.cond(tsfun_1.isDefined(customForms), assertions_1.Assertions.assertNoDuplicationInSelection(customForms)), tsfun_1.cond(tsfun_1.isDefined(customForms), merge_with_custom_forms_1.mergeWithCustomForms(customForms, categories, builtInFields, commonFields, relationDefinitions, selectedForms)), tsfun_1.cond(tsfun_1.isDefined(customForms), removeUnusedForms(Object.keys(customForms !== null && customForms !== void 0 ? customForms : {}))), insertValuelistIds, assertions_1.Assertions.assertValuelistIdsProvided, replaceValuelistIdsWithValuelists(valuelists), tsfun_1.cond(tsfun_1.isDefined(customForms), hide_fields_1.hideFields), applyLanguagesToForms(languageConfigurations, categories, selectedForms), prepareRawProjectConfiguration, add_relations_1.addRelations(relationDefinitions), tsfun_1.update(CATEGORIES, processForms(validateFields, languageConfigurations, categoriesOrder, relationDefinitions, categories, selectedParentForms, includeAllRelations)));
    return {
        forms,
        categories: finalizeCategories(categories),
        relations,
        commonFields,
        valuelists,
        projectLanguages
    };
}
exports.buildRawProjectConfiguration = buildRawProjectConfiguration;
const prepareRawProjectConfiguration = (forms) => [forms, [] /* relations */];
function buildCategories(builtInCategories, libraryCategories, languageConfigurations, valuelists) {
    const categories = merge_built_in_with_library_categories_1.mergeBuiltInWithLibraryCategories(builtInCategories, libraryCategories);
    for (const categoryDefinition of Object.values(categories)) {
        apply_languages_configurations_1.applyLanguagesToCategory(languageConfigurations, categoryDefinition);
        for (const fieldName of Object.keys(categoryDefinition.fields)) {
            categoryDefinition.fields[fieldName].name = fieldName;
            setDefaultFieldVisibility(categoryDefinition.fields[fieldName]);
            assertions_1.Assertions.assertValuelistIdsProvided(categories);
            replaceValuelistIdWithValuelist(categoryDefinition.fields[fieldName], valuelists);
        }
    }
    return categories;
}
function buildFields(fieldDefinitions, languageConfigurations, valuelists, section) {
    const fields = fieldDefinitions;
    for (const fieldName of Object.keys(fields)) {
        fields[fieldName].name = fieldName;
        setDefaultFieldVisibility(fields[fieldName]);
        replaceValuelistIdWithValuelist(fields[fieldName], valuelists);
    }
    apply_languages_configurations_1.applyLanguagesToFields(languageConfigurations, fields, section);
    return fields;
}
function processForms(validateFields, languageConfigurations, categoriesOrder, relations, categories, selectedParentForms, includeInvisibleRelations = false) {
    return tsfun_1.compose(validateFields, make_category_forest_1.makeCategoryForest(relations, categories, selectedParentForms, includeInvisibleRelations), forest_1.Forest.map(tsfun_1.curry(set_group_labels_1.setGroupLabels, languageConfigurations)), orderCategories(categoriesOrder), category_forest_1.linkParentAndChildInstances);
}
function setDefaultConstraintIndexed(categories, builtInFields, commonFields) {
    helpers_1.iterateOverFields(categories, (_, __, ___, field) => {
        field.defaultConstraintIndexed = field.constraintIndexed === true;
    });
    Object.values(builtInFields).concat(Object.values(commonFields)).forEach(field => {
        field.defaultConstraintIndexed = field.constraintIndexed === true;
    });
}
const orderCategories = (categoriesOrder = []) => (categories) => forest_1.Tree.mapTrees(sort_struct_array_1.sortStructArray(categoriesOrder, forest_1.Tree.ITEMNAMEPATH), categories);
function setDefaultFieldVisibility(field) {
    if (field.visible === undefined)
        field.visible = true;
    if (field.editable === undefined)
        field.editable = true;
    if (field.selectable === undefined)
        field.selectable = true;
}
function insertValuelistIds(forms) {
    helpers_1.iterateOverFields(forms, (_, form, fieldName, field) => {
        if (form.valuelists && form.valuelists[fieldName]) {
            if (tsfun_1.isString(form.valuelists[fieldName])) {
                field.valuelistId = form.valuelists[fieldName];
            }
            else {
                for (const subfieldName of Object.keys(form.valuelists[fieldName])) {
                    const subfield = field.subfields.find(subfield => {
                        return subfield.name === subfieldName;
                    });
                    subfield.valuelistId = form.valuelists[fieldName][subfieldName];
                }
            }
        }
    });
    return forms;
}
function replaceValuelistIdsWithValuelists(valuelists) {
    return (forms) => {
        for (const form of Object.values(forms)) {
            if (!form.fields)
                continue;
            for (const field of Object.values(form.fields)) {
                replaceValuelistIdWithValuelist(field, valuelists);
                if (field.subfields) {
                    for (const subfield of field.subfields) {
                        replaceValuelistIdWithValuelist(subfield, valuelists);
                    }
                }
            }
        }
        return forms;
    };
}
function replaceValuelistIdWithValuelist(field, valuelists) {
    var _a;
    if (!field_1.Field.InputType.VALUELIST_INPUT_TYPES.includes(field.inputType)) {
        delete field.valuelist;
        delete field.valuelistId;
        return;
    }
    if (!field.valuelistId)
        return;
    field.valuelist = valuelists[field.valuelistId];
    if ((_a = field.valuelist) === null || _a === void 0 ? void 0 : _a.extendedValuelist) {
        field.valuelist = valuelist_1.Valuelist.applyExtension(field.valuelist, valuelists[field.valuelist.extendedValuelist]);
    }
    delete field.valuelistId;
}
function applyLanguagesToForms(languageConfigurations, categories, selectedForms) {
    return (forms) => {
        var _a;
        for (const form of Object.values(forms)) {
            const parentForm = get_parent_form_1.getParentForm(form, Object.values(forms), selectedForms);
            apply_languages_configurations_1.applyLanguagesToForm(languageConfigurations, form, (_a = form.parent) !== null && _a !== void 0 ? _a : categories[form.categoryName].parent, parentForm === null || parentForm === void 0 ? void 0 : parentForm.name);
        }
        return forms;
    };
}
function removeUnusedForms(selectedFormsNames) {
    return (forms) => {
        const formsToRemove = tsfun_1.flow(forms, Object.keys, tsfun_1.filter(tsfun_1.isNot(tsfun_1.includedIn(selectedFormsNames))));
        return formsToRemove.reduce(utils_1.withDissoc, forms);
    };
}
function finalizeCategories(categories) {
    for (const category of Object.values(categories)) {
        delete category.minimalForm;
    }
    return categories;
}
//# sourceMappingURL=build-raw-project-configuration.js.map