import { Map } from 'tsfun';
import { ConfigurationDocument } from '../../model/configuration-document';
import { Relation } from '../../model/configuration/relation';
import { LanguageConfiguration } from '../model/language/language-configuration';
import { ProjectConfiguration } from '../../services/project-configuration';
import { ConfigReader } from './config-reader';
import { BuiltInCategoryDefinition } from '../model/category/built-in-category-definition';
import { BuiltInFieldDefinition } from '../model/field/built-in-field-definition';
import { Valuelist } from '../../model/configuration/valuelist';
import { Template } from '../../model/configuration/template';
/**
 * Lets clients subscribe for the app
 * configuration. In order for this to work, they
 * have to call <code>validateFieldDefinitions_</code> and <code>getProjectConfiguration</code>
 *  (the call order does not matter).
 *
 * It is recommended to handle a promise rejection of
 * <code>getProjectConfiguration</code> at a single place in your app.
 *
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 * @author Fabian Z.
 */
export declare class ConfigLoader {
    private configReader;
    constructor(configReader: ConfigReader);
    go(commonFields: Map<BuiltInFieldDefinition>, builtInCategories: Map<BuiltInCategoryDefinition>, relations: Array<Relation>, builtInFields: Map<BuiltInFieldDefinition>, configurationDocument: ConfigurationDocument, includeAllRelations?: boolean): Promise<ProjectConfiguration>;
    private readLibraryFile;
    private loadConfiguration;
    readDefaultLanguageConfigurations(): {
        [language: string]: Array<LanguageConfiguration>;
    };
    mergeLanguageConfigurations(defaultLanguageConfigurations: {
        [language: string]: Array<LanguageConfiguration>;
    }, customLanguageConfiguration: {
        [language: string]: LanguageConfiguration;
    }): {
        [language: string]: Array<LanguageConfiguration>;
    };
    readTemplates(): Map<Template>;
    readValuelists(): Map<Valuelist>;
    private setValuelistsLanguages;
    private setValuelistDescription;
    private setValueLabels;
    private readLanguageConfiguration;
}
