"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigurationValidation = void 0;
const model_1 = require("../../model");
const configuration_errors_1 = require("./configuration-errors");
/**
 * @author F.Z.
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
var ConfigurationValidation;
(function (ConfigurationValidation) {
    function findMissingRelationType(relations, categoryNames) {
        let msgs = [];
        function addMissingRelationCategories(rangeOrDomain) {
            if (!rangeOrDomain)
                return;
            for (let category of rangeOrDomain) {
                const categoryWithoutInheritanceSuffix = category.substring(0, category.indexOf(':') !== -1
                    ? category.indexOf(':')
                    : undefined);
                if (categoryNames.indexOf(categoryWithoutInheritanceSuffix) === -1 && category !== 'Project') {
                    msgs.push([configuration_errors_1.ConfigurationErrors.INVALID_CONFIG_MISSINGRELATIONCATEGORY, category]);
                }
            }
        }
        if (relations)
            for (let relation of relations) {
                addMissingRelationCategories(relation.domain);
                addMissingRelationCategories(relation.range);
            }
        return msgs;
    }
    ConfigurationValidation.findMissingRelationType = findMissingRelationType;
    function validateFieldDefinitions(forms) {
        let messages = [];
        const errors = findInvalidFieldDefinitions(forms);
        if (errors.length)
            messages = messages.concat(errors);
        return messages;
    }
    ConfigurationValidation.validateFieldDefinitions = validateFieldDefinitions;
    function findInvalidFieldDefinitions(forms) {
        const messages = [];
        for (let form of forms) {
            for (let fieldName of Object.keys(form.fields)) {
                const fieldDefinition = form.fields[fieldName];
                if (!fieldDefinition.hasOwnProperty('inputType'))
                    fieldDefinition.inputType = 'input';
                if (model_1.Field.InputType.VALUELIST_INPUT_TYPES.indexOf(fieldDefinition.inputType) !== -1
                    && !fieldDefinition.valuelistFromProjectField
                    && !isValidValuelist(fieldDefinition.valuelist)) {
                    messages.push([
                        configuration_errors_1.ConfigurationErrors.INVALID_CONFIG_MISSINGVALUELIST,
                        fieldName,
                        form.name
                    ]);
                }
            }
        }
        return messages;
    }
    function isValidValuelist(valuelist) {
        return valuelist
            && valuelist.values
            && Object.keys(valuelist.values).length > 0;
    }
})(ConfigurationValidation = exports.ConfigurationValidation || (exports.ConfigurationValidation = {}));
//# sourceMappingURL=configuration-validation.js.map