"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAvailableForms = void 0;
const tsfun_1 = require("tsfun");
const add_fields_to_form_1 = require("./add-fields-to-form");
const configuration_errors_1 = require("./configuration-errors");
const get_parent_form_1 = require("./get-parent-form");
const merge_groups_configurations_1 = require("./merge-groups-configurations");
/**
 *
 * @author Thomas Kleinke
 */
function getAvailableForms(categories, libraryForms, builtInFields, commonFields, relations, selectedForms) {
    const builtInForms = tsfun_1.map(getMinimalForm(categories), categories);
    const forms = Object.keys(libraryForms).reduce((forms, formName) => {
        if (!forms[formName]) {
            forms[formName] = makeTransientForm(libraryForms[formName], formName, categories[libraryForms[formName].categoryName]);
        }
        return forms;
    }, builtInForms);
    return tsfun_1.flow(forms, tsfun_1.map(form => setGroups(form, Object.values(forms), selectedForms)), tsfun_1.filter(tsfun_1.isDefined), tsfun_1.map(form => add_fields_to_form_1.addFieldsToForm(form, categories, builtInFields, commonFields, relations, get_parent_form_1.getParentForm(form, Object.values(forms), selectedForms))));
}
exports.getAvailableForms = getAvailableForms;
function getMinimalForm(categories) {
    return function (category, categoryName) {
        var _a;
        let minimalForm = tsfun_1.clone((_a = category.minimalForm) !== null && _a !== void 0 ? _a : (category.parent
            ? categories[category.parent].minimalForm
            : undefined));
        if (!minimalForm) {
            throw [[configuration_errors_1.ConfigurationErrors.NO_MINIMAL_FORM_PROVIDED, category.name]];
        }
        minimalForm.description = {};
        minimalForm.name = categoryName;
        minimalForm.categoryName = categoryName;
        minimalForm.label = category.label;
        minimalForm.defaultLabel = category.defaultLabel;
        minimalForm.description = category.description;
        minimalForm.defaultDescription = category.defaultDescription;
        minimalForm.parent = category.parent;
        minimalForm.color = category.color;
        return minimalForm;
    };
}
function makeTransientForm(libraryForm, formName, category) {
    const clonedForm = tsfun_1.clone(libraryForm);
    clonedForm.name = formName;
    clonedForm.label = category.label;
    clonedForm.defaultLabel = category.defaultLabel;
    clonedForm.description = category.description;
    clonedForm.defaultDescription = category.defaultDescription;
    clonedForm.parent = category.parent;
    clonedForm.color = category.color;
    return clonedForm;
}
/**
 * @returns undefined if no parent form could be found for a subcategory form
 */
function setGroups(form, forms, selectedForms) {
    const clonedForm = tsfun_1.clone(form);
    if (!clonedForm.parent)
        return clonedForm;
    const parentForm = get_parent_form_1.getParentForm(clonedForm, forms, selectedForms);
    if (!parentForm)
        return undefined;
    clonedForm.groups = merge_groups_configurations_1.mergeGroupsConfigurations(parentForm.groups, clonedForm.groups);
    return clonedForm;
}
//# sourceMappingURL=get-available-forms.js.map