"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeBuiltInWithLibraryCategories = void 0;
const tsfun_1 = require("tsfun");
/**
 * @author Thomas Kleinke
 */
function mergeBuiltInWithLibraryCategories(builtInCategories, libraryCategories) {
    const result = tsfun_1.map(makeTransientCategoryDefinition, tsfun_1.clone(builtInCategories));
    return Object.keys(libraryCategories).reduce((categories, categoryName) => {
        categories[categoryName] = categories[categoryName]
            ? mergeCategories(categories[categoryName], libraryCategories[categoryName])
            : libraryCategories[categoryName];
        categories[categoryName].name = categoryName;
        return categories;
    }, result);
}
exports.mergeBuiltInWithLibraryCategories = mergeBuiltInWithLibraryCategories;
function mergeCategories(builtInCategory, libraryCategory) {
    const result = tsfun_1.clone(builtInCategory);
    result.description = libraryCategory.description;
    result.color = libraryCategory.color;
    if (libraryCategory.minimalForm)
        result.minimalForm = libraryCategory.minimalForm;
    if (libraryCategory.fields) {
        result.fields = mergeFields(builtInCategory.fields, libraryCategory.fields);
    }
    return result;
}
function mergeFields(builtInFields, libraryFields) {
    return Object.keys(libraryFields).reduce((fields, fieldName) => {
        if (!fields[fieldName])
            fields[fieldName] = libraryFields[fieldName];
        return fields;
    }, tsfun_1.clone(builtInFields));
}
function makeTransientCategoryDefinition(category, categoryName) {
    const result = category;
    result.name = categoryName;
    result.description = {};
    return result;
}
//# sourceMappingURL=merge-built-in-with-library-categories.js.map