"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuiltInConfiguration = void 0;
const field_1 = require("../model/configuration/field");
const group_1 = require("../model/configuration/group");
const relation_1 = require("../model/configuration/relation");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
class BuiltInConfiguration {
    constructor(customConfigurationName) {
        this.commonFields = {
            period: {
                inputType: field_1.Field.InputType.DROPDOWNRANGE,
                constraintIndexed: true,
                valuelistId: 'periods-default-1'
            },
            dating: {
                inputType: field_1.Field.InputType.DATING
            },
            diary: {
                inputType: field_1.Field.InputType.INPUT,
                constraintIndexed: true
            },
            area: {
                inputType: field_1.Field.InputType.UNSIGNEDFLOAT,
                constraintIndexed: true
            },
            dimensionLength: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            dimensionWidth: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            dimensionHeight: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            dimensionDepth: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            dimensionDiameter: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            dimensionPerimeter: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            dimensionThickness: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            dimensionVerticalExtent: {
                inputType: field_1.Field.InputType.DIMENSION,
                inputTypeOptions: { validation: { permissive: true } },
                valuelistId: 'position-values-edge-default'
            },
            dimensionOther: {
                inputType: field_1.Field.InputType.DIMENSION,
                valuelistId: 'position-values-expansion-default'
            },
            beginningDate: {
                inputType: field_1.Field.InputType.DATE,
            },
            endDate: {
                inputType: field_1.Field.InputType.DATE,
            },
            processor: {
                inputType: field_1.Field.InputType.CHECKBOXES,
                valuelistFromProjectField: 'staff',
                constraintIndexed: true,
                fixedInputType: true
            },
            campaign: {
                inputType: field_1.Field.InputType.CHECKBOXES,
                valuelistFromProjectField: 'campaigns',
                allowOnlyValuesOfParent: true,
                constraintIndexed: true,
                fixedInputType: true
            },
            description: {
                inputType: field_1.Field.InputType.TEXT
            },
            date: {
                inputType: field_1.Field.InputType.DATE
            },
            spatialLocation: {
                inputType: field_1.Field.InputType.INPUT
            },
            provenance: {
                inputType: field_1.Field.InputType.DROPDOWN,
                constraintIndexed: true,
                valuelistId: 'provenance-default-1'
            },
            orientation: {
                inputType: field_1.Field.InputType.DROPDOWN,
                constraintIndexed: true,
                valuelistId: 'orientation-default-1'
            },
            literature: {
                inputType: field_1.Field.InputType.LITERATURE
            },
            geometry: {
                inputType: field_1.Field.InputType.GEOMETRY,
                visible: false
            },
            notes: {
                inputType: field_1.Field.InputType.TEXT
            },
            damage: {
                inputType: field_1.Field.InputType.FLOAT
            },
            webGisId: {
                inputType: field_1.Field.InputType.UNSIGNEDINT
            },
            shortDescriptionAddendum: {
                inputType: field_1.Field.InputType.INPUT
            },
            phase: {
                inputType: field_1.Field.InputType.INPUT
            },
            'archaeoDox:documentationUnit': {
                inputType: field_1.Field.InputType.SIMPLE_MULTIINPUT,
                selectable: false
            },
        };
        this.builtInCategories = {
            Project: {
                required: true,
                fields: {
                    identifier: {
                        inputType: field_1.Field.InputType.IDENTIFIER,
                        editable: false,
                        visible: false
                    },
                    shortName: {
                        inputType: field_1.Field.InputType.INPUT,
                        fixedInputType: true,
                        maxCharacters: 50
                    },
                    coordinateReferenceSystem: {
                        inputType: field_1.Field.InputType.DROPDOWN,
                        valuelistId: 'coordinate-reference-system-default-1',
                        fixedInputType: true
                    },
                    staff: {
                        inputType: field_1.Field.InputType.SIMPLE_MULTIINPUT,
                        fixedInputType: true
                    },
                    campaigns: {
                        inputType: field_1.Field.InputType.SIMPLE_MULTIINPUT,
                        fixedInputType: true
                    }
                },
                minimalForm: {
                    valuelists: {
                        coordinateReferenceSystem: 'coordinate-reference-system-default-1'
                    },
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['shortName', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.PROPERTIES,
                            fields: ['staff', 'campaigns', 'coordinateReferenceSystem']
                        }
                    ]
                }
            },
            Operation: {
                supercategory: true,
                abstract: true,
                fields: {
                    supervisor: {
                        inputType: field_1.Field.InputType.CHECKBOXES,
                        valuelistFromProjectField: 'staff',
                        constraintIndexed: true,
                        fixedInputType: true
                    }
                },
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Building: {
                parent: 'Operation',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Survey: {
                parent: 'Operation',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Trench: {
                parent: 'Operation',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            ExcavationArea: {
                parent: 'Operation',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Profile: {
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry', 'includesStratigraphicalUnits']
                        }
                    ]
                }
            },
            Planum: {
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry', 'includesStratigraphicalUnits']
                        }
                    ]
                }
            },
            Place: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {
                    gazId: {
                        inputType: field_1.Field.InputType.UNSIGNEDINT,
                        constraintIndexed: true
                    }
                },
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.PROPERTIES,
                            fields: ['gazId']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Inscription: {
                mustLieWithin: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        }
                    ]
                }
            },
            Level: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            // Room is an idealized (non material) entity
            Room: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            RoomWall: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            RoomFloor: {
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            RoomCeiling: {
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            BuildingPart: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Opening: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Roof: {
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Stairs: {
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Area: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Damage: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            DesignElement: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Feature: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription', relation_1.Relation.SAME_AS]
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.STRATIGRAPHY,
                            fields: ['isAbove', 'isBelow', 'cuts', 'isCutBy', 'fills', 'isFilledBy', 'abuts',
                                'isAbuttedBy', 'bondsWith', 'borders']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry', 'isPresentIn']
                        },
                        {
                            name: group_1.Groups.TIME,
                            fields: ['period', 'dating'].concat(relation_1.Relation.Time.ALL)
                        }
                    ]
                }
            },
            FeatureGroup: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription', relation_1.Relation.SAME_AS]
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry', 'isPresentIn']
                        }
                    ]
                }
            },
            FeatureSegment: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                mustLieWithin: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription', relation_1.Relation.SAME_AS]
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry', 'isPresentIn']
                        }
                    ]
                }
            },
            Find: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                scanCodesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription', relation_1.Relation.SAME_AS, 'isStoredIn']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.IDENTIFICATION,
                            fields: ['isInstanceOf']
                        },
                        {
                            name: group_1.Groups.INVENTORY,
                            fields: ['isStoredIn']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            FindCollection: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                scanCodesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription', 'isStoredIn']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.IDENTIFICATION,
                            fields: ['isInstanceOf']
                        },
                        {
                            name: group_1.Groups.INVENTORY,
                            fields: ['isStoredIn']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            Sample: {
                mustLieWithin: true,
                scanCodesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription', 'isStoredIn']
                        },
                        {
                            name: group_1.Groups.HIERARCHY,
                            fields: ['hasChildren']
                        },
                        {
                            name: group_1.Groups.INVENTORY,
                            fields: ['isStoredIn']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            },
            TypeCatalog: {
                supercategory: true,
                fields: {
                    criterion: {
                        inputType: field_1.Field.InputType.DROPDOWN,
                        constraintIndexed: true,
                        valuelistId: 'TypeCatalog-criterion-default'
                    }
                },
                minimalForm: {
                    valuelists: {
                        criterion: 'TypeCatalog-criterion-default'
                    },
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.IDENTIFICATION,
                            fields: ['criterion']
                        }
                    ]
                }
            },
            Type: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                mustLieWithin: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.IDENTIFICATION,
                            fields: ['hasInstance']
                        }
                    ]
                }
            },
            StoragePlace: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                scanCodesAllowed: true,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.INVENTORY,
                            fields: ['isStoragePlaceOf']
                        }
                    ]
                }
            },
            Image: {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                required: true,
                fields: {
                    height: {
                        inputType: field_1.Field.InputType.UNSIGNEDINT,
                        editable: false
                    },
                    width: {
                        inputType: field_1.Field.InputType.UNSIGNEDINT,
                        editable: false
                    },
                    draughtsmen: {
                        inputType: field_1.Field.InputType.CHECKBOXES,
                        valuelistFromProjectField: 'staff',
                        constraintIndexed: true
                    },
                    imageRights: {
                        inputType: field_1.Field.InputType.INPUT
                    }
                },
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'category', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.PROPERTIES,
                            fields: ['height', 'width']
                        }
                    ]
                }
            }
        };
        this.builtInFields = {
            category: {
                inputType: field_1.Field.InputType.CATEGORY,
                visible: true,
                editable: false,
                fixedInputType: true
            },
            shortDescription: {
                inputType: field_1.Field.InputType.INPUT,
                visible: true,
                editable: true,
                fulltextIndexed: true
            },
            identifier: {
                inputType: field_1.Field.InputType.IDENTIFIER,
                visible: false,
                editable: true,
                mandatory: true,
                fulltextIndexed: true,
                fixedInputType: true
            },
            hasChildren: {
                inputType: field_1.Field.InputType.DERIVED_RELATION,
                visible: true,
                editable: false,
                constraintName: 'isChildOf:contain'
            },
            includesStratigraphicalUnits: {
                inputType: field_1.Field.InputType.DERIVED_RELATION,
                visible: true,
                editable: false,
                constraintName: 'isPresentIn:contain'
            }
        };
        this.builtInRelations = [
            {
                name: 'depicts',
                domain: ['Image:inherit'],
                range: [],
                inverse: 'isDepictedIn',
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isDepictedIn',
                domain: [],
                range: ['Image:inherit'],
                inverse: 'depicts',
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'hasMapLayer',
                inverse: 'isMapLayerOf',
                domain: ['Operation:inherit', 'Project'],
                range: ['Image:inherit'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isMapLayerOf',
                inverse: 'hasMapLayer',
                domain: ['Image:inherit'],
                range: ['Operation:inherit', 'Project'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'hasDefaultMapLayer',
                domain: ['Operation:inherit', 'Project'],
                range: ['Image:inherit'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isAfter',
                inverse: 'isBefore',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isBefore',
                inverse: 'isAfter',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: relation_1.Relation.SAME_AS,
                inverse: relation_1.Relation.SAME_AS,
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: relation_1.Relation.SAME_AS,
                inverse: relation_1.Relation.SAME_AS,
                domain: ['FeatureGroup:inherit'],
                range: ['FeatureGroup:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: relation_1.Relation.SAME_AS,
                inverse: relation_1.Relation.SAME_AS,
                domain: ['FeatureSegment:inherit'],
                range: ['FeatureSegment:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: relation_1.Relation.SAME_AS,
                inverse: relation_1.Relation.SAME_AS,
                domain: ['Find:inherit'],
                range: ['Find:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isContemporaryWith',
                inverse: 'isContemporaryWith',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isAbove',
                inverse: 'isBelow',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isBelow',
                inverse: 'isAbove',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'cuts',
                inverse: 'isCutBy',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isCutBy',
                inverse: 'cuts',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'fills',
                inverse: 'isFilledBy',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isFilledBy',
                inverse: 'fills',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'borders',
                inverse: 'borders',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'borders',
                inverse: 'borders',
                domain: ['BuildingPart:inherit'],
                range: ['BuildingPart:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'abuts',
                inverse: 'isAbuttedBy',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isAbuttedBy',
                inverse: 'abuts',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'bondsWith',
                inverse: 'bondsWith',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: relation_1.Relation.IS_PRESENT_IN,
                domain: ['Feature:inherit', 'FeatureGroup:inherit', 'FeatureSegment:inherit'],
                range: ['Profile', 'Planum'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isRecordedIn',
                domain: ['Profile', 'Planum'],
                range: ['Trench', 'ExcavationArea'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isRecordedIn',
                domain: ['Level:inherit', 'Room:inherit', 'RoomFloor', 'RoomWall:inherit', 'RoomCeiling',
                    'Roof', 'Stairs', 'Opening:inherit', 'Damage:inherit', 'DesignElement:inherit'],
                range: ['Building'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isRecordedIn',
                domain: ['Area:inherit'],
                range: ['Survey'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isRecordedIn',
                domain: ['BuildingPart:inherit'],
                range: ['Building', 'Survey'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isRecordedIn',
                domain: ['Find:inherit', 'FindCollection:inherit', 'Inscription', 'Sample'],
                range: ['Trench', 'Building', 'Survey', 'ExcavationArea'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isRecordedIn',
                domain: ['Feature:inherit', 'FeatureGroup:inherit', 'FeatureSegment:inherit'],
                range: ['Trench', 'ExcavationArea'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Operation:inherit', 'Place:inherit'],
                range: ['Place:inherit'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['FindCollection:inherit', 'Find:inherit'],
                range: ['FindCollection:inherit', 'Feature:inherit', 'Area:inherit', 'Sample', 'Room:inherit',
                    'BuildingPart:inherit', 'Level:inherit', 'RoomFloor', 'RoomWall:inherit', 'RoomCeiling', 'Roof',
                    'Stairs', 'DesignElement:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Inscription'],
                range: ['Find:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Feature:inherit'],
                range: ['Feature:inherit', 'FeatureGroup:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['FeatureSegment:inherit'],
                range: ['Feature:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Sample'],
                range: ['Sample', 'Feature:inherit', 'Find:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Level:inherit'],
                range: ['BuildingPart:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['BuildingPart:inherit'],
                range: ['BuildingPart:inherit', 'Area:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Room:inherit'],
                range: ['BuildingPart:inherit', 'Level:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Area:inherit'],
                range: ['Area:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['RoomFloor', 'RoomWall:inherit', 'RoomCeiling', 'Roof', 'Stairs'],
                range: ['BuildingPart:inherit', 'Room:inherit', 'Level:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Opening:inherit'],
                range: ['Room:inherit', 'RoomFloor', 'RoomWall:inherit', 'RoomCeiling', 'Roof', 'Stairs'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Damage:inherit'],
                range: ['BuildingPart:inherit', 'Room:inherit', 'Level:inherit', 'RoomFloor', 'RoomWall:inherit',
                    'RoomCeiling', 'Roof', 'Stairs', 'Opening:inherit', 'DesignElement:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['DesignElement:inherit'],
                range: ['BuildingPart:inherit', 'Room:inherit', 'Level:inherit', 'RoomFloor', 'RoomWall:inherit',
                    'RoomCeiling', 'Roof', 'Stairs', 'Opening:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['Type:inherit'],
                range: ['Type:inherit', 'TypeCatalog:inherit'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'liesWithin',
                domain: ['StoragePlace:inherit'],
                range: ['StoragePlace:inherit'],
                editable: false,
                visible: false,
                inputType: 'relation'
            },
            {
                name: 'isInstanceOf',
                inverse: 'hasInstance',
                domain: ['Find:inherit'],
                range: ['Type:inherit'],
                editable: true,
                visible: true,
                inputType: 'instanceOf'
            },
            {
                name: 'hasInstance',
                inverse: 'isInstanceOf',
                domain: ['Type:inherit'],
                range: ['Find:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isStoredIn',
                inverse: 'isStoragePlaceOf',
                domain: ['Find:inherit', 'FindCollection:inherit', 'Sample'],
                range: ['StoragePlace:inherit'],
                editable: true,
                visible: true,
                inputType: 'relation'
            },
            {
                name: 'isStoragePlaceOf',
                inverse: 'isStoredIn',
                domain: ['StoragePlace:inherit'],
                range: ['Find:inherit', 'FindCollection:inherit', 'Sample'],
                editable: true,
                visible: true,
                inputType: 'relation'
            }
        ];
        this.addProjectSpecificBuiltinConfiguration(customConfigurationName);
    }
    addProjectSpecificBuiltinConfiguration(customConfigurationName) {
        if (customConfigurationName === 'Meninx' || customConfigurationName === 'Bourgou') {
            this.builtInCategories.Wall_surface = {
                color: '#ffff99',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInCategories.Drilling = {
                color: '#08519c',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInRelations.push({
                name: 'isRecordedIn',
                domain: ['Wall_surface'],
                range: ['Trench'],
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'isRecordedIn',
                domain: ['Drilling'],
                range: ['Survey'],
                editable: false,
                inputType: 'relation'
            });
        }
        if (customConfigurationName === 'Pergamon') {
            this.builtInCategories.BuildingFloor = {
                color: '#6600cc',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInCategories.SurveyBurial = {
                color: '#45ff95',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInRelations.push({
                name: 'isRecordedIn',
                domain: ['BuildingFloor'],
                range: ['Building'],
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'isRecordedIn',
                domain: ['SurveyBurial'],
                range: ['Survey'],
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'liesWithin',
                domain: ['SurveyBurial'],
                range: ['Area:inherit'],
                sameMainCategoryResource: true,
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'borders',
                inverse: 'borders',
                domain: ['BuildingFloor'],
                range: ['BuildingPart:inherit'],
                sameMainCategoryResource: true,
                editable: true,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'borders',
                inverse: 'borders',
                domain: ['BuildingPart:inherit'],
                range: ['BuildingPart:inherit', 'BuildingFloor'],
                sameMainCategoryResource: true,
                editable: true,
                inputType: 'relation'
            });
        }
        if (customConfigurationName === 'Milet') {
            this.builtInCategories.Quantification = {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                abstract: false,
                color: '#c6dbef',
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInCategories.Building = {
                parent: 'Operation',
                fields: {
                    gazId: {
                        inputType: field_1.Field.InputType.UNSIGNEDINT,
                        constraintIndexed: true
                    }
                },
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.PROPERTIES,
                            fields: ['gazId']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInCategories.Find = {
                supercategory: true,
                userDefinedSubcategoriesAllowed: true,
                fields: {
                    diameterPercentage: {
                        inputType: field_1.Field.InputType.UNSIGNEDFLOAT,
                    }
                },
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.IDENTIFICATION,
                            fields: ['isInstanceOf']
                        },
                        {
                            name: group_1.Groups.DIMENSION,
                            fields: ['diameterPercentage']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInCategories.Impression = {
                supercategory: false,
                userDefinedSubcategoriesAllowed: false,
                fields: {},
                minimalForm: {
                    groups: [
                        {
                            name: group_1.Groups.STEM,
                            fields: ['identifier', 'shortDescription']
                        },
                        {
                            name: group_1.Groups.POSITION,
                            fields: ['geometry']
                        }
                    ]
                }
            };
            this.builtInRelations.push({
                name: 'isRecordedIn',
                domain: ['Quantification:inherit', 'Impression'],
                range: ['Trench:inherit'],
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'liesWithin',
                domain: ['Find:inherit'],
                range: ['Feature:inherit', 'Area:inherit', 'Quantification:inherit'],
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'liesWithin',
                domain: ['Impression'],
                range: ['Feature:inherit'],
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'liesWithin',
                domain: ['Quantification:inherit'],
                range: ['Feature:inherit', 'Quantification:inherit'],
                editable: false,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'wasFoundIn',
                inverse: 'hasFinds',
                domain: ['Find:inherit'],
                range: ['Building', 'Place:inherit', 'Survey', 'Trench'],
                editable: true,
                inputType: 'relation'
            });
            this.builtInRelations.push({
                name: 'hasFinds',
                inverse: 'wasFoundIn',
                domain: ['Building', 'Place:inherit', 'Survey', 'Trench'],
                range: ['Find:inherit'],
                editable: true,
                inputType: 'relation'
            });
            this.commonFields['datingAddenda'] = {
                inputType: 'text'
            };
        }
    }
}
exports.BuiltInConfiguration = BuiltInConfiguration;
//# sourceMappingURL=built-in-configuration.js.map