"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assertFieldsAreValid = void 0;
const tsfun_1 = require("tsfun");
const base_field_definition_1 = require("./base-field-definition");
const configuration_errors_1 = require("../../boot/configuration-errors");
const VALID_INPUT_TYPES = [
    'input', 'simpleInput', 'multiInput', 'simpleMultiInput', 'text', 'dropdown', 'dropdownRange', 'radio',
    'checkboxes', 'int', 'unsignedInt', 'float', 'unsignedFloat', 'dating', 'dimension', 'literature', 'boolean',
    'date', 'url', 'composite'
];
function assertFieldsAreValid(fields, validFieldKeys, source) {
    assertInputTypesAreValid(fields);
    assertFieldKeysAreValid(fields, validFieldKeys, source);
}
exports.assertFieldsAreValid = assertFieldsAreValid;
function assertInputTypesAreValid(fields) {
    const isIllegal = tsfun_1.and(tsfun_1.isDefined, tsfun_1.isNot(tsfun_1.includedIn(VALID_INPUT_TYPES)));
    tsfun_1.flow(tsfun_1.keysValues(fields), tsfun_1.filter(tsfun_1.on([1, base_field_definition_1.BaseFieldDefinition.INPUTTYPE], isIllegal)), tsfun_1.forEach(([fieldName, field]) => {
        throw [configuration_errors_1.ConfigurationErrors.ILLEGAL_FIELD_INPUT_TYPE, field.inputType, fieldName];
    }));
}
function assertFieldKeysAreValid(fields, validFieldKeys, source) {
    function throwIllegalFieldProperty(keys) {
        throw [configuration_errors_1.ConfigurationErrors.ILLEGAL_FIELD_PROPERTY, source, keys[0]];
    }
    const throwIllegalFieldPropertyIfNotEmpty = tsfun_1.cond(tsfun_1.not(tsfun_1.isEmpty), throwIllegalFieldProperty);
    tsfun_1.flow(fields, tsfun_1.map(Object.keys), tsfun_1.map(tsfun_1.remove(tsfun_1.includedIn(validFieldKeys))), tsfun_1.values, tsfun_1.forEach(throwIllegalFieldPropertyIfNotEmpty));
}
//# sourceMappingURL=assert-fields-are-valid.js.map