"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomFormDefinition = void 0;
const tsfun_1 = require("tsfun");
const assert_fields_are_valid_1 = require("../field/assert-fields-are-valid");
const configuration_errors_1 = require("../../boot/configuration-errors");
const custom_field_definition_1 = require("../field/custom-field-definition");
const VALID_CUSTOM_FORM_PROPERTIES = [
    'valuelists', 'color', 'hidden', 'parent', 'fields', 'groups', 'references', 'identifierPrefix', 'resourceLimit',
    'scanCodes'
];
var CustomFormDefinition;
(function (CustomFormDefinition) {
    CustomFormDefinition.VALUELISTS = 'valuelists';
    CustomFormDefinition.PARENT = 'parent';
    function makeAssertIsValid(formNames) {
        return function assertIsValid([formName, form]) {
            Object.keys(form)
                .filter(tsfun_1.isNot(tsfun_1.includedIn(VALID_CUSTOM_FORM_PROPERTIES)))
                .map(fieldName => [configuration_errors_1.ConfigurationErrors.ILLEGAL_CUSTOM_FORM_PROPERTY, fieldName, formName])
                .forEach(tsfun_1.throws());
            if (!formNames.includes(formName)) {
                if (!form.parent) {
                    throw [
                        configuration_errors_1.ConfigurationErrors.MISSING_FORM_PROPERTY,
                        CustomFormDefinition.PARENT,
                        formName,
                        'must be set for new categories'
                    ];
                }
            }
            else {
                if (form.parent) {
                    throw [
                        configuration_errors_1.ConfigurationErrors.ILLEGAL_CUSTOM_FORM_PROPERTY,
                        CustomFormDefinition.PARENT,
                        formName,
                        'must not be set if not a new category'
                    ];
                }
            }
            assert_fields_are_valid_1.assertFieldsAreValid(form.fields, custom_field_definition_1.VALID_CUSTOM_FIELD_PROPERTIES, 'custom');
        };
    }
    CustomFormDefinition.makeAssertIsValid = makeAssertIsValid;
})(CustomFormDefinition = exports.CustomFormDefinition || (exports.CustomFormDefinition = {}));
//# sourceMappingURL=custom-form-definition.js.map