"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChangesStream = void 0;
const document_1 = require("../../model/document");
const observer_util_1 = require("../../tools/observer-util");
const helpers_1 = require("../helpers");
const warnings_updater_1 = require("../warnings-updater");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
class ChangesStream {
    constructor(pouchDbDatastore, datastore, indexFacade, documentCache, documentConverter, projectConfiguration, getUsername) {
        this.datastore = datastore;
        this.indexFacade = indexFacade;
        this.documentCache = documentCache;
        this.documentConverter = documentConverter;
        this.projectConfiguration = projectConfiguration;
        this.getUsername = getUsername;
        this.remoteChangesObservers = [];
        this.remoteConfigurationChangesObservers = [];
        this.projectDocumentObservers = [];
        this.remoteChangesNotifications = () => observer_util_1.ObserverUtil.register(this.remoteChangesObservers);
        this.remoteConfigurationChangesNotifications = () => observer_util_1.ObserverUtil.register(this.remoteConfigurationChangesObservers);
        this.projectDocumentNotifications = () => observer_util_1.ObserverUtil.register(this.projectDocumentObservers);
        pouchDbDatastore.deletedNotifications().subscribe(document => {
            this.documentCache.remove(document.resource.id);
            this.indexFacade.remove(document);
        });
        pouchDbDatastore.changesNotifications().subscribe((document) => __awaiter(this, void 0, void 0, function* () {
            if (helpers_1.isProjectDocument(document)) {
                observer_util_1.ObserverUtil.notify(this.projectDocumentObservers, document);
            }
            const isRemoteChange = yield ChangesStream.isRemoteChange(document, this.getUsername());
            if (isRemoteChange || !this.documentCache.get(document.resource.id)
                || document._conflicts !== undefined) {
                yield this.welcomeDocument(document);
            }
            if (isRemoteChange && document.resource.category === 'Configuration') {
                observer_util_1.ObserverUtil.notify(this.remoteConfigurationChangesObservers, null);
            }
        }));
    }
    welcomeDocument(document) {
        return __awaiter(this, void 0, void 0, function* () {
            this.documentConverter.convert(document);
            warnings_updater_1.WarningsUpdater.updateIndexIndependentWarnings(document, this.projectConfiguration);
            this.indexFacade.put(document);
            const previousVersion = this.documentCache.get(document.resource.id);
            const previousIdentifier = previousVersion === null || previousVersion === void 0 ? void 0 : previousVersion.resource.identifier;
            if (previousVersion) {
                document = this.documentCache.reassign(document);
            }
            else {
                this.documentCache.set(document);
            }
            yield warnings_updater_1.WarningsUpdater.updateIndexDependentWarnings(document, this.indexFacade, this.documentCache, this.projectConfiguration, this.datastore, previousIdentifier, true);
            observer_util_1.ObserverUtil.notify(this.remoteChangesObservers, { document, new: previousVersion === undefined });
        });
    }
    static isRemoteChange(document, username) {
        const latestAction = document_1.Document.getLastModified(document);
        return latestAction && latestAction.user !== username;
    }
}
exports.ChangesStream = ChangesStream;
//# sourceMappingURL=changes-stream.js.map