"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dissocIndices = exports.last2 = exports.replaceLastPair = exports.sortRevisionsByLastModified = exports.isProjectDocument = void 0;
const tsfun_1 = require("tsfun");
const document_1 = require("../model/document");
/**
 * @author Daniel de Oliveira
 */
function isProjectDocument(document) {
    return document.resource.id === 'project';
}
exports.isProjectDocument = isProjectDocument;
function sortRevisionsByLastModified(documents) {
    return documents.sort((l, r) => {
        const lDate = document_1.Document.getLastModified(l).date;
        const rDate = document_1.Document.getLastModified(r).date;
        if (lDate < rDate)
            return -1;
        if (lDate > rDate)
            return 1;
        return 0;
    });
}
exports.sortRevisionsByLastModified = sortRevisionsByLastModified;
function replaceLastPair(as, replacement) {
    return replaceRight(as, 2, replacement);
}
exports.replaceLastPair = replaceLastPair;
function replaceRight(as, itemsToReplace, replacement) {
    return tsfun_1.flow(as, tsfun_1.dropRight(itemsToReplace), tsfun_1.append(replacement));
}
const lengthIsnt2 = tsfun_1.compose(tsfun_1.size, tsfun_1.isnt(2));
exports.last2 = tsfun_1.compose(tsfun_1.takeRight(2), tsfun_1.cond(lengthIsnt2, tsfun_1.throws('Illegal argument, length must be at least 2')));
/**
 * Dissociates the given indices from an array.
 *
 * Example
 *   > dissocIndices([0, 2])(['a', 'b', 'c', 'd')
 *   ['b', 'd']
 *
 * @param indices must be sorted in ascending order
 */
function dissocIndices(indices) {
    return (as) => {
        const index = tsfun_1.last(indices);
        if (index === undefined)
            return as;
        return dissocIndices(tsfun_1.dropRight(1, indices))(tsfun_1.take(index, as)
            .concat(tsfun_1.drop(index + 1, as)));
    };
}
exports.dissocIndices = dissocIndices;
//# sourceMappingURL=helpers.js.map