import { PouchdbDatastore } from '../pouchdb';
import { SyncStatus } from '../sync-status';
import { ImageVariant, ImageStore, FileInfo } from './image-store';
import { RemoteImageStoreInterface } from './remote-image-store-interface';
interface SyncDifference {
    missingLocally: {
        [uuid: string]: FileInfo;
    };
    missingRemotely: {
        [uuid: string]: FileInfo;
    };
    deleteLocally: string[];
    deleteRemotely: string[];
}
export interface FileSyncPreference {
    variant: ImageVariant;
    upload: boolean;
    download: boolean;
}
export declare class ImageSyncService {
    private imageStore;
    private remoteImageStore;
    private readonly longIntervalDuration;
    private readonly shortIntervalDuration;
    private active;
    private schedules;
    private status;
    private inProcess;
    constructor(imageStore: ImageStore, remoteImageStore: RemoteImageStoreInterface, datastore: PouchdbDatastore);
    getStatus(): {
        [variant in ImageVariant]?: SyncStatus;
    };
    /**
     * Start syncing images of the given {@link ImageVariant}.
     */
    startSync(preference: FileSyncPreference): void;
    /**
     * Stop syncing images of the given {@link ImageVariant}.
     */
    stopSync(variant: ImageVariant): void;
    /**
     * Stop syncing for all {@link ImageVariant}.
     */
    stopAllSyncing(): void;
    private triggerUpdate;
    private scheduleNextSync;
    private sync;
    static evaluateDifference(localData: {
        [uuid: string]: FileInfo;
    }, remoteData: {
        [uuid: string]: FileInfo;
    }, variant: ImageVariant): Promise<SyncDifference>;
    private isVariantSyncActive;
}
export {};
