"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Migrator = exports.singleToMultipleValuesFieldNames = void 0;
const tsfun_1 = require("tsfun");
const optional_range_1 = require("../model/optional-range");
const category_form_1 = require("../model/configuration/category-form");
const field_1 = require("../model/configuration/field");
exports.singleToMultipleValuesFieldNames = [
    'processor',
    'supervisor',
    'draughtsmen',
    'campaign',
    'archaeoDox:distinguishingCriterium'
];
/**
 * @author Thomas Kleinke
 */
var Migrator;
(function (Migrator) {
    /**
     * @param document is modified in place
     * */
    function migrate(document, projectConfiguration) {
        migrateGeneralFieldsAndRelations(document);
        migratePeriodFields(document);
        migrateSingleToMultipleValues(document);
        migrateDatings(document, projectConfiguration);
    }
    Migrator.migrate = migrate;
    function migratePeriodFields(document) {
        const PERIOD = 'period';
        const PERIODEND = 'periodEnd';
        if (document.resource[PERIOD] && !tsfun_1.isObject(document.resource[PERIOD])) {
            document.resource[PERIOD] = {
                value: document.resource[PERIOD]
            };
            if (document.resource[PERIODEND]) {
                document.resource[PERIOD][optional_range_1.OptionalRange.ENDVALUE] = document.resource[PERIODEND];
                delete document.resource[PERIODEND];
            }
        }
    }
    function migrateGeneralFieldsAndRelations(document) {
        if (document.resource.relations)
            delete document.resource.relations['includes'];
        if (document.resource.type) {
            document.resource.category = document.resource['type'];
            delete document.resource['type'];
        }
    }
    function migrateSingleToMultipleValues(document) {
        exports.singleToMultipleValuesFieldNames.forEach((fieldName) => {
            if (document.resource[fieldName] && !Array.isArray(document.resource[fieldName])) {
                document.resource[fieldName] = [document.resource[fieldName]];
            }
        });
    }
    function migrateDatings(document, projectConfiguration) {
        const category = projectConfiguration.getCategory(document);
        if (!category)
            return;
        category_form_1.CategoryForm.getFields(category)
            .filter(field => field.inputType === field_1.Field.InputType.DATING)
            .forEach(field => {
            const datings = document.resource[field.name];
            if (!datings || !tsfun_1.isArray(datings))
                return;
            datings.forEach(dating => {
                if (dating.type === 'exact')
                    dating.type = 'single';
            });
        });
    }
})(Migrator = exports.Migrator || (exports.Migrator = {}));
//# sourceMappingURL=migrator.js.map