"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChangeHistoryMerge = void 0;
/**
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
var ChangeHistoryMerge;
(function (ChangeHistoryMerge) {
    /**
     * Merges the change histories of two documents.
     *
     * Only the mainDocument is changed. Its change history merges with the change history (created & modified actions)
     * of the secondDocument.
     */
    function mergeChangeHistories(mainDocument, secondDocument) {
        const changeHistory = getCombinedChangeHistory([mainDocument, secondDocument]);
        sortChangeHistory(changeHistory);
        if (changeHistory.length === 0)
            return;
        mainDocument.created = changeHistory.shift();
        mainDocument.modified = changeHistory;
    }
    ChangeHistoryMerge.mergeChangeHistories = mergeChangeHistories;
    function getCombinedChangeHistory(documents) {
        return documents.reduce((changeHistory, document) => (addActionsToChangeHistory(changeHistory, document), changeHistory), []);
    }
    function addActionsToChangeHistory(changeHistory, document) {
        if (document.created && !isInChangeHistory(document.created, changeHistory)) {
            changeHistory.push(document.created);
        }
        if (document.modified) {
            document.modified
                .filter(action => !isInChangeHistory(action, changeHistory))
                .forEach(action => changeHistory.push(action));
        }
    }
    function isInChangeHistory(action, changeHistory) {
        return changeHistory.find(_ => isSameAction(action, _)) !== undefined;
    }
    function isSameAction(action1, action2) {
        return (action1.date.getTime() === action2.date.getTime()
            && action1.user === action2.user);
    }
    function sortChangeHistory(changeHistory) {
        changeHistory.sort((action1, action2) => {
            if (action1.date < action2.date)
                return -1;
            if (action2.date < action1.date)
                return 1;
            return 0;
        });
    }
})(ChangeHistoryMerge = exports.ChangeHistoryMerge || (exports.ChangeHistoryMerge = {}));
//# sourceMappingURL=change-history-merge.js.map