/// <reference types="pouchdb-find" />
/// <reference types="pouchdb-core" />
/// <reference types="pouchdb-adapter-leveldb" />
/// <reference types="pouchdb-adapter-http" />
/// <reference types="pouchdb-mapreduce" />
/// <reference types="pouchdb-replication" />
/// <reference types="pouchdb-node" />
/// <reference types="pouchdb-adapter-cordova-sqlite" />
/// <reference types="pouchdb-adapter-fruitdown" />
/// <reference types="pouchdb-adapter-idb" />
/// <reference types="pouchdb-adapter-localstorage" />
/// <reference types="pouchdb-adapter-memory" />
/// <reference types="pouchdb-adapter-websql" />
import { Observable } from 'rxjs';
import { ConfigurationDocument } from '../../model/configuration-document';
import { Document } from '../../model/document';
import { NewDocument } from '../../model/document';
import { IdGenerator } from './id-generator';
import { PouchDbFactory } from './types';
/**
 * @author Sebastian Cuy
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
export declare class PouchdbDatastore {
    private pouchDbFactory;
    private idGenerator;
    private db;
    private changesObservers;
    private deletedObservers;
    private deletedOnes;
    constructor(pouchDbFactory: PouchDbFactory, idGenerator: IdGenerator);
    getDb: () => PouchDB.Database;
    destroyDb: (dbName: string) => Promise<void>;
    createEmptyDb(name: string, destroyExisting?: boolean): any;
    createDbForTesting(dbName: string): PouchDB.Database<{}>;
    setDb_e2e: (db: PouchDB.Database) => PouchDB.Database<{}>;
    /**
     * Creates a new database. Unless specified specifically
     * with destroyBeforeCreate set to true,
     * a possible existing database with the specified name will get used
     * and not overwritten.
     */
    createDb(name: string, projectDocument?: Document, configurationDocument?: ConfigurationDocument, destroyBeforeCreate?: boolean): Promise<PouchDB.Database>;
    close(): void;
    changesNotifications: () => Observable<Document>;
    deletedNotifications: () => Observable<Document>;
    /**
     * @returns newest revision of the document fetched from db
     * @throws [DOCUMENT_RESOURCE_ID_EXISTS]
     * @throws [INVALID_DOCUMENT] - in case either the document given as param or
     *   the document fetched directly after db.put is not valid
     */
    create(document: NewDocument, username: string): Promise<Document>;
    bulkCreate(documents: Array<NewDocument>, username: string): Promise<Array<Document>>;
    /**
     * @returns newest revision of the document fetched from db
     * @throws [DOCUMENT_NOT_FOUND]
     * @throws [INVALID_DOCUMENT] - in case either the document given as param or
     *   the document fetched directly after db.put is not valid
     */
    update(document: Document, username: string, squashRevisionsIds?: string[]): Promise<Document>;
    bulkUpdate(documents: Array<Document>, username: string): Promise<Array<Document>>;
    /**
     * @throws [DOCUMENT_NOT_FOUND]
     */
    remove(document: Document): Promise<void>;
    /**
     * @param resourceId
     * @param options
     * @param skipValidation
     * @throws [DOCUMENT_NOT_FOUND]
     * @throws [INVALID_DOCUMENT] if not Document.isValid
     * @returns Document. It is made sure that it isValid and the dates are converted to type Date.
     */
    fetch(resourceId: string, options?: any, skipValidation?: boolean): Promise<Document>;
    bulkFetch(resourceIds: string[]): Promise<Array<Document>>;
    /**
     * @throws [DOCUMENT_NOT_FOUND]
     * @throws [INVALID_DOCUMENT]
     */
    fetchRevision(resourceId: string, revisionId: string): Promise<Document>;
    setupChangesEmitter(): void;
    getLatestChange(): Promise<string | undefined>;
    private performPut;
    private performBulkDocs;
    private mergeModifiedDates;
    private removeRevisions;
    private handleNonDeletionChange;
    private assertNotExists;
    private static convertDates;
    private static initializeDocument;
    private static cleanUp;
    private static autoFixCategory;
}
