import { CategoryForm } from '../model/configuration/category-form';
import { Field } from '../model/configuration/field';
import { Document } from '../model/document';
import { Resource } from '../model/resource';
export declare type IndexType = 'match' | 'contain' | 'contained' | 'exist' | 'links';
export interface IndexDefinition {
    path: string;
    pathArray: string[];
    type: IndexType;
    recursivelySearchable?: boolean;
}
export interface ConstraintIndex {
    indexDefinitions: {
        [name: string]: IndexDefinition;
    };
    containIndex: {
        [path: string]: {
            [searchTerm: string]: {
                [id: string]: true;
            };
        };
    };
    matchIndex: {
        [path: string]: {
            [searchTerm: string]: {
                [id: string]: true;
            };
        };
    };
    existIndex: {
        [path: string]: {
            [id: string]: true;
        };
    };
    linksIndex: {
        [path: string]: {
            [resourceId: string]: {
                [id: string]: true;
            };
        };
    };
    allIndex: {
        [resourceId: string]: true;
    };
}
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
export declare module ConstraintIndex {
    function make(defaultIndexDefinitions: {
        [name: string]: IndexDefinition;
    }, categories: Array<CategoryForm>): ConstraintIndex;
    const clear: (index: ConstraintIndex) => void;
    function put(index: ConstraintIndex, document: Document, skipRemoval?: boolean, indexDefinitionName?: string): void;
    function remove(index: ConstraintIndex, document: Document, indexDefinitionName?: string): void;
    function get(index: ConstraintIndex, indexName: string, matchTerms: string | string[]): Array<Resource.Id>;
    function getWithDescendants(index: ConstraintIndex, indexName: string, matchTerm: string | string[]): Array<Resource.Id>;
    function getCount(index: ConstraintIndex, indexName: string, matchTerm: string): number;
    function addIndexDefinitionsForField(index: ConstraintIndex, field: Field): void;
    function getIndexType(field: Field): IndexType;
}
