import { Document } from '../model/document';
import { Resource } from '../model/resource';
import { Field } from '../model';
export interface FulltextIndex {
    [category: string]: {
        [term: string]: {
            [id: string]: true;
        };
    };
}
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
export declare module FulltextIndex {
    function put(index: FulltextIndex, document: Document, fieldsToIndex: Array<Field>, skipRemoval?: boolean): void;
    function remove(index: FulltextIndex, document: Document): void;
    /**
     * @param index
     * @param s search string, which gets tokenized, so that the result will include
     *   search hits for any of the tokens. If s is "hello world", all items which are
     *   indexed under either "hello" or "world" will be included in the result. The
     *   result will be a set in the sense that it will include each item only once.
     * @param categories if undefined, searches in all categories. If defined, only search hits
     *   indexed under the specified categories will be included in the results.
     */
    function get(index: FulltextIndex, s: string, categories: string[] | undefined): Array<Resource.Id>;
}
