import { Observable } from 'rxjs';
import { Field } from '../model/configuration/field';
import { Document } from '../model/document';
import { Query } from '../model/query';
import { ProjectConfiguration } from '../services';
import { ConstraintIndex } from './constraint-index';
import { FulltextIndex } from './fulltext-index';
/**
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
export declare class IndexFacade {
    private constraintIndex;
    private fulltextIndex;
    private projectConfiguration;
    private showWarnings;
    private observers;
    private indexItems;
    constructor(constraintIndex: ConstraintIndex, fulltextIndex: FulltextIndex, projectConfiguration: ProjectConfiguration, showWarnings: boolean);
    changesNotifications: () => Observable<Document | undefined>;
    find(query: Query): Array<string>;
    /**
     * @param document document.resource.identifier needs to be present, otherwise document does not get indexed
     */
    put(document: Document): void;
    /**
     * This does not notify observers of IndexFacade notifications. notifyObservers has to be called after all changes
     * to the index have been completed.
     */
    putToSingleIndex(document: Document, constraintIndexName: string): void;
    putMultiple(documents: Array<Document>, setProgress?: (count: number) => Promise<void>): Promise<void>;
    remove(document: Document): void;
    clear(): void;
    getCount(constraintIndexName: string, matchTerm: string): number;
    getDescendantIds(constraintIndexName: string, matchTerm: string): string[];
    addConstraintIndexDefinitionsForField(field: Field): void;
    notifyObservers(): void;
    private getSortedResult;
    private _put;
    private getIndexItem;
    private static createAssociatedTypeItem;
    private static deleteAssociatedTypeItem;
    private static updateTypeItem;
    private static setChildOfRelation;
    private static removeChildOfRelation;
}
