"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Indexer = void 0;
const tsfun_1 = require("tsfun");
const warnings_updater_1 = require("../datastore/warnings-updater");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 * @author Sebastian Cuy
 */
var Indexer;
(function (Indexer) {
    function reindex(indexFacade, db, documentCache, converter, projectConfiguration, keepCachedInstances, setProgress, setIndexing, setError) {
        return __awaiter(this, void 0, void 0, function* () {
            indexFacade.clear();
            let documents = [];
            try {
                documents = yield fetchAll(db);
            }
            catch (err) {
                console.error(err);
                setError && (yield setError('fetchDocumentsError'));
                throw err;
            }
            setIndexing && (yield setIndexing());
            try {
                if (keepCachedInstances) {
                    documents = documents.filter(document => { var _a; return !documentCache.get((_a = document.resource) === null || _a === void 0 ? void 0 : _a.id); });
                }
                documents = convertDocuments(documents, converter);
                documents.forEach(document => {
                    warnings_updater_1.WarningsUpdater.updateIndexIndependentWarnings(document, projectConfiguration);
                    documentCache.set(document);
                });
                if (keepCachedInstances) {
                    documentCache.getAll().forEach(document => {
                        warnings_updater_1.WarningsUpdater.updateIndexIndependentWarnings(document, projectConfiguration);
                    });
                    documents = documents.concat(documentCache.getAll());
                }
                yield indexFacade.putMultiple(documents, setProgress);
                yield addIndexDependentWarnings(indexFacade, documentCache, projectConfiguration, setProgress);
            }
            catch (err) {
                console.error(err);
                setError && setError('indexingError');
                throw err;
            }
        });
    }
    Indexer.reindex = reindex;
    function fetchAll(db) {
        return __awaiter(this, void 0, void 0, function* () {
            return (yield db
                .allDocs({
                include_docs: true,
                conflicts: true
            })).rows
                .filter(row => !isDesignDoc(row))
                .map(row => row.doc);
        });
    }
    function convertDocuments(documents, converter) {
        return documents.map(document => {
            try {
                converter.convert(document);
                return document;
            }
            catch (err) {
                console.warn('Error while converting document: ', err);
                return undefined;
            }
        }).filter(tsfun_1.not(tsfun_1.isUndefined));
    }
    function addIndexDependentWarnings(indexFacade, documentCache, projectConfiguration, setProgress) {
        return __awaiter(this, void 0, void 0, function* () {
            const documents = documentCache.getAll();
            for (let i = 0; i < documents.length; i++) {
                const document = documents[i];
                yield warnings_updater_1.WarningsUpdater.updateIndexDependentWarnings(document, indexFacade, documentCache, projectConfiguration);
                if (setProgress && (i % 250 === 0 || i === documents.length)) {
                    yield setProgress(documents.length * 0.75 + i * 0.25);
                }
            }
            ;
            indexFacade.notifyObservers();
        });
    }
    const isDesignDoc = (row) => row.id.indexOf('_') === 0;
})(Indexer = exports.Indexer || (exports.Indexer = {}));
//# sourceMappingURL=indexer.js.map