"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.performQuery = void 0;
const constraint_1 = require("../model/constraint");
const query_1 = require("../model/query");
const constraint_index_1 = require("./constraint-index");
const fulltext_index_1 = require("./fulltext-index");
const result_sets_1 = require("./result-sets");
/**
 * @author Daniel de Oliveira
 *
 * Runtime info: Skips the fulltime query if query is empty and constraint search delivered results
 */
function performQuery(query, constraintIndex, fulltextIndex) {
    let resultSets = performConstraints(constraintIndex, query.constraints ? query.constraints : {});
    resultSets = result_sets_1.ResultSets.containsOnlyEmptyAddSets(resultSets)
        || (query_1.Query.isEmpty(query) && !result_sets_1.ResultSets.isEmpty(resultSets))
        ? resultSets
        : performFulltext(fulltextIndex, query, resultSets);
    return result_sets_1.ResultSets.collapse(resultSets);
}
exports.performQuery = performQuery;
function performFulltext(fulltextIndex, query, resultSets) {
    const q = !query.q || query.q.trim() === '' ? '*' : query.q;
    const queryResult = fulltext_index_1.FulltextIndex.get(fulltextIndex, q, query.categories);
    result_sets_1.ResultSets.combine(resultSets, queryResult);
    return resultSets;
}
function performConstraints(constraintIndex, constraints) {
    return Object.keys(constraints).reduce((resultSets, name) => {
        const constraint = constraint_1.Constraint.convert(constraints[name]);
        const get = !constraint.searchRecursively
            ? constraint_index_1.ConstraintIndex.get
            : constraint_index_1.ConstraintIndex.getWithDescendants;
        const indexItemIds = get(constraintIndex, name, constraint.value);
        result_sets_1.ResultSets.combine(resultSets, indexItemIds, constraint.subtract);
        return resultSets;
    }, result_sets_1.ResultSets.make());
}
//# sourceMappingURL=perform-query.js.map