"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Composite = void 0;
const tsfun_1 = require("tsfun");
const field_1 = require("./configuration/field");
/**
 * @author Thomas Kleinke
 */
var Composite;
(function (Composite) {
    function isValid(entry, subfields) {
        if (!entry || !tsfun_1.isObject(entry))
            return false;
        return Object.keys(entry).find(subfieldName => {
            const subfieldDefinition = subfields.find(subfield => subfield.name === subfieldName);
            return !subfieldDefinition
                || !field_1.Field.isValidFieldData(entry[subfieldName], subfieldDefinition)
                || !isConditionFulfilled(entry, subfieldDefinition, subfields);
        }) === undefined;
    }
    Composite.isValid = isValid;
    function isConditionFulfilled(entry, subfieldToCheck, subfields) {
        if (!subfieldToCheck.condition)
            return true;
        const conditionSubfield = subfields.find(subfield => {
            return subfield.name === subfieldToCheck.condition.subfieldName;
        });
        const data = entry[conditionSubfield.name];
        const fulfilled = data !== undefined
            ? tsfun_1.isArray(subfieldToCheck.condition.values)
                ? tsfun_1.isArray(data)
                    ? tsfun_1.intersect(data)(subfieldToCheck.condition.values).length > 0
                    : subfieldToCheck.condition.values.includes(data)
                : data === subfieldToCheck.condition.values
            : false;
        return fulfilled
            ? conditionSubfield.condition
                ? isConditionFulfilled(entry, conditionSubfield, subfields)
                : true
            : false;
    }
    Composite.isConditionFulfilled = isConditionFulfilled;
    /**
     * @returns null if no label could be generated because of invalid data
     */
    function generateLabel(entry, subfields, translate, getFromLabeledValue, getFromI18NString, getValueLabel) {
        try {
            return subfields.reduce((result, subfield) => {
                const subfieldData = entry[subfield.name];
                if (subfieldData === undefined)
                    return result;
                if (result.length !== 0)
                    result += ', ';
                return result
                    + getFromLabeledValue(subfield) + ': '
                    + generateSubfieldLabel(subfieldData, subfield.inputType, translate, getFromI18NString, getValueLabel, subfield.valuelist);
            }, '');
        }
        catch (err) {
            console.warn('Failed to generate label.', err);
            return null;
        }
    }
    Composite.generateLabel = generateLabel;
    function generateSubfieldLabel(subfieldData, inputType, translate, getFromI18NString, getValueLabel, valuelist) {
        switch (inputType) {
            case field_1.Field.InputType.INPUT:
            case field_1.Field.InputType.TEXT:
                return getFromI18NString(subfieldData);
            case field_1.Field.InputType.MULTIINPUT:
                return subfieldData.map(i18nString => getFromI18NString(i18nString)).join('/');
            case field_1.Field.InputType.SIMPLE_MULTIINPUT:
                return subfieldData.join('/');
            case field_1.Field.InputType.BOOLEAN:
                return translate(subfieldData);
            case field_1.Field.InputType.DROPDOWN:
            case field_1.Field.InputType.RADIO:
                return getValueLabel(valuelist, subfieldData);
            case field_1.Field.InputType.CHECKBOXES:
                return subfieldData.map(valueId => getValueLabel(valuelist, valueId)).join('/');
            default:
                return subfieldData;
        }
    }
})(Composite = exports.Composite || (exports.Composite = {}));
//# sourceMappingURL=composite.js.map