"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigurationDocument = exports.OVERRIDE_VISIBLE_FIELDS = void 0;
const tsfun_1 = require("tsfun");
const document_1 = require("./document");
const category_form_1 = require("./configuration/category-form");
const custom_language_configurations_1 = require("./custom-language-configurations");
const resource_1 = require("./resource");
const field_resource_1 = require("./field-resource");
const project_configuration_names_1 = require("../configuration/project-configuration-names");
const sample_data_labels_1 = require("../datastore/sampledata/sample-data-labels");
exports.OVERRIDE_VISIBLE_FIELDS = [resource_1.Resource.IDENTIFIER, field_resource_1.FieldResource.SHORTDESCRIPTION, field_resource_1.FieldResource.GEOMETRY];
var ConfigurationDocument;
(function (ConfigurationDocument) {
    function getConfigurationDocument(getFunction, configReader, projectIdentifier, username) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield getFunction('configuration');
            }
            catch (_) {
                return yield createConfigurationDocumentFromFile(configReader, projectIdentifier, username);
            }
        });
    }
    ConfigurationDocument.getConfigurationDocument = getConfigurationDocument;
    ConfigurationDocument.isHidden = (customFormDefinition, parentCustomFormDefinitiion) => (field) => {
        var _a, _b;
        return ((_a = customFormDefinition === null || customFormDefinition === void 0 ? void 0 : customFormDefinition.hidden) !== null && _a !== void 0 ? _a : []).includes(field.name) ||
            ((_b = parentCustomFormDefinitiion === null || parentCustomFormDefinitiion === void 0 ? void 0 : parentCustomFormDefinitiion.hidden) !== null && _b !== void 0 ? _b : []).includes(field.name);
    };
    function isCustomizedCategory(configurationDocument, category, checkChildren = false) {
        var _a;
        const customDefinition = configurationDocument.resource
            .forms[(_a = category.libraryId) !== null && _a !== void 0 ? _a : category.name];
        const result = customDefinition.color !== undefined
            || customDefinition.groups !== undefined
            || (customDefinition.valuelists !== undefined && !tsfun_1.isEmpty(customDefinition.valuelists))
            || (customDefinition.fields !== undefined && !tsfun_1.isEmpty(customDefinition.fields))
            || (customDefinition.hidden !== undefined && !tsfun_1.isEmpty(customDefinition.hidden))
            || custom_language_configurations_1.CustomLanguageConfigurations.hasCustomTranslations(configurationDocument.resource.languages, category);
        if (checkChildren) {
            if (category.children.find(childCategory => isCustomizedCategory(configurationDocument, childCategory))) {
                return true;
            }
        }
        return result;
    }
    ConfigurationDocument.isCustomizedCategory = isCustomizedCategory;
    function getCustomCategoryDefinition(configurationDocument, category) {
        var _a;
        return configurationDocument.resource.forms[(_a = category.libraryId) !== null && _a !== void 0 ? _a : category.name];
    }
    ConfigurationDocument.getCustomCategoryDefinition = getCustomCategoryDefinition;
    function getParentCustomCategoryDefinition(configurationDocument, category) {
        var _a;
        return category.parentCategory
            ? configurationDocument.resource.forms[(_a = category.parentCategory.libraryId) !== null && _a !== void 0 ? _a : category.parentCategory.name]
            : undefined;
    }
    ConfigurationDocument.getParentCustomCategoryDefinition = getParentCustomCategoryDefinition;
    function deleteCategory(customConfigurationDocument, category, removeFromCategoriesOrder = true) {
        var _a;
        const clonedConfigurationDocument = document_1.Document.clone(customConfigurationDocument);
        delete clonedConfigurationDocument.resource.forms[(_a = category.libraryId) !== null && _a !== void 0 ? _a : category.name];
        custom_language_configurations_1.CustomLanguageConfigurations.deleteCategory(clonedConfigurationDocument.resource.languages, category);
        if (removeFromCategoriesOrder) {
            clonedConfigurationDocument.resource.order
                = clonedConfigurationDocument.resource.order.filter(categoryName => categoryName !== category.name);
        }
        return clonedConfigurationDocument;
    }
    ConfigurationDocument.deleteCategory = deleteCategory;
    function deleteGroup(customConfigurationDocument, category, group, otherCategories) {
        var _a;
        const clonedConfigurationDocument = document_1.Document.clone(customConfigurationDocument);
        const clonedCategoryConfiguration = clonedConfigurationDocument.resource
            .forms[(_a = category.libraryId) !== null && _a !== void 0 ? _a : category.name];
        clonedCategoryConfiguration.groups = clonedCategoryConfiguration
            .groups.filter(g => g.name !== group.name);
        if (!otherCategories.find(category => category.groups.find(g => g.name === group.name))) {
            custom_language_configurations_1.CustomLanguageConfigurations.update(clonedConfigurationDocument.resource.languages, {}, {}, category, undefined, undefined, group);
        }
        return clonedConfigurationDocument;
    }
    ConfigurationDocument.deleteGroup = deleteGroup;
    function deleteField(customConfigurationDocument, category, field) {
        var _a;
        const clonedConfigurationDocument = document_1.Document.clone(customConfigurationDocument);
        const clonedCategoryConfiguration = clonedConfigurationDocument.resource
            .forms[(_a = category.libraryId) !== null && _a !== void 0 ? _a : category.name];
        delete clonedCategoryConfiguration.fields[field.name];
        const scanCodeConfiguration = clonedCategoryConfiguration.scanCodes;
        if (scanCodeConfiguration === null || scanCodeConfiguration === void 0 ? void 0 : scanCodeConfiguration.printedFields) {
            scanCodeConfiguration.printedFields = scanCodeConfiguration.printedFields.filter(printedField => {
                return printedField.name !== field.name;
            });
        }
        removeFieldFromForm(clonedConfigurationDocument, category, field.name);
        category.children.filter(childCategory => childCategory.customFields.includes(field.name))
            .forEach(childCategory => {
            removeFieldFromForm(clonedConfigurationDocument, childCategory, field.name);
        });
        custom_language_configurations_1.CustomLanguageConfigurations.update(clonedConfigurationDocument.resource.languages, {}, {}, category, field);
        if (field.subfields) {
            field.subfields.forEach(subfield => {
                custom_language_configurations_1.CustomLanguageConfigurations.update(clonedConfigurationDocument.resource.languages, {}, {}, category, field, subfield);
            });
        }
        return clonedConfigurationDocument;
    }
    ConfigurationDocument.deleteField = deleteField;
    function deleteValuelist(customConfigurationDocument, valuelist) {
        const clonedConfigurationDocument = document_1.Document.clone(customConfigurationDocument);
        delete clonedConfigurationDocument.resource.valuelists[valuelist.id];
        return clonedConfigurationDocument;
    }
    ConfigurationDocument.deleteValuelist = deleteValuelist;
    function getPermanentlyHiddenFields(category) {
        return category.name === 'Project'
            ? [resource_1.Resource.IDENTIFIER]
            : [];
    }
    ConfigurationDocument.getPermanentlyHiddenFields = getPermanentlyHiddenFields;
    function swapCategoryForm(configurationDocument, currentForm, newForm, parentForm) {
        const clonedConfigurationDocument = ConfigurationDocument.deleteCategory(configurationDocument, currentForm, false);
        [newForm].concat(currentForm.children).forEach(form => {
            const formDefinition = {
                fields: {},
                hidden: []
            };
            if (form.source === 'custom' && form.parentCategory) {
                formDefinition.parent = form.parentCategory.name;
                formDefinition.groups = category_form_1.CategoryForm.getGroupsConfiguration(newForm, getPermanentlyHiddenFields(newForm));
            }
            clonedConfigurationDocument.resource.forms[form.libraryId] = formDefinition;
        });
        if (parentForm)
            addCustomParentFields(newForm, parentForm, clonedConfigurationDocument);
        return clonedConfigurationDocument;
    }
    ConfigurationDocument.swapCategoryForm = swapCategoryForm;
    function addCategoryForm(configurationDocument, categoryForm, parentForm) {
        var _a;
        const clonedConfigurationDocument = document_1.Document.clone(configurationDocument);
        clonedConfigurationDocument.resource.forms[categoryForm.libraryId] = {
            fields: {},
            hidden: []
        };
        if (parentForm)
            addCustomParentFields(categoryForm, parentForm, clonedConfigurationDocument);
        return addToCategoriesOrder(clonedConfigurationDocument, categoryForm.name, (_a = categoryForm.parentCategory) === null || _a === void 0 ? void 0 : _a.name);
    }
    ConfigurationDocument.addCategoryForm = addCategoryForm;
    function addField(configurationDocument, category, permanentlyHiddenFields, groupName, fieldName) {
        const clonedConfigurationDocument = document_1.Document.clone(configurationDocument);
        addFieldToGroup(clonedConfigurationDocument, category, permanentlyHiddenFields, groupName, fieldName);
        category.children.filter(childCategory => {
            return !category_form_1.CategoryForm.getFields(childCategory).map(tsfun_1.to('name')).includes(fieldName);
        })
            .forEach(childCategory => {
            addFieldToGroup(clonedConfigurationDocument, childCategory, permanentlyHiddenFields, groupName, fieldName);
        });
        return clonedConfigurationDocument;
    }
    ConfigurationDocument.addField = addField;
    function addToCategoriesOrder(configurationDocument, newCategoryName, parentCategoryName) {
        const clonedConfigurationDocument = document_1.Document.clone(configurationDocument);
        const order = clonedConfigurationDocument.resource.order;
        if (parentCategoryName) {
            order.splice(order.indexOf(parentCategoryName) + 1, 0, newCategoryName);
        }
        else {
            order.push(newCategoryName);
        }
        return clonedConfigurationDocument;
    }
    ConfigurationDocument.addToCategoriesOrder = addToCategoriesOrder;
    function createConfigurationDocumentFromFile(configReader, projectIdentifier, username) {
        return __awaiter(this, void 0, void 0, function* () {
            const customConfigurationName = project_configuration_names_1.getConfigurationName(projectIdentifier);
            const customConfiguration = yield configReader.read('/Config-' + customConfigurationName + '.json');
            const languageConfigurations = configReader.getCustomLanguageConfigurations(customConfigurationName);
            const configurationDocument = {
                _id: 'configuration',
                created: {
                    user: username,
                    date: new Date()
                },
                modified: [],
                resource: {
                    id: 'configuration',
                    identifier: 'Configuration',
                    category: 'Configuration',
                    relations: {},
                    forms: customConfiguration.forms,
                    order: customConfiguration.order,
                    languages: languageConfigurations,
                    valuelists: {},
                    projectLanguages: projectIdentifier === 'test' ? Object.keys(sample_data_labels_1.sampleDataLabels) : []
                }
            };
            return configurationDocument;
        });
    }
    function addCustomParentFields(categoryForm, parentForm, clonedConfigurationDocument) {
        parentForm.groups.forEach(group => {
            group.fields.filter(field => { var _a; return (_a = parentForm.customFields) === null || _a === void 0 ? void 0 : _a.includes(field.name); })
                .forEach(field => addFieldToGroup(clonedConfigurationDocument, categoryForm, getPermanentlyHiddenFields(categoryForm), group.name, field.name));
        });
    }
    function addFieldToGroup(configurationDocument, category, permanentlyHiddenFields, groupName, fieldName) {
        var _a;
        const form = configurationDocument.resource
            .forms[(_a = category.libraryId) !== null && _a !== void 0 ? _a : category.name];
        if (!form.groups || form.groups.length === 0) {
            form.groups = category_form_1.CategoryForm.getGroupsConfiguration(category, permanentlyHiddenFields);
        }
        let group = form.groups.find(tsfun_1.on('name', groupName));
        if (!group) {
            group = { name: groupName, fields: [] };
            form.groups.push(group);
        }
        group.fields.push(fieldName);
    }
    function removeFieldFromForm(configurationDocument, category, fieldName) {
        var _a, _b;
        const formDefinition = configurationDocument.resource
            .forms[(_a = category.libraryId) !== null && _a !== void 0 ? _a : category.name];
        const groupDefinition = formDefinition.groups
            .find(group => group.fields.includes(fieldName));
        groupDefinition.fields = groupDefinition.fields.filter(f => f !== fieldName);
        if (groupDefinition.fields.length === 0) {
            formDefinition.groups.splice(formDefinition.groups.indexOf(groupDefinition), 1);
        }
        if ((_b = formDefinition.valuelists) === null || _b === void 0 ? void 0 : _b[fieldName]) {
            delete formDefinition.valuelists[fieldName];
            if (tsfun_1.isEmpty(formDefinition.valuelists))
                delete formDefinition.valuelists;
        }
    }
})(ConfigurationDocument = exports.ConfigurationDocument || (exports.ConfigurationDocument = {}));
//# sourceMappingURL=configuration-document.js.map