import { I18N } from '../../tools/i18n';
import { Name } from '../../tools/named';
import { Field } from './field';
import { Group, GroupDefinition } from './group';
import { Valuelist } from './valuelist';
import { ScanCodeConfiguration } from './scan-code-configuration';
export interface CategoryForm {
    name: string;
    /**
     * For builtIn and library categories, the original identifier (possibly a map key).
     */
    libraryId?: string;
    source?: 'builtin' | 'library' | 'custom';
    customFields?: string[];
    isAbstract: boolean;
    mustLieWithin: boolean | undefined;
    userDefinedSubcategoriesAllowed?: boolean;
    scanCodesAllowed?: boolean;
    required?: boolean;
    children: Array<CategoryForm>;
    parentCategory: CategoryForm | undefined;
    groups: Array<Group>;
    label: I18N.String;
    description: I18N.String;
    defaultLabel?: I18N.String;
    defaultDescription?: I18N.String;
    categoryLabel: I18N.String;
    createdBy?: string;
    creationDate?: Date;
    references?: string[];
    color?: CategoryForm.Color;
    defaultColor?: CategoryForm.Color;
    identifierPrefix?: string;
    resourceLimit?: number;
    scanCodes?: ScanCodeConfiguration;
}
/**
 * @author F.Z.
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
export declare namespace CategoryForm {
    type Color = string;
    const COLOR = "color";
    const PARENT_CATEGORY = "parentCategory";
    const DEFAULT_LABEL = "defaultLabel";
    const CHILDREN = "children";
    const DESCRIPTION = "description";
    const GROUPS = "groups";
    namespace Source {
        const BUILTIN = "builtin";
        const LIBRARY = "library";
        const CUSTOM = "custom";
    }
    function build(name: Name, parentCategory?: CategoryForm): CategoryForm;
    function getFields(category: CategoryForm): Array<Field>;
    function getField(category: CategoryForm, fieldName: string): Field;
    function getNamesOfCategoryAndSubcategories(category: CategoryForm): string[];
    function getTextColorForCategory(category: CategoryForm): string;
    function hasCustomFields(category: CategoryForm): boolean;
    function isMandatoryField(category: CategoryForm, fieldName: string): boolean;
    function getGroupsConfiguration(category: CategoryForm, permanentlyHiddenFields: string[]): Array<GroupDefinition>;
    function getShortDescriptionValuelist(category: CategoryForm): Valuelist | undefined;
    function isBrightColor(color: Color): boolean;
    function generateColorForCategory(categoryName: string): Color;
}
