"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CategoryForm = void 0;
const tsfun_1 = require("tsfun");
const named_1 = require("../../tools/named");
const field_resource_1 = require("../field-resource");
const field_1 = require("./field");
const group_1 = require("./group");
/**
 * @author F.Z.
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
var CategoryForm;
(function (CategoryForm) {
    CategoryForm.COLOR = 'color';
    CategoryForm.PARENT_CATEGORY = 'parentCategory';
    CategoryForm.DEFAULT_LABEL = 'defaultLabel';
    CategoryForm.CHILDREN = 'children';
    CategoryForm.DESCRIPTION = 'description';
    CategoryForm.GROUPS = 'groups';
    let Source;
    (function (Source) {
        Source.BUILTIN = 'builtin';
        Source.LIBRARY = 'library';
        Source.CUSTOM = 'custom';
    })(Source = CategoryForm.Source || (CategoryForm.Source = {}));
    function build(name, parentCategory) {
        const color = CategoryForm.generateColorForCategory(name);
        const newCategory = {
            name: name,
            label: {},
            defaultLabel: {},
            description: {},
            defaultDescription: {},
            color: color,
            defaultColor: color,
            source: Source.CUSTOM
        } /* TODO any */;
        if (parentCategory) {
            newCategory.parentCategory = parentCategory;
            newCategory.groups = parentCategory.groups;
        }
        return newCategory;
    }
    CategoryForm.build = build;
    function getFields(category) {
        return tsfun_1.flatMap(tsfun_1.values(category.groups), group_1.Group.toFields);
    }
    CategoryForm.getFields = getFields;
    function getField(category, fieldName) {
        var _a;
        return (_a = getFields(category)) === null || _a === void 0 ? void 0 : _a.find(named_1.Named.onName(tsfun_1.is(fieldName)));
    }
    CategoryForm.getField = getField;
    function getNamesOfCategoryAndSubcategories(category) {
        return [category.name].concat(category.children.map(tsfun_1.to(named_1.Named.NAME)));
    }
    CategoryForm.getNamesOfCategoryAndSubcategories = getNamesOfCategoryAndSubcategories;
    function getTextColorForCategory(category) {
        return CategoryForm.isBrightColor(getColor(category)) ? '#000000' : '#ffffff';
    }
    CategoryForm.getTextColorForCategory = getTextColorForCategory;
    function getColor(category) {
        var _a;
        return (_a = category.color) !== null && _a !== void 0 ? _a : '#cccccc';
    }
    function hasCustomFields(category) {
        return tsfun_1.compose(CategoryForm.getFields, tsfun_1.map(tsfun_1.to(field_1.Field.SOURCE)), tsfun_1.any(tsfun_1.is(field_1.Field.Source.CUSTOM)))(category);
    }
    CategoryForm.hasCustomFields = hasCustomFields;
    function isMandatoryField(category, fieldName) {
        return hasProperty(category, fieldName, field_1.Field.MANDATORY);
    }
    CategoryForm.isMandatoryField = isMandatoryField;
    function getGroupsConfiguration(category, permanentlyHiddenFields) {
        return category.groups
            .reduce((result, group) => {
            result.push({
                name: group.name,
                fields: group.fields
                    .filter(field => !permanentlyHiddenFields.includes(field.name))
                    .map(field => field.name)
            });
            return result;
        }, []);
    }
    CategoryForm.getGroupsConfiguration = getGroupsConfiguration;
    function getShortDescriptionValuelist(category) {
        const fields = CategoryForm.getFields(category);
        const shortDescriptionField = fields.find(field => field.name === field_resource_1.FieldResource.SHORTDESCRIPTION);
        return shortDescriptionField.valuelist;
    }
    CategoryForm.getShortDescriptionValuelist = getShortDescriptionValuelist;
    function isBrightColor(color) {
        color = color.substring(1); // strip #
        let rgb = parseInt(color, 16); // convert rrggbb to decimal
        let r = (rgb >> 16) & 0xff; // extract red
        let g = (rgb >> 8) & 0xff; // extract green
        let b = (rgb >> 0) & 0xff; // extract blue
        let luma = 0.2126 * r + 0.7152 * g + 0.0722 * b; // per ITU-R BT.709
        return luma > 200;
    }
    CategoryForm.isBrightColor = isBrightColor;
    function generateColorForCategory(categoryName) {
        const hash = hashCode(categoryName);
        const r = (hash & 0xFF0000) >> 16;
        const g = (hash & 0x00FF00) >> 8;
        const b = hash & 0x0000FF;
        return '#' + ('0' + r.toString(16)).substr(-2)
            + ('0' + g.toString(16)).substr(-2) + ('0' + b.toString(16)).substr(-2);
    }
    CategoryForm.generateColorForCategory = generateColorForCategory;
    function hashCode(string) {
        let hash = 0, i, chr;
        if (string.length === 0)
            return hash;
        for (i = 0; i < string.length; i++) {
            chr = string.charCodeAt(i);
            hash = ((hash << 5) - hash) + chr;
            hash |= 0; // Convert to 32bit integer
        }
        return hash;
    }
    function hasProperty(category, fieldName, propertyName) {
        return tsfun_1.flow(CategoryForm.getFields(category), tsfun_1.filter(tsfun_1.on(named_1.Named.NAME, tsfun_1.is(fieldName))), tsfun_1.filter(tsfun_1.on(propertyName, tsfun_1.is(true))), tsfun_1.not(tsfun_1.isEmpty));
    }
})(CategoryForm = exports.CategoryForm || (exports.CategoryForm = {}));
//# sourceMappingURL=category-form.js.map