import { I18N } from '../../tools/i18n';
import { Valuelist } from './valuelist';
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
export interface Field extends BaseField {
    inputTypeOptions?: {
        validation?: {
            permissive?: true;
        };
    };
    valuelistFromProjectField?: string;
    editable?: boolean;
    visible?: boolean;
    selectable?: boolean;
    fulltextIndexed?: boolean;
    constraintIndexed?: boolean;
    defaultConstraintIndexed?: boolean;
    mandatory?: true;
    fixedInputType?: true;
    allowOnlyValuesOfParent?: true;
    maxCharacters?: number;
    source?: Field.SourceType;
    subfields?: Array<Subfield>;
    constraintName?: string;
}
export interface Subfield extends BaseField {
    condition?: SubfieldCondition;
}
export interface BaseField extends I18N.LabeledValue, I18N.Described {
    inputType: Field.InputType;
    defaultLabel?: I18N.String;
    defaultDescription?: I18N.String;
    valuelist?: Valuelist;
}
export interface SubfieldCondition {
    subfieldName: string;
    values: string[] | boolean;
}
export declare module Field {
    type SourceType = 'builtIn' | 'library' | 'custom' | 'common';
    const INPUTTYPE = "inputType";
    const SOURCE = "source";
    const VISIBLE = "visible";
    const MANDATORY = "mandatory";
    const EDITABLE = "editable";
    const NAME = "name";
    const LABEL = "label";
    const DESCRIPTION = "description";
    const FULLTEXTINDEXED = "fulltextIndexed";
    const CONSTRAINTINDEXED = "constraintIndexed";
    const GROUP = "group";
    module Source {
        const BUILTIN = "builtIn";
        const LIBRARY = "library";
        const CUSTOM = "custom";
        const COMMON = "common";
    }
    function isValidFieldData(fieldData: any, field: BaseField): boolean;
    type InputType = 'input' | 'simpleInput' | 'unsignedInt' | 'unsignedFloat' | 'int' | 'float' | 'text' | 'url' | 'multiInput' | 'simpleMultiInput' | 'dropdown' | 'dropdownRange' | 'radio' | 'boolean' | 'checkboxes' | 'dating' | 'date' | 'dimension' | 'literature' | 'geometry' | 'relation' | 'derivedRelation' | 'instanceOf' | 'default' | 'category' | 'identifier' | 'composite' | 'none';
    module InputType {
        const INPUT = "input";
        const SIMPLE_INPUT = "simpleInput";
        const UNSIGNEDINT = "unsignedInt";
        const UNSIGNEDFLOAT = "unsignedFloat";
        const INT = "int";
        const FLOAT = "float";
        const TEXT = "text";
        const MULTIINPUT = "multiInput";
        const SIMPLE_MULTIINPUT = "simpleMultiInput";
        const URL = "url";
        const DROPDOWN = "dropdown";
        const DROPDOWNRANGE = "dropdownRange";
        const RADIO = "radio";
        const BOOLEAN = "boolean";
        const CHECKBOXES = "checkboxes";
        const DATING = "dating";
        const DATE = "date";
        const DIMENSION = "dimension";
        const LITERATURE = "literature";
        const GEOMETRY = "geometry";
        const INSTANCE_OF = "instanceOf";
        const RELATION = "relation";
        const DERIVED_RELATION = "derivedRelation";
        const CATEGORY = "category";
        const IDENTIFIER = "identifier";
        const COMPOSITE = "composite";
        const NONE = "none";
        const DEFAULT = "default";
        const VALUELIST_INPUT_TYPES: Array<InputType>;
        const NUMBER_INPUT_TYPES: Array<InputType>;
        const I18N_COMPATIBLE_INPUT_TYPES: Array<InputType>;
        const I18N_INPUT_TYPES: Array<InputType>;
        const SIMPLE_INPUT_TYPES: Array<InputType>;
        const SUBFIELD_INPUT_TYPES: Array<InputType>;
        const RELATION_INPUT_TYPES: Array<InputType>;
        function getInterchangeableInputTypes(inputType: InputType): Array<InputType>;
    }
}
