import { Map } from 'tsfun';
import { I18N } from '../../tools/i18n';
import { ValuelistValue } from './valuelist-value';
export declare type ValuelistId = string;
export declare type Valuelists = {
    [fieldName: string]: ValuelistId | Map<ValuelistId>;
};
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
export interface Valuelist {
    id?: string;
    values: {
        [key: string]: ValuelistValue;
    };
    description?: {
        [language: string]: string;
    };
    createdBy?: string;
    creationDate?: string;
    references?: string[];
    extendedValuelist?: string;
    hidden?: string[];
    order?: string[];
    source?: Valuelist.SourceTypes;
    deprecated?: boolean;
}
export declare module Valuelist {
    type SourceTypes = 'library' | 'custom';
    function getValueLabel(valuelist: Valuelist, valueId: string): I18N.String | undefined;
    function assertIsValid(valuelistDefinition: Valuelist): string[];
    function applyExtension(valuelist: Valuelist, extendedValuelist: Valuelist): Valuelist;
    function orderKeysByLabels(valuelist: Valuelist, alternativeComparator: (valuelist: Valuelist) => (a: string, b: string) => number): string[];
}
