"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomLanguageConfigurations = void 0;
const in_place_1 = require("../tools/in-place");
const field_1 = require("./configuration/field");
/**
 * @author Thomas Kleinke
 */
var CustomLanguageConfigurations;
(function (CustomLanguageConfigurations) {
    function update(customLanguageConfigurations, editedLabel, editedDescription, category, field, subfield, group) {
        updateSection(customLanguageConfigurations, 'label', editedLabel, category, field, subfield, group);
        if (!group && editedDescription) {
            updateSection(customLanguageConfigurations, 'description', editedDescription, category, field, subfield);
        }
    }
    CustomLanguageConfigurations.update = update;
    function deleteCategory(customLanguageConfigurations, category) {
        Object.keys(customLanguageConfigurations).forEach(languageKey => {
            in_place_1.InPlace.removeFrom(customLanguageConfigurations, [languageKey, 'categories', category.name]);
        });
    }
    CustomLanguageConfigurations.deleteCategory = deleteCategory;
    function hasCustomTranslations(customLanguageConfigurations, category) {
        return Object.values(customLanguageConfigurations).find(languageConfiguration => {
            var _a;
            return (_a = languageConfiguration.categories) === null || _a === void 0 ? void 0 : _a[category.name];
        }) !== undefined;
    }
    CustomLanguageConfigurations.hasCustomTranslations = hasCustomTranslations;
    function updateSection(customLanguageConfigurations, section, editedI18nString, category, field, subfield, group) {
        Object.keys(editedI18nString).forEach(languageCode => {
            handleNewTextInSection(customLanguageConfigurations, section, editedI18nString[languageCode], languageCode, category, field, subfield, group);
        });
        Object.keys(customLanguageConfigurations)
            .filter(languageCode => !editedI18nString[languageCode])
            .forEach(languageCode => {
            deleteFromSection(customLanguageConfigurations, section, languageCode, category === null || category === void 0 ? void 0 : category.name, field, subfield, group === null || group === void 0 ? void 0 : group.name);
        });
    }
    function handleNewTextInSection(customLanguageConfigurations, section, newText, languageCode, category, field, subfield, group) {
        var _a, _b, _c;
        const definition = (_b = (_a = group !== null && group !== void 0 ? group : subfield) !== null && _a !== void 0 ? _a : field) !== null && _b !== void 0 ? _b : category;
        if (newText === ((_c = definition[section === 'label' ? 'defaultLabel' : 'defaultDescription']) === null || _c === void 0 ? void 0 : _c[languageCode])) {
            deleteFromSection(customLanguageConfigurations, section, languageCode, category === null || category === void 0 ? void 0 : category.name, field, subfield, group === null || group === void 0 ? void 0 : group.name);
        }
        else {
            addToSection(customLanguageConfigurations, section, newText, languageCode, category === null || category === void 0 ? void 0 : category.name, field, subfield, group === null || group === void 0 ? void 0 : group.name);
        }
    }
    function deleteFromSection(customLanguageConfigurations, section, languageCode, categoryName, field, subfield, groupName) {
        in_place_1.InPlace.removeFrom(customLanguageConfigurations, getPath(section, languageCode, categoryName, field, subfield, groupName));
    }
    function addToSection(customLanguageConfigurations, section, newText, languageCode, categoryName, field, subfield, groupName) {
        in_place_1.InPlace.setOn(customLanguageConfigurations, getPath(section, languageCode, categoryName, field, subfield, groupName))(newText);
    }
    function getPath(section, languageCode, categoryName, field, subfield, groupName) {
        return groupName
            ? [languageCode, 'groups', groupName]
            : field
                ? field.inputType === field_1.Field.InputType.RELATION
                    ? [languageCode, 'relations', field.name, section]
                    : subfield
                        ? [languageCode, 'categories', categoryName, 'fields', field.name, 'subfields',
                            subfield.name, section]
                        : [languageCode, 'categories', categoryName, 'fields', field.name, section]
                : [languageCode, 'categories', categoryName, section];
    }
})(CustomLanguageConfigurations = exports.CustomLanguageConfigurations || (exports.CustomLanguageConfigurations = {}));
//# sourceMappingURL=custom-language-configurations.js.map