import { I18N } from '../tools/i18n';
/**
 * @author Sebastian Cuy
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
export interface Dating {
    type: Dating.Types;
    begin?: DatingElement;
    end?: DatingElement;
    margin?: number;
    source?: I18N.String | string;
    isImprecise?: boolean;
    isUncertain?: boolean;
    label?: string;
}
export interface DatingElement {
    year: number;
    inputYear: number;
    inputType: DatingType;
}
export declare type DatingType = 'bce' | 'ce' | 'bp';
export declare module Dating {
    const TYPE = "type";
    const BEGIN = "begin";
    const END = "end";
    const MARGIN = "margin";
    const SOURCE = "source";
    const IS_IMPRECISE = "isImprecise";
    const IS_UNCERTAIN = "isUncertain";
    const LABEL = "label";
    const YEAR = "year";
    const INPUT_YEAR = "inputYear";
    const INPUT_TYPE = "inputType";
    const VALID_DATING_TYPES: string[];
    const VALID_TYPES: string[];
    type Types = 'range' | 'single' | 'before' | 'after' | 'scientific';
    type Translations = 'bce' | 'ce' | 'bp' | 'before' | 'after';
    function isDating(dating: any): dating is Dating;
    function isValid(dating: Dating): boolean;
    function revert(dating: Dating): Dating;
    function addNormalizedValues(dating: Dating): void;
    function generateLabel(dating: Dating, getTranslation: (term: Dating.Translations) => string, getFromI18NString: (i18nString: I18N.String | string) => string): string;
    function setNormalizedYears(dating: Dating): void;
    function getNormalizedYear(inputYear: number, inputType: DatingType): number;
}
