import { I18N } from '../tools/i18n';
/**
 * @author Fabian Z.
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
export interface Dimension {
    value?: number;
    rangeMin?: number;
    rangeMax?: number;
    inputValue: number;
    inputRangeEndValue?: number;
    inputUnit: Dimension.InputUnits;
    measurementPosition?: string;
    measurementComment?: I18N.String | string;
    isImprecise: boolean;
    isRange?: boolean;
    label?: string;
}
export declare module Dimension {
    const VALUE = "value";
    const LABEL = "label";
    const ISRANGE = "isRange";
    const RANGEMIN = "rangeMin";
    const RANGEMAX = "rangeMax";
    const INPUTVALUE = "inputValue";
    const INPUTRANGEENDVALUE = "inputRangeEndValue";
    const INPUTUNIT = "inputUnit";
    const MEASUREMENTPOSITION = "measurementPosition";
    const MEASUREMENTCOMMENT = "measurementComment";
    const ISIMPRECISE = "isImprecise";
    type InputUnits = 'mm' | 'cm' | 'm';
    type Translations = 'asMeasuredBy';
    const VALID_INPUT_UNITS: string[];
    function isDimension(dimension: any): dimension is Dimension;
    /**
     * Note: There still may be dimension['isRange'] boolean values stored in the database.
     * These should be handled properly if we're up to changing things here, for example if
     * we want to make sure only defined fields are present.
     *
     * @param dimension
     * @param options
     */
    function isValid(dimension: Dimension, options?: any): boolean;
    /**
     * Reverts the dimension back to the state before normalization
     * @param dimension gets modified in place
     */
    function revert(dimension: Dimension): Dimension;
    function addNormalizedValues(dimension: Dimension): void;
    function generateLabel(dimension: Dimension, transform: (value: any) => string | null, translate: (term: Dimension.Translations) => string, getFromI18NString: (i18nString: I18N.String | string) => string, measurementPositionLabel?: string): string;
}
