import { NewResource, Resource } from './resource';
import { Action } from './action';
import { Labels, ProjectConfiguration } from '../services';
import { Warnings } from './warnings';
export declare type RevisionId = string;
export declare type DocumentId = string;
export interface NewDocument {
    resource: NewResource;
}
export declare module NewDocument {
    const hasId: (doc: NewDocument) => boolean;
}
/**
 * Document =
 *   | FieldDocument             // Category: Inscriptions, Operations, Finds, Features, Types, TypeCatalogs,
 *                               // !Project, !Images, !Configuration
 *     | [ConcreteFieldDocument] // Resources which can possibly have geometries + Inscriptions, which do not have geometries
 *         | FeatureDocument     // Category: Feature and subtypes
 *     | [AbstractFieldDocument] // Category: Type/TypeCatalog
 *   | ImageDocument             // Category: Image and subtypes
 *   | ConfigurationDocument
 *
 * Names with [] denote Document types which we currently do not have a concrete interface for but exist logically.
 */
export interface Document extends NewDocument {
    _id: DocumentId;
    _rev?: RevisionId;
    _conflicts?: Array<RevisionId>;
    resource: Resource;
    modified: Array<Action>;
    created: Action;
    warnings?: Warnings;
    project?: string;
}
export declare const toResourceId: (doc: Document) => Resource.Id;
/**
 * Companion module
 */
export declare module Document {
    const CREATED = "created";
    const MODIFIED = "modified";
    const PROJECT = "project";
    const RESOURCE = "resource";
    const _REV = "_rev";
    function clone<D extends NewDocument>(document: D): D;
    function getLastModified(document: Document): Action;
    function isValid(document: Document | NewDocument, newDocument?: boolean): boolean;
    function isValidParent(document: Document, parent: Document, recordedInTarget: Document, projectConfiguration: ProjectConfiguration): boolean;
    function getLabel(document: Document, labels: Labels, projectConfiguration: ProjectConfiguration): string;
    function removeFields<D extends Document>(fields: Array<string>): (document: D) => D;
    function removeRelations<D extends Document>(relations: Array<string>): (document: D) => D;
    function removeEmptyRelationArrays(document: Document): Document;
    function hasRelationTarget(document: Document, relationName: string, targetId: string): boolean;
    function hasRelations(document: Document, relationName: string): boolean;
    const hasEqualId: (l: Document | undefined) => (r: Document) => boolean;
    const hasGeometry: (document: Document) => boolean;
}
