"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Document = exports.toResourceId = exports.NewDocument = void 0;
const tsfun_1 = require("tsfun");
const resource_1 = require("./resource");
const object_utils_1 = require("../tools/object-utils");
const relation_1 = require("./configuration/relation");
const named_1 = require("../tools/named");
var NewDocument;
(function (NewDocument) {
    NewDocument.hasId = (doc) => doc.resource.id !== undefined;
})(NewDocument = exports.NewDocument || (exports.NewDocument = {}));
const toResourceId = (doc) => tsfun_1.to([Document.RESOURCE, resource_1.Resource.ID])(doc);
exports.toResourceId = toResourceId;
/**
 * Companion module
 */
var Document;
(function (Document) {
    Document.CREATED = 'created';
    Document.MODIFIED = 'modified';
    Document.PROJECT = 'project';
    Document.RESOURCE = 'resource';
    Document._REV = '_rev';
    function clone(document) {
        if (tsfun_1.isAssociative(document))
            return tsfun_1.map(document, clone);
        if (tsfun_1.isPrimitive(document))
            return document;
        return document instanceof Date
            ? new Date(document)
            : object_utils_1.ObjectUtils.jsonClone(document);
    }
    Document.clone = clone;
    function getLastModified(document) {
        return (document.modified && document.modified.length > 0)
            ? document.modified[document.modified.length - 1]
            : document.created;
    }
    Document.getLastModified = getLastModified;
    function isValid(document, newDocument = false) {
        if (!document.resource)
            return false;
        if (!document.resource.id && !newDocument)
            return false;
        if (!document.resource.category)
            return false;
        if (!document.resource.relations)
            return false;
        if (!newDocument && !document.created)
            return false;
        if (!newDocument && !document.modified)
            return false;
        return true;
    }
    Document.isValid = isValid;
    function isValidParent(document, parent, recordedInTarget, projectConfiguration) {
        const category = projectConfiguration.getCategory(document.resource.category);
        if (!category)
            return true;
        if (parent && !projectConfiguration.getCategory(parent.resource.category))
            return false;
        if (recordedInTarget && !projectConfiguration.getCategory(recordedInTarget.resource.category))
            return false;
        const hasIsRecordedIn = resource_1.Resource.hasRelations(document.resource, relation_1.Relation.Hierarchy.RECORDEDIN);
        const hasLiesWithin = resource_1.Resource.hasRelations(document.resource, relation_1.Relation.Hierarchy.LIESWITHIN);
        if (!parent && (hasIsRecordedIn || hasLiesWithin))
            return false;
        if (!recordedInTarget && hasIsRecordedIn)
            return false;
        if (!hasIsRecordedIn
            && (projectConfiguration.getRegularCategories().map(named_1.Named.toName).includes(document.resource.category))) {
            return false;
        }
        if (!hasLiesWithin && category.mustLieWithin)
            return false;
        if (!parent)
            return true;
        if (hasIsRecordedIn && !projectConfiguration.isAllowedRelationDomainCategory(category.name, recordedInTarget.resource.category, relation_1.Relation.Hierarchy.RECORDEDIN)) {
            return false;
        }
        if (hasLiesWithin && !projectConfiguration.isAllowedRelationDomainCategory(category.name, parent.resource.category, relation_1.Relation.Hierarchy.LIESWITHIN)) {
            return false;
        }
        return true;
    }
    Document.isValidParent = isValidParent;
    function getLabel(document, labels, projectConfiguration) {
        let label = document.resource.identifier;
        if (document.resource.shortDescription) {
            label += ' ('
                + resource_1.Resource.getShortDescriptionLabel(document.resource, labels, projectConfiguration)
                + ')';
        }
        return label;
    }
    Document.getLabel = getLabel;
    function removeFields(fields) {
        return (document) => {
            const result = Object.assign({}, document);
            result.resource = tsfun_1.filter(document.resource, (_propertyValue, propertyKey) => !fields.includes(propertyKey));
            return result;
        };
    }
    Document.removeFields = removeFields;
    function removeRelations(relations) {
        return (document) => {
            const result = Object.assign({}, document);
            result.resource = Object.assign({}, document.resource);
            result.resource.relations = tsfun_1.filter(result.resource.relations, (_propertyValue, propertyKey) => !relations.includes(propertyKey));
            return result;
        };
    }
    Document.removeRelations = removeRelations;
    function removeEmptyRelationArrays(document) {
        const undefinedOrEmptyRelationFields = tsfun_1.flow(document.resource.relations, tsfun_1.filter(tsfun_1.isUndefinedOrEmpty), tsfun_1.keys);
        return removeRelations(undefinedOrEmptyRelationFields)(document);
    }
    Document.removeEmptyRelationArrays = removeEmptyRelationArrays;
    function hasRelationTarget(document, relationName, targetId) {
        return resource_1.Resource.hasRelationTarget(document.resource, relationName, targetId);
    }
    Document.hasRelationTarget = hasRelationTarget;
    function hasRelations(document, relationName) {
        return resource_1.Resource.hasRelations(document.resource, relationName);
    }
    Document.hasRelations = hasRelations;
    Document.hasEqualId = (l) => (r) => (l !== undefined && l.resource.id === r.resource.id);
    Document.hasGeometry = (document) => document.resource.geometry ? true : false;
})(Document = exports.Document || (exports.Document = {}));
//# sourceMappingURL=document.js.map