"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Literature = void 0;
const tsfun_1 = require("tsfun");
var Literature;
(function (Literature) {
    Literature.QUOTATION = 'quotation';
    Literature.ZENON_ID = 'zenonId';
    Literature.DOI = 'doi';
    Literature.PAGE = 'page';
    Literature.FIGURE = 'figure';
    const VALID_FIELDS = [Literature.QUOTATION, Literature.ZENON_ID, Literature.DOI, Literature.PAGE, Literature.FIGURE];
    function isLiterature(literature) {
        if (!tsfun_1.isObject(literature))
            return false;
        for (const fieldName in literature) {
            if (!VALID_FIELDS.includes(fieldName))
                return false;
        }
        if (!tsfun_1.isString(literature.quotation))
            return false;
        if (literature.zenonId && !tsfun_1.isString(literature.zenonId))
            return false;
        if (literature.doi && !tsfun_1.isString(literature.doi))
            return false;
        if (literature.page && !tsfun_1.isString(literature.page))
            return false;
        if (literature.figure && !tsfun_1.isString(literature.figure))
            return false;
        return true;
    }
    Literature.isLiterature = isLiterature;
    function isValid(literature, options) {
        return literature.quotation !== undefined && literature.quotation.length > 0;
    }
    Literature.isValid = isValid;
    function generateLabel(literature, getTranslation, includeZenonId = true, includeDoi = true) {
        if (isValid(literature)) {
            let additionalInformation = [];
            if (includeZenonId && literature.zenonId) {
                additionalInformation.push(getTranslation('zenonId') + ': ' + literature.zenonId);
            }
            if (includeDoi && literature.doi) {
                additionalInformation.push(getTranslation('doi') + ': ' + literature.doi);
            }
            if (literature.page) {
                additionalInformation.push(getTranslation('page') + ' ' + literature.page);
            }
            if (literature.figure) {
                additionalInformation.push(getTranslation('figure') + ' ' + literature.figure);
            }
            return literature.quotation + (additionalInformation.length > 0
                ? ' (' + additionalInformation.join(', ') + ')'
                : '');
        }
        else {
            return JSON.stringify(literature);
        }
    }
    Literature.generateLabel = generateLabel;
})(Literature = exports.Literature || (exports.Literature = {}));
//# sourceMappingURL=literature.js.map