import { Map } from 'tsfun';
import { Datastore } from '../datastore/datastore';
import { Document } from './document';
import { Name } from '../tools/named';
import { Labels, ProjectConfiguration } from '../services';
export interface NewResource {
    id?: string;
    identifier: string;
    category: string;
    relations: Resource.Relations;
    [propName: string]: any;
}
export interface Resource extends NewResource {
    id: Resource.Id;
}
/**
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
export declare module Resource {
    type Id = string;
    interface Relations {
        [propName: string]: string[];
    }
    const ID = "id";
    const CATEGORY = "category";
    const IDENTIFIER = "identifier";
    const RELATIONS = "relations";
    const CONSTANT_FIELDS: string[];
    function getDifferingFields(resource1: Resource, resource2: Resource): string[];
    function getDifferingRelations(resource1: Resource, resource2: Resource): Name[];
    function hasRelations(resource: Resource, relation: Name): boolean;
    function hasRelationTarget(resource: Resource, relation: Name, target: Id): boolean;
    function getRelationTargets(resource: Resource, allowedRelations?: Array<Name>): Array<Id>;
    function getRelationTargetDocuments(resource: Resource, datastore: Datastore): Promise<Map<Array<Document>>>;
    function removeEmptyRelations(resource: Resource): void;
    const relationsEquivalent: (r1: Resource) => (r2: Resource) => boolean;
    const getShortDescriptionLabel: (resource: Resource, labels: Labels, projectConfiguration: ProjectConfiguration) => string;
}
