"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Labels = void 0;
const tsfun_1 = require("tsfun");
const i18n_1 = require("../tools/i18n");
const valuelist_1 = require("../model/configuration/valuelist");
const category_form_1 = require("../model/configuration/category-form");
const sort_util_1 = require("../tools/sort-util");
/**
 * @author Daniel de Oliveira
 */
class Labels {
    constructor(getLanguages, projectConfiguration) {
        this.getLanguages = getLanguages;
        this.projectConfiguration = projectConfiguration;
        this.sortAlphanumerically = (valuelist) => (valueA, valueB) => {
            return sort_util_1.SortUtil.alnumCompare(this.getValueLabel(valuelist, valueA).toLowerCase(), this.getValueLabel(valuelist, valueB).toLowerCase());
        };
    }
    get(labeledValue) {
        return i18n_1.I18N.getLabel(labeledValue, this.getLanguages());
    }
    getFromI18NString(i18nString) {
        var _a;
        if (tsfun_1.isString(i18nString))
            return i18nString;
        if (!i18n_1.I18N.isI18NString(i18nString))
            return undefined;
        const fallbackValue = i18nString && Object.keys(i18nString).length > 0
            ? (_a = i18nString[i18n_1.I18N.UNSPECIFIED_LANGUAGE]) !== null && _a !== void 0 ? _a : i18nString[Object.keys(i18nString)[0]]
            : undefined;
        return this.get({ label: i18nString, name: fallbackValue });
    }
    getValueLabel(valuelist, valueId) {
        const label = valuelist_1.Valuelist.getValueLabel(valuelist, valueId);
        const translation = i18n_1.I18N.getTranslation(label, this.getLanguages());
        return translation !== null && translation !== void 0 ? translation : valueId;
    }
    getLabelAndDescription(labeledValue) {
        return i18n_1.I18N.getLabelAndDescription(labeledValue, this.getLanguages());
    }
    getDescription(describedValue) {
        return i18n_1.I18N.getDescription(describedValue, this.getLanguages());
    }
    getFieldLabel(category, fieldName) {
        const field = category_form_1.CategoryForm.getField(category, fieldName);
        if (!field)
            return undefined;
        return i18n_1.I18N.getLabel(field, this.getLanguages());
    }
    getRelationLabel(relationName) {
        const relation = this.projectConfiguration.getRelations().find(relation => {
            return relation.name === relationName;
        });
        if (!relation)
            return undefined;
        return i18n_1.I18N.getLabel(relation, this.getLanguages());
    }
    orderKeysByLabels(valuelist) {
        return valuelist_1.Valuelist.orderKeysByLabels(valuelist, this.sortAlphanumerically);
    }
}
exports.Labels = Labels;
//# sourceMappingURL=labels.js.map