import { Map } from 'tsfun';
import { Forest, Name } from '../tools';
import { Category } from '../model/configuration/category';
import { CategoryForm } from '../model/configuration/category-form';
import { Relation } from '../model/configuration/relation';
import { Field } from '../model/configuration/field';
import { Document } from '../model/document';
import { Valuelist } from '../model';
export interface RawProjectConfiguration {
    forms: Forest<CategoryForm>;
    categories: Map<Category>;
    relations: Array<Relation>;
    commonFields: Map<Field>;
    valuelists: Map<Valuelist>;
    projectLanguages: string[];
}
/**
 * For naming of document types (for example "ConcreteField"-XYZ, "Image"-XYZ)
 * see document.ts
 *
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 * @author Sebastian Cuy
 * @author F.Z.
 */
export declare class ProjectConfiguration {
    private categoryForms;
    private relations;
    private projectLanguages;
    private categoriesMap;
    private regularCategories;
    private fieldCategories;
    private overviewCategories;
    private concreteOverviewCategories;
    private overviewSupercategories;
    private typeManagementCategories;
    private typeManagementSupercategories;
    private typeCategories;
    private categoriesWithSubcategories;
    constructor(rawConfiguration: RawProjectConfiguration);
    update(newProjectConfiguration: ProjectConfiguration): void;
    getProjectLanguages(): string[];
    /**
     * @return Category, including children field
     */
    getCategory(category: Name): CategoryForm | undefined;
    getCategory(document: Document): CategoryForm | undefined;
    getCategories(...selectedTopLevelCategories: Array<Name>): Forest<CategoryForm>;
    getHierarchyParentCategories(categoryName: string): Array<CategoryForm>;
    isSubcategory(category: Name, superCategoryName: string): boolean;
    isGeometryCategory(category: Name): boolean;
    getRegularCategories(): Array<CategoryForm>;
    getFieldCategories(): Array<CategoryForm>;
    getOverviewCategories(): Array<CategoryForm>;
    getConcreteOverviewCategories(): Array<CategoryForm>;
    getOverviewSupercategories(): Array<CategoryForm>;
    getTypeManagementCategories(): Array<CategoryForm>;
    getTypeManagementSupercategories(): Array<CategoryForm>;
    getTypeCategories(): Array<CategoryForm>;
    getCategoryWithSubcategories(categoryName: string): Array<CategoryForm>;
    getInventoryCategories(): Array<CategoryForm>;
    getInventorySupercategories(): Array<CategoryForm>;
    getImageCategories(): Array<CategoryForm>;
    getFeatureCategories(): Array<CategoryForm>;
    getOperationCategories(): Array<CategoryForm>;
    getQrCodeCategories(): Array<CategoryForm>;
    getRelations(): Array<Relation>;
    getRelationsForDomainCategory(categoryName: string): Array<Relation>;
    getRelationsForRangeCategory(categoryName: string): Array<Relation>;
    isAllowedRelationDomainCategory(domainCategory: Name, rangeCategory: Name, relation: Name): boolean;
    getAllowedRelationDomainCategories(relationName: string, rangeCategoryName: string): Array<CategoryForm>;
    getAllowedRelationRangeCategories(relationName: string, domainCategoryName: string): Array<CategoryForm>;
    private createCategoriesMap;
    private updateFilteredCategories;
    private filterRegularCategories;
    private filterFieldCategories;
    private filterOverviewCategories;
    private filterConcreteOverviewCategories;
    private filterOverviewSupercategories;
    private filterTypeManagementCategories;
    private filterTypeManagementSupercategories;
    private filterTypeCategories;
    private filterCategoriesWithSubcategories;
    private filterCategoryWithSubcategories;
}
