"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hierarchy = void 0;
const tsfun_1 = require("tsfun");
const basic_index_configuration_1 = require("../../basic-index-configuration");
const relation_1 = require("../../model/configuration/relation");
const document_1 = require("../../model/document");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
var Hierarchy;
(function (Hierarchy) {
    function getWithDescendants(find, documents) {
        return __awaiter(this, void 0, void 0, function* () {
            const documentsIds = documents.map(document_1.toResourceId);
            const descendants = [];
            for (let document of documents) {
                const docs = (yield find(basic_index_configuration_1.childrenOf(document.resource.id))).documents
                    .filter(doc => !documentsIds.includes(doc.resource.id));
                descendants.push(...docs);
            }
            const descendantsSet = tsfun_1.set(tsfun_1.on(['resource', 'id']), descendants); // documents may themselves appear as descendants in multiselect
            return descendantsSet.concat(documents);
        });
    }
    Hierarchy.getWithDescendants = getWithDescendants;
    // TODO review if our datastore can do this, too, via constraintIndex
    function getAntescendents(get, id) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const document = yield get(id);
                return [document].concat(yield _getAntecendents(get, document));
            }
            catch (_a) {
                console.error('error in Hierarchy.getAntescendents()');
                return [];
            }
        });
    }
    Hierarchy.getAntescendents = getAntescendents;
    function getParentDocument(get, document) {
        return __awaiter(this, void 0, void 0, function* () {
            return getParent(get, document.resource);
        });
    }
    Hierarchy.getParentDocument = getParentDocument;
    function getParentResource(get, resource) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            return (_a = (yield getParent(get, resource))) === null || _a === void 0 ? void 0 : _a.resource;
        });
    }
    Hierarchy.getParentResource = getParentResource;
    function getParent(get, resource) {
        return __awaiter(this, void 0, void 0, function* () {
            return resource.relations['liesWithin'] && resource.relations['liesWithin'].length > 0
                ? (yield get(resource.relations.liesWithin[0]))
                : resource.relations['isRecordedIn'] && resource.relations['isRecordedIn'].length > 0
                    ? (yield get(resource.relations.isRecordedIn[0]))
                    : undefined;
        });
    }
    function _getAntecendents(get, document) {
        return __awaiter(this, void 0, void 0, function* () {
            const documents = [];
            let current = document;
            while (document_1.Document.hasRelations(current, relation_1.Relation.Hierarchy.LIESWITHIN)
                || document_1.Document.hasRelations(current, relation_1.Relation.Hierarchy.RECORDEDIN)) {
                const parent = yield get(document_1.Document.hasRelations(current, relation_1.Relation.Hierarchy.LIESWITHIN)
                    ? current.resource.relations[relation_1.Relation.Hierarchy.LIESWITHIN][0]
                    : current.resource.relations[relation_1.Relation.Hierarchy.RECORDEDIN][0]);
                documents.push(parent);
                current = parent;
            }
            return documents;
        });
    }
})(Hierarchy = exports.Hierarchy || (exports.Hierarchy = {}));
//# sourceMappingURL=hierarchy.js.map