import { Map } from 'tsfun';
import { ProjectConfiguration } from '../services/project-configuration';
import { Datastore } from '../datastore/datastore';
import { Document } from '../model/document';
import { BaseGroup } from '../model/configuration/group';
import { Resource } from '../model/resource';
import { Valuelist } from '../model/configuration/valuelist';
import { BaseField, Field, Subfield } from '../model/configuration/field';
import { Labels } from '../services';
export interface FieldsViewGroup extends BaseGroup {
    fields: Array<FieldsViewField>;
}
export interface FieldsViewField extends FieldsViewSubfield {
    value?: any;
    targets?: Array<Document>;
    subfields?: Array<FieldsViewSubfield>;
}
export interface FieldsViewSubfield {
    definition: BaseField;
    label: string;
    type: FieldsViewFieldType;
    valuelist?: Valuelist;
}
export declare type FieldsViewFieldType = 'default' | 'relation' | 'url' | 'composite';
export declare module FieldsViewGroup {
    const RELATIONS = "relations";
    const FIELDS = "fields";
}
/**
 * @author Thomas Kleinke
 * @author Sebastian Cuy
 * @author Daniel de Oliveira
 */
export declare module FieldsViewUtil {
    function getGroupsForResource(resource: Resource, projectConfiguration: ProjectConfiguration, datastore: Datastore, labels: Labels): Promise<Array<FieldsViewGroup>>;
    function getLabel(field: FieldsViewSubfield, fieldContent: any, labels: Labels, getTranslation: (key: string) => string, formatDecimal: (value: number) => string): any;
    function getObjectLabel(object: any, field: FieldsViewSubfield, getTranslation: (key: string) => string, formatDecimal: (value: number) => string, labels: Labels): string | null;
    function makeField(field: Field, fieldContent: any, resource: Resource, projectConfiguration: ProjectConfiguration, relationTargets: Map<Array<Document>>, labels: Labels, datastore: Datastore): Promise<FieldsViewField>;
    function makeSubfields(subfields: Array<Subfield>, labels: Labels): Array<FieldsViewSubfield>;
}
