"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FieldsViewUtil = exports.FieldsViewGroup = void 0;
const tsfun_1 = require("tsfun");
const dating_1 = require("../model/dating");
const dimension_1 = require("../model/dimension");
const literature_1 = require("../model/literature");
const optional_range_1 = require("../model/optional-range");
const resource_1 = require("../model/resource");
const category_form_1 = require("../model/configuration/category-form");
const field_1 = require("../model/configuration/field");
const named_1 = require("./named");
const services_1 = require("../services");
const model_1 = require("../model");
const string_utils_1 = require("./string-utils");
const valuelist_util_1 = require("./valuelist-util");
var FieldsViewGroup;
(function (FieldsViewGroup) {
    FieldsViewGroup.RELATIONS = 'relations';
    FieldsViewGroup.FIELDS = 'fields';
})(FieldsViewGroup = exports.FieldsViewGroup || (exports.FieldsViewGroup = {}));
/**
 * @author Thomas Kleinke
 * @author Sebastian Cuy
 * @author Daniel de Oliveira
 */
var FieldsViewUtil;
(function (FieldsViewUtil) {
    function getGroupsForResource(resource, projectConfiguration, datastore, labels) {
        return __awaiter(this, void 0, void 0, function* () {
            const relationTargets = yield resource_1.Resource.getRelationTargetDocuments(resource, datastore);
            yield addDerivedRelationTargetDocuments(relationTargets, projectConfiguration, resource, datastore);
            return createFieldsViewGroups(projectConfiguration.getCategory(resource.category).groups, resource, projectConfiguration, relationTargets, labels, datastore);
        });
    }
    FieldsViewUtil.getGroupsForResource = getGroupsForResource;
    function getLabel(field, fieldContent, labels, getTranslation, formatDecimal) {
        const entries = tsfun_1.isArray(fieldContent) ? fieldContent : [fieldContent];
        return entries.map(entry => {
            if (tsfun_1.isObject(entry)) {
                return FieldsViewUtil.getObjectLabel(entry, field, getTranslation, formatDecimal, labels);
            }
            else {
                return entry;
            }
        }).join(', ');
    }
    FieldsViewUtil.getLabel = getLabel;
    function getObjectLabel(object, field, getTranslation, formatDecimal, labels) {
        var _a, _b, _c, _d, _e, _f, _g;
        if (((_a = field === null || field === void 0 ? void 0 : field.definition) === null || _a === void 0 ? void 0 : _a.inputType) === field_1.Field.InputType.DATING) {
            return (_b = object.label) !== null && _b !== void 0 ? _b : dating_1.Dating.generateLabel(object, getTranslation, (value) => labels.getFromI18NString(value));
        }
        else if (((_c = field === null || field === void 0 ? void 0 : field.definition) === null || _c === void 0 ? void 0 : _c.inputType) === field_1.Field.InputType.DIMENSION && field.valuelist) {
            return (_d = object.label) !== null && _d !== void 0 ? _d : dimension_1.Dimension.generateLabel(object, formatDecimal, getTranslation, (value) => labels.getFromI18NString(value), labels.getValueLabel(field.valuelist, object.measurementPosition));
        }
        else if (((_e = field === null || field === void 0 ? void 0 : field.definition) === null || _e === void 0 ? void 0 : _e.inputType) === field_1.Field.InputType.LITERATURE) {
            return literature_1.Literature.generateLabel(object, getTranslation);
        }
        else if (((_f = field === null || field === void 0 ? void 0 : field.definition) === null || _f === void 0 ? void 0 : _f.inputType) === field_1.Field.InputType.DROPDOWNRANGE) {
            return optional_range_1.OptionalRange.generateLabel(object, getTranslation, (value) => labels.getValueLabel(field.valuelist, value));
        }
        else if (((_g = field === null || field === void 0 ? void 0 : field.definition) === null || _g === void 0 ? void 0 : _g.inputType) === field_1.Field.InputType.COMPOSITE) {
            return model_1.Composite.generateLabel(object, field.definition.subfields, getTranslation, (labeledValue) => labels.get(labeledValue), (value) => labels.getFromI18NString(value), (valuelist, valueId) => labels.getValueLabel(valuelist, valueId));
        }
        else {
            const result = labels.getFromI18NString(object);
            return result && tsfun_1.isString(result)
                ? string_utils_1.StringUtils.prepareStringForHTML(result)
                : JSON.stringify(object);
        }
    }
    FieldsViewUtil.getObjectLabel = getObjectLabel;
    function makeField(field, fieldContent, resource, projectConfiguration, relationTargets, labels, datastore) {
        return __awaiter(this, void 0, void 0, function* () {
            const valuelist = valuelist_util_1.ValuelistUtil.getValuelist(field, yield datastore.get('project'), projectConfiguration, yield services_1.Hierarchy.getParentResource(datastore.get, resource));
            switch (field.inputType) {
                case field_1.Field.InputType.RELATION:
                case field_1.Field.InputType.INSTANCE_OF:
                case field_1.Field.InputType.DERIVED_RELATION:
                    return {
                        definition: field,
                        label: labels.get(field),
                        type: 'relation',
                        targets: relationTargets[field.name]
                    };
                default:
                    return {
                        definition: field,
                        label: labels.get(field),
                        value: getFieldValue(fieldContent, field, valuelist, labels, projectConfiguration),
                        type: getFieldType(field.inputType),
                        valuelist,
                        subfields: makeSubfields(field.subfields, labels)
                    };
            }
        });
    }
    FieldsViewUtil.makeField = makeField;
    function makeSubfields(subfields, labels) {
        if (!subfields)
            return undefined;
        return subfields.map(subfield => {
            return {
                definition: subfield,
                label: labels.get(subfield),
                type: getFieldType(subfield.inputType),
            };
        });
    }
    FieldsViewUtil.makeSubfields = makeSubfields;
})(FieldsViewUtil = exports.FieldsViewUtil || (exports.FieldsViewUtil = {}));
function addDerivedRelationTargetDocuments(targetDocuments, projectConfiguration, resource, datastore) {
    return __awaiter(this, void 0, void 0, function* () {
        const category = projectConfiguration.getCategory(resource.category);
        const derivedRelationFields = category_form_1.CategoryForm.getFields(category)
            .filter(field => field.inputType === field_1.Field.InputType.DERIVED_RELATION);
        for (let field of derivedRelationFields) {
            const constraints = {};
            constraints[field.constraintName] = resource.id;
            targetDocuments[field.name] = (yield datastore.find({ constraints })).documents;
        }
    });
}
function getFieldValue(fieldContent, field, valuelist, labels, projectConfiguration) {
    if (tsfun_1.isArray(fieldContent)) {
        return getArrayFieldValue(fieldContent, field, valuelist, labels);
    }
    else {
        return field.name === resource_1.Resource.CATEGORY
            ? labels.get(projectConfiguration.getCategory(fieldContent))
            : getValue(fieldContent, labels, valuelist);
    }
}
function getArrayFieldValue(fieldContent, field, valuelist, labels) {
    const entries = field.inputType === field_1.Field.InputType.CHECKBOXES
        && fieldContent.every(entry => tsfun_1.isString(entry))
        ? getSortedValues(fieldContent, valuelist, labels)
        : fieldContent;
    return entries.map((entryContent) => field.subfields && tsfun_1.isObject(entryContent)
        ? getCompositeFieldValue(entryContent, labels, field.subfields)
        : getValue(entryContent, labels, valuelist));
}
function getSortedValues(values, valuelist, labels) {
    const order = labels.orderKeysByLabels(valuelist);
    return values.slice().sort((valueA, valueB) => {
        return order.indexOf(valueA) - order.indexOf(valueB);
    });
}
function getFieldType(inputType) {
    switch (inputType) {
        case field_1.Field.InputType.URL:
            return 'url';
        case field_1.Field.InputType.COMPOSITE:
            return 'composite';
        default:
            return 'default';
    }
}
function getValue(fieldContent, labels, valuelist) {
    return valuelist
        ? labels.getValueLabel(valuelist, fieldContent)
        : tsfun_1.isString(fieldContent)
            ? string_utils_1.StringUtils.prepareStringForHTML(fieldContent)
            : fieldContent;
}
function getCompositeFieldValue(fieldContent, labels, subfields) {
    return Object.keys(fieldContent).reduce((result, subfieldName) => {
        const subfield = subfields.find(tsfun_1.on(named_1.Named.NAME, tsfun_1.is(subfieldName)));
        const subfieldContent = fieldContent[subfieldName];
        result[subfieldName] = tsfun_1.isArray(subfieldContent)
            ? subfieldContent.map(element => getValue(element, labels, subfield === null || subfield === void 0 ? void 0 : subfield.valuelist))
            : getValue(subfieldContent, labels, subfield === null || subfield === void 0 ? void 0 : subfield.valuelist);
        return result;
    }, {});
}
function createFieldsViewGroups(groups, resource, projectConfiguration, relationTargets, labels, datastore) {
    return __awaiter(this, void 0, void 0, function* () {
        const result = [];
        for (let group of groups) {
            const fieldsViewGroup = yield createFieldsViewGroup(group, resource, projectConfiguration, relationTargets, labels, datastore);
            if (fieldsViewGroup.fields.length)
                result.push(fieldsViewGroup);
        }
        return result;
    });
}
function createFieldsViewGroup(group, resource, projectConfiguration, relationTargets, labels, datastore) {
    return __awaiter(this, void 0, void 0, function* () {
        const fields = [];
        for (let field of group.fields) {
            if (!field.visible)
                continue;
            const fieldContent = getFieldContent(resource, field.name);
            if ((fieldContent !== undefined && fieldContent !== '')
                || field.inputType === field_1.Field.InputType.DERIVED_RELATION) {
                fields.push(yield FieldsViewUtil.makeField(field, fieldContent, resource, projectConfiguration, relationTargets, labels, datastore));
            }
        }
        return {
            name: group.name,
            label: group.label,
            defaultLabel: group.defaultLabel,
            fields: fields.filter(field => field !== undefined && (!field.targets || field.targets.length > 0))
        };
    });
}
const getFieldContent = (resource, fieldName) => {
    var _a;
    return (_a = resource[fieldName]) !== null && _a !== void 0 ? _a : (resource.relations[fieldName] && resource.relations[fieldName].length > 0
        ? resource.relations[fieldName]
        : undefined);
};
//# sourceMappingURL=fields-view-util.js.map