import { Mapping, Predicate, Pair, Path, Comparator } from 'tsfun';
import * as tsfun from 'tsfun';
export declare type Tree<T = any> = {
    item: T;
    trees: Forest<T>;
};
export declare type Forest<T = any> = Array<Tree<T>>;
export declare type Node<ITEM, TREES> = Pair<ITEM, TREES>;
export declare type ArrayTree<T = any> = Node<T, ArrayForest<T>>;
export declare type ArrayForest<T = any> = Array<ArrayTree<T>>;
/**
 * A forest of general trees
 *
 * @author Daniel de Oliveira
 */
export declare namespace Forest {
    const wrap: <T>(items: T[]) => Forest<T>;
    function map<A, B>(f: Mapping<A, B>, t: Forest<A>): Forest<B>;
    function map<A, B>(f: Mapping<A, B>): Mapping<Forest<A>, Forest<B>>;
    function zip<T>(ts: Array<Forest<T>>): Forest<Array<T>>;
    function zip<T>(zipItems: (items: Array<T>) => T, ts: Array<Forest<T>>): Forest<T>;
    function build<T>(t: ArrayForest<T>): Forest<T>;
}
/**
 * A general tree
 *
 * @author Daniel de Oliveira
 */
export declare namespace Tree {
    const ITEM = "item";
    const TREES = "trees";
    const ITEMNAMEPATH: Path;
    const toItem: {
        (t: any[]): any;
        (t: tsfun.Map<any>): any;
    };
    const wrap: <T>(item: T) => Tree<T>;
    function map<A, B>(f: Mapping<A, B>, t: Tree<A>): Tree<B>;
    function map<A, B>(f: Mapping<A, B>): Mapping<Tree<A>, Tree<B>>;
    function access<T>(t: Forest<T> | Tree<T>, ...path: number[]): T;
    function mapTrees<T>(f: Mapping<Forest<T>>, t: Forest<T>): Forest<T>;
    function flatten<A>(t: Tree<A> | Forest<A>): Array<A>;
    function find<T>(t: Forest<T> | Tree<T>, match: T | Predicate<T>, comparator?: Comparator): Tree<T> | undefined;
    function build<T>([item, children]: ArrayTree<T>): Tree<T>;
}
