"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tree = exports.Forest = void 0;
const tsfun_1 = require("tsfun");
const tsfun = __importStar(require("tsfun"));
const named_1 = require("./named");
/**
 * A forest of general trees
 *
 * @author Daniel de Oliveira
 */
var Forest;
(function (Forest) {
    Forest.wrap = (items) => items.map(Tree.wrap);
    function map(...args) {
        const $ = (f) => (forest) => {
            const replacement = [];
            for (let { item: t, trees: tree } of forest) {
                replacement.push({ item: f(t), trees: map(f, tree) });
            }
            return replacement;
        };
        return args.length === 2
            ? $(args[0])(args[1])
            : $(args[0]);
    }
    Forest.map = map;
    function zip(...args) {
        const $ = (zipItems) => (ts) => tsfun.zip(ts).map((ns) => ({
            item: zipItems(ns.map(tsfun_1.to(Tree.ITEM))),
            trees: zip(zipItems, ns.map(tsfun_1.to(Tree.TREES)))
        }));
        return args.length > 1 && tsfun_1.isFunction(args[0])
            ? $(args[0])(args[1])
            : $(tsfun_1.identity)(args[0]);
    }
    Forest.zip = zip;
    function build(t) {
        return t.map(([t, trees]) => ({ item: t, trees: build(trees) }));
    }
    Forest.build = build;
})(Forest = exports.Forest || (exports.Forest = {}));
/**
 * A general tree
 *
 * @author Daniel de Oliveira
 */
var Tree;
(function (Tree) {
    Tree.ITEM = 'item';
    Tree.TREES = 'trees';
    Tree.ITEMNAMEPATH = [Tree.ITEM, named_1.Named.NAME];
    Tree.toItem = tsfun_1.to(Tree.ITEM);
    Tree.wrap = (item) => ({ item: item, trees: [] });
    function map(...args) {
        const $ = (f) => (tree) => {
            return {
                item: f(tree.item),
                trees: Forest.map(f, tree.trees)
            };
        };
        return args.length === 2
            ? $(args[0])(args[1])
            : $(args[0]);
    }
    Tree.map = map;
    function access(t, ...path) {
        function _accessTree(t, path) {
            const segment = tsfun_1.first(path);
            if (segment === undefined)
                return t.item;
            else if (tsfun_1.isNumber(segment))
                return _accessTree(t.trees[segment], tsfun_1.rest(path));
            return _accessForest(t.trees, path);
        }
        function _accessForest(t, path) {
            const segment = tsfun_1.first(path);
            if (!tsfun_1.isNumber(segment))
                return t[0];
            return _accessTree(t[segment], tsfun_1.rest(path));
        }
        return (tsfun_1.isObject(t)
            ? _accessTree
            : _accessForest)(t, path);
    }
    Tree.access = access;
    function mapTrees(f, t) {
        return f(t).map(({ item: t, trees: children }) => ({ item: t, trees: mapTrees(f, children) }));
    }
    Tree.mapTrees = mapTrees;
    function flatten(t) {
        const reduced = (tsfun_1.isArray(t) ? t : t.trees)
            .reduce((as, { item: a, trees: children }) => as.concat([a]).concat(flatten(children)), []);
        return (tsfun_1.isArray(t) ? [] : [t.item]).concat(reduced);
    }
    Tree.flatten = flatten;
    function find(t, match, comparator) {
        if (tsfun_1.isObject(t))
            return find([t], match, comparator);
        for (let node of t) {
            const { item: t, trees: trees } = node;
            const matches = buildMatches(match, comparator);
            if (matches(t))
                return node;
            const findResult = find(trees, match, comparator);
            if (findResult)
                return findResult;
        }
        return undefined;
    }
    Tree.find = find;
    function buildMatches(match, comparator) {
        return comparator !== undefined
            ? comparator(match)
            : tsfun_1.isFunction(match)
                ? match
                : tsfun_1.is(match);
    }
    function build([item, children]) {
        return {
            item: item,
            trees: children.map(([t, trees]) => ({ item: t, trees: Forest.build(trees) }))
        };
    }
    Tree.build = build;
})(Tree = exports.Tree || (exports.Tree = {}));
//# sourceMappingURL=forest.js.map