import { Map } from 'tsfun';
import { Named } from './named';
/**
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
export declare namespace I18N {
    type String = {
        [languageCode: string]: string;
    };
    interface Labeled {
        label?: String;
    }
    interface Described {
        description?: String;
    }
    interface LabeledValue extends Named, Labeled {
    }
    const UNSPECIFIED_LANGUAGE = "unspecifiedLanguage";
    function mergeI18nStrings(original: String | undefined, toAdd: String): String;
    function getLabel(labeledValue: LabeledValue, languages: string[]): string;
    function getDescription(labeledValue: Described, languages: string[]): string;
    function getLabelAndDescription(labeledValue: LabeledValue, languages: string[]): {
        label: string;
        description?: string;
    };
    /**
     * ```
     * >> getTranslations({ de: "Bla", en: "Blub" }, ["en"])
     * "Blub"
     * >> getTranslations({ en: "Blub" }, ["de"])
     * undefined
     * ```
     */
    function getTranslation(labels: String | string, languages: string[]): string | undefined;
    function removeEmpty(i18nString: I18N.String): I18N.String;
    function getFormattedContent(i18nString: I18N.String, languageLabels: Map<string>): string;
    function isI18NString(object: any): boolean;
}
