"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.I18N = void 0;
const tsfun_1 = require("tsfun");
/**
 * @author Thomas Kleinke
 * @author Daniel de Oliveira
 */
var I18N;
(function (I18N) {
    ;
    I18N.UNSPECIFIED_LANGUAGE = 'unspecifiedLanguage';
    function mergeI18nStrings(original, toAdd) {
        return Object.keys(toAdd).reduce((result, language) => {
            result[language] = toAdd[language];
            return result;
        }, tsfun_1.clone(original !== null && original !== void 0 ? original : {}));
    }
    I18N.mergeI18nStrings = mergeI18nStrings;
    function getLabel(labeledValue, languages) {
        var _a;
        return (_a = getTranslation(labeledValue.label, languages)) !== null && _a !== void 0 ? _a : labeledValue.name;
    }
    I18N.getLabel = getLabel;
    function getDescription(labeledValue, languages) {
        return getTranslation(labeledValue.description, languages);
    }
    I18N.getDescription = getDescription;
    function getLabelAndDescription(labeledValue, languages) {
        var _a;
        if (!labeledValue.label) {
            return {
                label: labeledValue.name,
                description: getTranslation(labeledValue['description'], languages)
            };
        }
        const language = getLanguage(labeledValue.label, languages);
        return language
            ? {
                label: labeledValue.label[language],
                description: (_a = labeledValue === null || labeledValue === void 0 ? void 0 : labeledValue['description']) === null || _a === void 0 ? void 0 : _a[language]
            }
            : {
                label: labeledValue.name,
                description: getTranslation(labeledValue['description'], languages)
            };
    }
    I18N.getLabelAndDescription = getLabelAndDescription;
    /**
     * ```
     * >> getTranslations({ de: "Bla", en: "Blub" }, ["en"])
     * "Blub"
     * >> getTranslations({ en: "Blub" }, ["de"])
     * undefined
     * ```
     */
    function getTranslation(labels, languages) {
        if (!labels)
            return undefined;
        if (tsfun_1.isString(labels))
            return labels;
        const language = getLanguage(labels, languages);
        return language ? labels[language] : undefined;
    }
    I18N.getTranslation = getTranslation;
    function removeEmpty(i18nString) {
        const result = tsfun_1.clone(i18nString);
        Object.keys(result).filter(key => result[key].length === 0)
            .forEach(key => delete result[key]);
        return result;
    }
    I18N.removeEmpty = removeEmpty;
    function getFormattedContent(i18nString, languageLabels) {
        return Object.keys(i18nString).reduce((result, language) => {
            if (result)
                result += ', ';
            result += languageLabels[language] + ': ' + i18nString[language];
            return result;
        }, '');
    }
    I18N.getFormattedContent = getFormattedContent;
    function isI18NString(object) {
        return tsfun_1.isObject(object) && Object.keys(object).every(key => {
            return tsfun_1.isString(object[key])
                && (key.length === 2 || key === I18N.UNSPECIFIED_LANGUAGE);
        });
    }
    I18N.isI18NString = isI18NString;
    function getLanguage(labels, languages) {
        return languages.find(languageCode => labels[languageCode]);
    }
})(I18N = exports.I18N || (exports.I18N = {}));
//# sourceMappingURL=i18n.js.map