"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InPlace = void 0;
const tsfun_1 = require("tsfun");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 *
 * In-place modifications of structs (nested arrays or objects, as per {} and [])
 */
var InPlace;
(function (InPlace) {
    function setOn(object, path_) {
        return (value) => _setOn(object, tsfun_1.isString(path_) || tsfun_1.isNumber(path_) ? [path_] : path_, value);
    }
    InPlace.setOn = setOn;
    function removeFrom(object, path_) {
        return _removeFrom(object, tsfun_1.isString(path_) || tsfun_1.isNumber(path_) ? [path_] : path_);
    }
    InPlace.removeFrom = removeFrom;
    /**
     * if o has not already a value at path, it sets it to alternative
     */
    function takeOrMake(o, path, alternative) {
        return setOn(o, path)(tsfun_1.to(path, alternative)(o));
    }
    InPlace.takeOrMake = takeOrMake;
    function moveInArray(array, originalIndex, targetIndex) {
        array.splice(targetIndex, 0, array.splice(originalIndex, 1)[0]);
    }
    InPlace.moveInArray = moveInArray;
    function _setOn(object, path, value) {
        const key = path[0];
        if (path.length === 1) {
            object[key] = value;
        }
        else {
            path.shift();
            if (!object[key]) {
                object[key] = tsfun_1.isString(key)
                    ? {}
                    : [];
            }
            _setOn(object[key], path, value);
        }
    }
    function _removeFrom(object, path, removeOnlyIfEmpty = false) {
        let currentObject = object;
        for (let i = 0; i < path.length - 1; i++) {
            currentObject = currentObject[path[i]];
            if (!currentObject)
                return;
        }
        const key = path[path.length - 1];
        if (!key)
            return;
        if (!removeOnlyIfEmpty || tsfun_1.isEmpty(currentObject[key])) {
            if (tsfun_1.isString(key)) {
                delete currentObject[key];
            }
            else {
                currentObject.splice(key, 1);
            }
            _removeFrom(object, tsfun_1.take(path.length - 1)(path), true);
        }
    }
})(InPlace = exports.InPlace || (exports.InPlace = {}));
//# sourceMappingURL=in-place.js.map