"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InvalidDataUtil = void 0;
const tsfun_1 = require("tsfun");
const string_utils_1 = require("./string-utils");
const field_1 = require("../model/configuration/field");
/**
 * @author Thomas Kleinke
 */
var InvalidDataUtil;
(function (InvalidDataUtil) {
    function isConvertible(fieldContent, inputType) {
        switch (inputType) {
            case field_1.Field.InputType.BOOLEAN:
                return ['true', 'false'].includes(fieldContent.toString().toLowerCase());
            case field_1.Field.InputType.CHECKBOXES:
                return tsfun_1.isString(fieldContent);
            case field_1.Field.InputType.DROPDOWN:
            case field_1.Field.InputType.RADIO:
                return tsfun_1.isArray(fieldContent) && fieldContent.length === 1 && tsfun_1.isString(fieldContent[0]);
            case field_1.Field.InputType.INPUT:
            case field_1.Field.InputType.SIMPLE_INPUT:
                return tsfun_1.isNumber(fieldContent);
            default:
                return false;
        }
    }
    InvalidDataUtil.isConvertible = isConvertible;
    function convert(fieldContent, inputType) {
        switch (inputType) {
            case field_1.Field.InputType.BOOLEAN:
                return fieldContent.toLowerCase() === 'true';
            case field_1.Field.InputType.CHECKBOXES:
                return [fieldContent];
            case field_1.Field.InputType.DROPDOWN:
            case field_1.Field.InputType.RADIO:
                return fieldContent[0];
            case field_1.Field.InputType.INPUT:
            case field_1.Field.InputType.SIMPLE_INPUT:
                return fieldContent.toString();
            default:
                return fieldContent;
        }
    }
    InvalidDataUtil.convert = convert;
    function generateLabel(data, labels) {
        const entries = tsfun_1.isArray(data) ? data : [data];
        return entries.map(entry => generateValueLabel(entry, labels))
            .filter(entry => entry === null || entry === void 0 ? void 0 : entry.length)
            .join('<hr>');
    }
    InvalidDataUtil.generateLabel = generateLabel;
    function generateValueLabel(value, labels) {
        if (value === undefined || value === null) {
            return '';
        }
        else if (tsfun_1.isArray(value)) {
            return generateArrayLabel(value, labels);
        }
        else if (tsfun_1.isObject(value)) {
            return generateObjectLabel(value, labels);
        }
        else {
            return value.toString();
        }
    }
    function generateArrayLabel(value, labels) {
        return value.map(valueEntry => generateValueLabel(valueEntry, labels)).join('/');
    }
    function generateObjectLabel(value, labels) {
        const label = labels.getFromI18NString(value);
        return label && tsfun_1.isString(label)
            ? string_utils_1.StringUtils.prepareStringForHTML(label)
            : Object.keys(value).map(key => {
                return key + ': ' + generateValueLabel(value[key], labels);
            }).join(', ');
    }
})(InvalidDataUtil = exports.InvalidDataUtil || (exports.InvalidDataUtil = {}));
//# sourceMappingURL=invalid-data-util.js.map