import { Map, Predicate } from 'tsfun';
export declare type Name = string;
export interface Named {
    name: Name;
}
/**
 * A common interface for Maps having the `name` property.
 * Provides utilities to work with (collections of) such structures.
 *
 * When extending Named, make sure `name` is a **unique** property
 * of your data structures
 * (see `arrayToMap`, where name will be repurposed as map key).
 *
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
export declare namespace Named {
    const NAME = "name";
    /**
     * as: [{ name: '17', e: 9 }, { name: '19', e: 7 }]
     * ->
     * { '17': { e: 9, name: '17' }, { '19': { e: 7, name: '19' }}}
     */
    function arrayToMap<A extends Named>(as: Array<A>): Map<A>;
    function mapToNamedArray<A extends Map<any>>(m: Map<A>): (Map<any> | Named)[];
    function sortArray(order: string[]): <A extends Map<any> | Named>(items: A[]) => A[];
    function byName(a: Named, b: Named): number;
    const onName: (p: Predicate) => Predicate<unknown>;
    const toName: (named: Named) => string;
}
