"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Named = void 0;
const tsfun_1 = require("tsfun");
const transformers_1 = require("./transformers");
const sort_struct_array_1 = require("./sort-struct-array");
const sort_util_1 = require("./sort-util");
/**
 * A common interface for Maps having the `name` property.
 * Provides utilities to work with (collections of) such structures.
 *
 * When extending Named, make sure `name` is a **unique** property
 * of your data structures
 * (see `arrayToMap`, where name will be repurposed as map key).
 *
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
var Named;
(function (Named) {
    Named.NAME = 'name';
    /**
     * as: [{ name: '17', e: 9 }, { name: '19', e: 7 }]
     * ->
     * { '17': { e: 9, name: '17' }, { '19': { e: 7, name: '19' }}}
     */
    function arrayToMap(as) {
        return transformers_1.makeLookup(Named.NAME, as);
    }
    Named.arrayToMap = arrayToMap;
    function mapToNamedArray(m) {
        return transformers_1.mapToArray(Named.NAME)(m);
    }
    Named.mapToNamedArray = mapToNamedArray;
    function sortArray(order) {
        return (items) => {
            return sort_struct_array_1.sortStructArray(order, Named.NAME)(items);
        };
    }
    Named.sortArray = sortArray;
    function byName(a, b) {
        return sort_util_1.SortUtil.alnumCompare(a.name, b.name);
    }
    Named.byName = byName;
    Named.onName = (p) => tsfun_1.on(Named.NAME, p);
    Named.toName = (named) => named.name;
})(Named = exports.Named || (exports.Named = {}));
//# sourceMappingURL=named.js.map