"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseDate = void 0;
function parseDate(dateString, latestPossibleDate = false) {
    try {
        const dateComponents = dateString.split('.');
        if (dateComponents.filter(component => !isNumber(component)).length > 0)
            return undefined;
        const date = parse(dateComponents, latestPossibleDate);
        return (date && isValid(date, dateComponents)) ? date : undefined;
    }
    catch (_) {
        return undefined;
    }
}
exports.parseDate = parseDate;
function parse(dateComponents, latestPossibleDate = false) {
    if (dateComponents.length === 1) {
        return new Date(parseInt(dateComponents[0]), latestPossibleDate ? 11 : 0, latestPossibleDate ? 31 : 1);
    }
    else if (dateComponents.length === 2) {
        return latestPossibleDate
            ? new Date(parseInt(dateComponents[1]), parseInt(dateComponents[0]), 0) : new Date(parseInt(dateComponents[1]), parseInt(dateComponents[0]) - 1, 1);
    }
    else if (dateComponents.length === 3) {
        return new Date(parseInt(dateComponents[2]), parseInt(dateComponents[1]) - 1, parseInt(dateComponents[0]));
    }
}
function isValid(date, dateComponents) {
    const normalizedDateComponents = dateComponents.map(dateComponent => {
        if (dateComponent.startsWith('0')) {
            return dateComponent.slice(1);
        }
        else {
            return dateComponent;
        }
    });
    if (normalizedDateComponents.length === 2) {
        return (date.getMonth() + 1).toString() === normalizedDateComponents[0];
    }
    else if (normalizedDateComponents.length === 3) {
        return (date.getMonth() + 1).toString() === normalizedDateComponents[1]
            && date.getDate().toString() === normalizedDateComponents[0];
    }
    else {
        return true;
    }
}
function isNumber(value) {
    return value.match(/^[0-9]*$/) !== null;
}
//# sourceMappingURL=parse-date.js.map