"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValuelistUtil = void 0;
const tsfun_1 = require("tsfun");
const optional_range_1 = require("../model/optional-range");
const model_1 = require("../model");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
var ValuelistUtil;
(function (ValuelistUtil) {
    function getValuesNotIncludedInValuelist(fieldContent, valuelist) {
        if (!fieldContent || !valuelist)
            return undefined;
        const valuesToCheck = tsfun_1.isArray(fieldContent)
            ? fieldContent.map(entry => { var _a; return (_a = entry === null || entry === void 0 ? void 0 : entry[model_1.Dimension.MEASUREMENTPOSITION]) !== null && _a !== void 0 ? _a : entry; })
                .filter(entry => tsfun_1.isString(entry))
            : fieldContent[optional_range_1.OptionalRange.VALUE]
                ? [fieldContent[optional_range_1.OptionalRange.VALUE], fieldContent[optional_range_1.OptionalRange.ENDVALUE]]
                : [fieldContent];
        const itemsNotIncludedInValuelist = valuesToCheck
            .filter(tsfun_1.isDefined)
            .filter(value => value.length)
            .filter(tsfun_1.isNot(tsfun_1.includedIn(Object.keys(valuelist.values))));
        return itemsNotIncludedInValuelist.length > 0 ? itemsNotIncludedInValuelist : undefined;
    }
    ValuelistUtil.getValuesNotIncludedInValuelist = getValuesNotIncludedInValuelist;
    function getValuelist(field, projectDocument, projectConfiguration, parentResource) {
        const valuelist = field.valuelist
            ? field.valuelist
            : field.valuelistFromProjectField
                ? getValuelistFromProjectField(field.valuelistFromProjectField, projectDocument)
                : undefined;
        if (!valuelist)
            return undefined;
        const parentCategory = parentResource ?
            projectConfiguration.getCategory(parentResource.category)
            : undefined;
        return field.allowOnlyValuesOfParent && parentResource
            && model_1.CategoryForm.getFields(parentCategory).find(parentField => parentField.name === field.name)
            ? getValuesOfParentField(valuelist, field.name, parentResource)
            : valuelist;
    }
    ValuelistUtil.getValuelist = getValuelist;
    function getValuelistFromProjectField(fieldName, projectDocument) {
        const id = 'project-' + fieldName;
        const field = projectDocument.resource[fieldName];
        return field && tsfun_1.isArray(field)
            ? {
                values: field.reduce((values, fieldName) => {
                    values[fieldName] = {};
                    return values;
                }, {}), id: id
            }
            : { values: {}, id: id };
    }
    ValuelistUtil.getValuelistFromProjectField = getValuelistFromProjectField;
    function getValuesOfParentField(valuelist, fieldName, parentResource) {
        var _a;
        const parentValues = (_a = parentResource[fieldName]) !== null && _a !== void 0 ? _a : [];
        return {
            id: valuelist.id,
            values: tsfun_1.filter((_, key) => {
                return parentValues.includes(key);
            })(valuelist.values)
        };
    }
})(ValuelistUtil = exports.ValuelistUtil || (exports.ValuelistUtil = {}));
//# sourceMappingURL=valuelist-util.js.map