"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assertions_1 = require("../../../src/configuration/boot/assertions");
const configuration_errors_1 = require("../../../src/configuration/boot/configuration-errors");
const field_1 = require("../../../src/model/configuration/field");
describe('Assertions', () => {
    it('cannot overwrite valuelist of common fields where valuelistFromProjectField is set', () => {
        const commonFields = {
            aCommon: {
                inputType: field_1.Field.InputType.CHECKBOXES,
                valuelistFromProjectField: 'abc'
            }
        };
        const builtInCategories = {
            C: {
                fields: {},
                minimalForm: { groups: [] }
            }
        };
        const libraryForms = {
            'C:default': {
                categoryName: 'C',
                valuelists: {
                    aCommon: 'cde' // not allowed
                },
                groups: [],
                description: {},
                createdBy: '',
                creationDate: ''
            },
        };
        const customForms = {
            C: { fields: {} }
        };
        try {
            assertions_1.Assertions.performAssertions(builtInCategories, {}, libraryForms, commonFields, {}, customForms);
            fail();
        }
        catch (expected) {
            expect(expected).toEqual([
                configuration_errors_1.ConfigurationErrors.COMMON_FIELD_VALUELIST_FROM_PROJECTDOC_NOT_TO_BE_OVERWRITTEN,
                'C:default', 'aCommon'
            ]);
        }
    });
    it('assert input types are set in built-in category fields', () => {
        const builtInCategories = {
            C: {
                fields: {
                    field1: {}
                },
                minimalForm: { groups: [] }
            }
        };
        const customForms = {
            C: { fields: {} }
        };
        try {
            assertions_1.Assertions.performAssertions(builtInCategories, {}, {}, {}, {}, customForms);
            fail();
        }
        catch (expected) {
            expect(expected).toEqual([[
                    configuration_errors_1.ConfigurationErrors.MISSING_FIELD_PROPERTY,
                    'inputType', 'C', 'field1'
                ]]);
        }
    });
    it('assert input types are set in library category fields', () => {
        const builtInCategories = {
            C: {
                fields: {
                    field1: {
                        inputType: 'text'
                    }
                },
                minimalForm: { groups: [] }
            }
        };
        const libraryCategories = {
            C: {
                description: {},
                fields: {
                    field2: {}
                }
            }
        };
        const customForms = {
            C: { fields: {} }
        };
        try {
            assertions_1.Assertions.performAssertions(builtInCategories, libraryCategories, {}, {}, {}, customForms);
            fail();
        }
        catch (expected) {
            expect(expected).toEqual([[
                    configuration_errors_1.ConfigurationErrors.MISSING_FIELD_PROPERTY,
                    'inputType', 'C', 'field2'
                ]]);
        }
    });
    it('allow missing input types in custom form fields', () => {
        const builtInCategories = {
            C: {
                fields: {
                    field1: {
                        inputType: 'text'
                    }
                },
                minimalForm: { groups: [] }
            }
        };
        const customForms = {
            C: {
                fields: {
                    field1: { constraintIndexed: true }
                }
            }
        };
        try {
            assertions_1.Assertions.performAssertions(builtInCategories, {}, {}, {}, {}, customForms);
        }
        catch (err) {
            fail(err);
        }
    });
    it('assert no duplication in selection', () => {
        const forms = {
            'C:default': {
                name: 'C:default',
                categoryName: 'C',
                valuelists: {},
                fields: {},
                groups: [],
                description: {},
                createdBy: '',
                creationDate: ''
            },
            'C:other': {
                name: 'C:other',
                categoryName: 'C',
                valuelists: {},
                fields: {},
                groups: [],
                description: {},
                createdBy: '',
                creationDate: ''
            },
        };
        const customForms = {
            'C:default': { fields: {} },
            'C:other': { fields: {} }
        };
        try {
            assertions_1.Assertions.assertNoDuplicationInSelection(customForms)(forms);
            fail();
        }
        catch (expected) {
            expect(expected).toEqual([[configuration_errors_1.ConfigurationErrors.DUPLICATION_IN_SELECTION, 'C']]);
        }
    });
});
//# sourceMappingURL=assertions.spec.js.map