"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const boot_1 = require("../../../src/configuration/boot");
const group_1 = require("../../../src/model/configuration/group");
const tools_1 = require("../../../src/tools");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
describe('ConfigLoader', () => {
    let configLoader;
    let configReader;
    function applyConfig(libraryCategories = {}, libraryForms = {}, languageConfiguration = {}) {
        configReader.read.and.returnValues(libraryCategories, libraryForms, {}, languageConfiguration, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {});
        configReader.exists.and.returnValue(true);
        configReader.getValuelistsLanguages.and.returnValue({});
    }
    function getConfigurationDocument(customForms = {}, customLanguageConfiguration = {}) {
        return {
            resource: {
                forms: customForms,
                languages: { de: customLanguageConfiguration },
                order: [],
                valuelists: {}
            }
        };
    }
    beforeEach(() => {
        configReader = jasmine.createSpyObj('configReader', ['read', 'exists', 'getValuelistsLanguages']);
        applyConfig();
        configLoader = new boot_1.ConfigLoader(configReader);
    });
    it('mix in common fields', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            A: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            }
        };
        const libraryCategories = {
            B: {
                parent: 'A',
                fields: {},
                description: {},
                minimalForm: {
                    groups: [{ name: group_1.Groups.STEM, fields: ['processor'] }]
                }
            },
        };
        const customForms = {
            A: {
                fields: {}
            },
            B: {
                fields: {}
            }
        };
        applyConfig(libraryCategories);
        let pconf;
        try {
            pconf = yield configLoader.go({ processor: { inputType: 'input' } }, builtInCategories, [], {}, getConfigurationDocument(customForms));
        }
        catch (err) {
            fail(err);
        }
        expect(pconf.getCategory('B').groups[0].fields[0]['name']).toBe('processor');
        done();
    }));
    it('translate common fields', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            A: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            }
        };
        const libraryCategories = {
            B: {
                parent: 'A',
                fields: {},
                description: {},
                minimalForm: {
                    groups: [{ name: group_1.Groups.STEM, fields: ['processor'] }]
                }
            },
        };
        const customForms = {
            A: {
                fields: {}
            },
            B: {
                fields: {}
            }
        };
        applyConfig(libraryCategories, {}, {
            commons: {
                processor: { label: 'Bearbeiter/Bearbeiterin', description: 'abc' }
            },
            categories: {},
            relations: {}
        });
        let pconf;
        try {
            pconf = yield configLoader.go({ processor: { inputType: 'input' } }, builtInCategories, [], {}, getConfigurationDocument(customForms));
        }
        catch (err) {
            console.log('err', err);
            fail(err);
        }
        expect(pconf.getCategory('B').groups[0].fields[0].label.de).toBe('Bearbeiter/Bearbeiterin');
        expect(pconf.getCategory('B').groups[0].fields[0].description.de).toBe('abc');
        done();
    }));
    it('mix existing externally configured with internal inherits relation', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            A: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                supercategory: true,
                userDefinedSubcategoriesAllowed: true
            },
            B: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                supercategory: true,
                userDefinedSubcategoriesAllowed: true
            },
            C: {
                fields: {},
                minimalForm: {
                    groups: []
                },
            },
            D: {
                fields: {},
                minimalForm: {
                    groups: []
                }
            }
        };
        const libraryCategories = {
            'A1': { parent: 'A', fields: {}, description: {} },
            'A2': { parent: 'A', fields: {}, description: {} },
            'B1': { parent: 'B', fields: {}, description: {} },
            'B2': { parent: 'B', fields: {}, description: {} }
        };
        const customForms = {
            'A1': { fields: {} },
            'A2': { fields: {} },
            'B1': { fields: {} },
            'B2': { fields: {} },
            'A': { fields: {} },
            'B': { fields: {} },
            'C': { fields: {} },
            'D': { fields: {} }
        };
        applyConfig(libraryCategories);
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [
                {
                    name: 'connection',
                    domain: ['C'],
                    range: ['D'],
                    editable: false,
                    inputType: 'relation'
                }, {
                    name: 'connection',
                    domain: ['A:inherit'],
                    range: ['B:inherit'],
                    editable: false,
                    inputType: 'relation'
                }
            ], {}, getConfigurationDocument(customForms));
        }
        catch (err) {
            fail(err);
        }
        expect(pconf.getRelationsForDomainCategory('A')[0].range).toContain('B1');
        expect(pconf.getRelationsForDomainCategory('A1')[0].range).toContain('B');
        expect(pconf.getRelationsForDomainCategory('A2')[0].range).toContain('B2');
        expect(pconf.getRelationsForDomainCategory('C')[0].range).toContain('D');
        done();
    }));
    // TODO Adjust title / check if this test is still necessary
    it('preprocess - convert sameOperation to sameMainCategoryResource', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            T: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                supercategory: true,
                userDefinedSubcategoriesAllowed: true
            },
            A: {
                parent: 'T',
                fields: {},
                minimalForm: {
                    groups: []
                }
            },
            B: {
                parent: 'T',
                fields: {},
                minimalForm: {
                    groups: []
                }
            }
        };
        const customForms = {
            A: { fields: {} },
            B: { fields: {} },
            T: { fields: {} }
        };
        applyConfig();
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [{
                    name: 'abc',
                    domain: ['A'],
                    range: ['B'],
                    sameMainCategoryResource: false,
                    editable: false,
                    inputType: 'relation'
                }], {}, getConfigurationDocument(customForms, {}));
        }
        catch (err) {
            fail(err);
        }
        expect(pconf.getRelationsForDomainCategory('A')[0].sameMainCategoryResource).toBe(false);
        done();
    }));
    it('preprocess - apply language confs', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            Parent: {
                fields: {},
                minimalForm: { groups: [] },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            },
            A: { parent: 'Parent', fields: {}, minimalForm: { groups: [] } },
            B: { parent: 'Parent', fields: {}, minimalForm: { groups: [] } },
            C: { parent: 'Parent', fields: {}, minimalForm: { groups: [] } }
        };
        const customForms = {
            A: { fields: {} },
            B: { fields: {} },
            C: { fields: {} },
            Parent: { fields: {} }
        };
        applyConfig({}, {}, {
            categories: {
                A: { label: 'A_' },
                B: { label: 'B_' }
            },
            relations: {
                r1: { label: 'r1_' }
            }
        });
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [
                { name: 'r1', domain: ['A'], range: ['B'], editable: false, inputType: 'relation' },
                { name: 'r2', domain: ['A'], range: ['B'], editable: false, inputType: 'relation' }
            ], {}, getConfigurationDocument(customForms, {
                categories: {
                    B: { label: 'B__' }
                }
            }));
        }
        catch (err) {
            fail(err);
        }
        expect(pconf.getCategory('A').label.de).toEqual('A_');
        expect(pconf.getCategory('B').label.de).toEqual('B__');
        expect(pconf.getCategory('C').label).toEqual({});
        expect(pconf.getRelationsForDomainCategory('A')[1].label.de).toEqual('r1_');
        expect(pconf.getRelationsForDomainCategory('A')[0].label).toEqual({});
        done();
    }));
    it('preprocess - apply custom fields configuration', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            F: {
                fields: {
                    fieldF1: { inputType: 'input' }
                },
                minimalForm: {
                    groups: [{ name: group_1.Groups.STEM, fields: ['fieldF1'] }]
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            },
            G: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            }
        };
        const libraryCategories = {
            A: {
                parent: 'F',
                fields: { fieldA1: { inputType: 'input' } },
                description: {}
            },
            B: {
                parent: 'G',
                fields: { fieldB1: { inputType: 'unsignedInt' } },
                description: {}
            }
        };
        const customForms = {
            A: {
                fields: {
                    fieldA1: { inputType: 'text' }
                },
                groups: [{ name: group_1.Groups.STEM, fields: ['fieldF1', 'fieldA1'] }]
            },
            B: {
                fields: { fieldB2: { inputType: 'boolean' } },
                groups: [{ name: group_1.Groups.STEM, fields: ['fieldB1', 'fieldB2'] }]
            },
            F: {
                fields: {
                    fieldF1: { inputType: 'url' }
                },
                groups: [{ name: group_1.Groups.STEM, fields: ['fieldF1'] }]
            },
            G: {
                fields: {},
                groups: []
            }
        };
        applyConfig(libraryCategories);
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [], {}, getConfigurationDocument(customForms));
            expect(pconf.getCategory('F').groups[0].fields.find(field => field.name == 'fieldF1')
                .inputType).toEqual('url');
            expect(pconf.getCategory('A').groups[0].fields.find(field => field.name == 'fieldF1')
                .inputType).toEqual('url');
            expect(pconf.getCategory('A').groups[0].fields.find(field => field.name == 'fieldA1')
                .inputType).toEqual('text');
            expect(pconf.getCategory('B').groups[0].fields.find(field => field.name == 'fieldB1')
                .inputType).toEqual('unsignedInt');
            expect(pconf.getCategory('B').groups[0].fields.find(field => field.name == 'fieldB2')
                .inputType).toEqual('boolean');
        }
        catch (err) {
            fail(err);
        }
        done();
    }));
    it('preprocess - apply custom fields configuration - add subcategories', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            Find: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            }
        };
        const libraryCategories = {
            Find: {
                fields: { fieldA1: { inputType: 'unsignedInt' } },
                minimalForm: {
                    groups: [
                        { name: group_1.Groups.STEM, fields: ['fieldA1'] }
                    ]
                },
                description: {}
            }
        };
        const customForms = {
            B: {
                parent: 'Find',
                fields: { fieldB1: { inputType: 'boolean' } },
                groups: [
                    { name: group_1.Groups.STEM, fields: ['fieldA1', 'fieldB1'] }
                ]
            },
            Find: {
                fields: {}
            }
        };
        applyConfig(libraryCategories, {}, {});
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [], {}, getConfigurationDocument(customForms));
            expect(tools_1.Named.arrayToMap(tools_1.Tree.flatten(pconf.getCategories()))['B']
                .groups[0].fields
                .find(field => field.name == 'fieldB1').inputType)
                .toEqual('boolean');
        }
        catch (err) {
            fail(err);
        }
        done();
    }));
    it('preprocess - apply custom fields configuration - add subcategories - parent not defined', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const customForms = {
            'B': {
                parent: 'Find',
                valuelists: {},
                fields: { fieldC1: { inputType: 'boolean' } },
                groups: [{ name: group_1.Groups.STEM, fields: ['fieldC1'] }]
            }
        };
        applyConfig();
        try {
            yield configLoader.go({}, {}, [], {}, getConfigurationDocument(customForms));
            fail();
        }
        catch (err) {
            expect(err).toEqual([boot_1.ConfigurationErrors.INVALID_CONFIG_PARENT_NOT_DEFINED, 'Find']);
        }
        done();
    }));
    it('preprocess - apply custom fields configuration - add subcategories - non extendable categories not allowed', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            Place: {
                fields: { fieldA1: { inputType: 'unsignedInt' } },
                minimalForm: {
                    groups: []
                }
            }
        };
        const customForms = {
            Extension: {
                parent: 'Place',
                valuelists: {},
                fields: { fieldC1: { inputType: 'boolean' } },
                groups: [{ name: group_1.Groups.STEM, fields: ['fieldC1'] }]
            }
        };
        applyConfig();
        try {
            yield configLoader.go({}, builtInCategories, [], {}, getConfigurationDocument(customForms));
            fail();
        }
        catch (err) {
            expect(err).toEqual([boot_1.ConfigurationErrors.TRYING_TO_SUBTYPE_A_NON_EXTENDABLE_CATEGORY, 'Place']);
        }
        done();
    }));
    it('apply groups configuration', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            Parent1: {
                fields: {
                    parent1Field: { inputType: 'input' }
                },
                minimalForm: {
                    groups: []
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            },
            Parent2: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            }
        };
        const libraryCategories = {
            Parent1: {
                fields: {
                    parent1Field: { inputType: 'input' }
                },
                description: {}
            },
            Parent2: {
                fields: {
                    parent2Field: { inputType: 'input' }
                },
                description: {}
            },
            B: {
                parent: 'Parent1',
                fields: {
                    fieldB2: { inputType: 'input' },
                    fieldB3: { inputType: 'input' },
                    fieldB1: { inputType: 'input' }
                },
                minimalForm: {
                    groups: [
                        { name: group_1.Groups.STEM, fields: ['fieldB1', 'fieldB2'] },
                        { name: group_1.Groups.PROPERTIES, fields: ['fieldB3'] }
                    ],
                },
                description: {}
            },
            C: {
                parent: 'Parent1',
                fields: {
                    fieldC1: { inputType: 'input' },
                    fieldC2: { inputType: 'input' }
                },
                description: {}
            },
            A: {
                parent: 'Parent1',
                fields: {
                    fieldA2: { inputType: 'input' },
                    fieldA1: { inputType: 'input' }
                },
                description: {}
            },
            D: {
                parent: 'Parent2',
                fields: {},
                description: {}
            }
        };
        const libraryForms = {
            'Parent1:default': {
                categoryName: 'Parent1',
                groups: [
                    { name: group_1.Groups.STEM, fields: ['parent1Field'] }
                ],
                valuelists: {},
                description: {},
                createdBy: '',
                creationDate: ''
            },
            'Parent2:default': {
                categoryName: 'Parent2',
                groups: [
                    { name: group_1.Groups.STEM, fields: ['parent2Field'] }
                ],
                valuelists: {},
                description: {},
                createdBy: '',
                creationDate: ''
            },
            'A:default': {
                categoryName: 'A',
                groups: [
                    { name: group_1.Groups.STEM, fields: ['fieldA1', 'fieldA2'] }
                ],
                valuelists: {},
                description: {},
                createdBy: '',
                creationDate: ''
            },
            'C:default': {
                categoryName: 'C',
                groups: [
                    { name: group_1.Groups.STEM, fields: ['fieldC1'] },
                    { name: group_1.Groups.PROPERTIES, fields: ['fieldC2'] }
                ],
                valuelists: {},
                description: {},
                createdBy: '',
                creationDate: ''
            }
        };
        const customForms = {
            'A:default': { fields: {} },
            B: { fields: {} },
            'C:default': { fields: {} },
            D: { fields: {} },
            Parent1: { fields: {} },
            'Parent2:default': { fields: {} }
        };
        applyConfig(libraryCategories, libraryForms);
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [], {}, getConfigurationDocument(customForms));
            const result = tools_1.Named.arrayToMap(tools_1.Tree.flatten(pconf.getCategories()));
            expect(result['A'].name).toEqual('A');
            expect(result['A'].groups[0].name).toBe(group_1.Groups.STEM);
            expect(result['A'].groups[0].fields.length).toBe(2);
            expect(result['A'].groups[0].fields[0].name).toEqual('fieldA1');
            expect(result['A'].groups[0].fields[1].name).toEqual('fieldA2');
            expect(result['B'].name).toEqual('B');
            expect(result['B'].groups[0].name).toBe(group_1.Groups.STEM);
            expect(result['B'].groups[0].fields.length).toBe(2);
            expect(result['B'].groups[0].fields[0].name).toEqual('fieldB1');
            expect(result['B'].groups[0].fields[1].name).toEqual('fieldB2');
            expect(result['B'].groups[1].name).toBe(group_1.Groups.PROPERTIES);
            expect(result['B'].groups[1].fields.length).toBe(1);
            expect(result['B'].groups[1].fields[0].name).toEqual('fieldB3');
            expect(result['C'].name).toEqual('C');
            expect(result['C'].groups[0].name).toBe(group_1.Groups.STEM);
            expect(result['C'].groups[0].fields.length).toBe(1);
            expect(result['C'].groups[0].fields[0].name).toEqual('fieldC1');
            expect(result['C'].groups[1].name).toBe(group_1.Groups.PROPERTIES);
            expect(result['C'].groups[1].fields.length).toBe(1);
            expect(result['C'].groups[1].fields[0].name).toEqual('fieldC2');
            expect(result['D'].name).toEqual('D');
            expect(result['D'].groups[0].name).toBe(group_1.Groups.STEM);
            expect(result['D'].groups[0].fields.length).toBe(1);
            expect(result['D'].groups[0].fields[0].name).toEqual('parent2Field');
        }
        catch (err) {
            fail(err);
        }
        done();
    }));
    it('add fields only once even if they are mentioned multiple times in groups configuration', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            Parent: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                supercategory: true,
                userDefinedSubcategoriesAllowed: true
            }
        };
        const libraryCategories = {
            A: {
                parent: 'Parent',
                fields: {
                    fieldA2: { inputType: 'input' },
                    fieldA1: { inputType: 'input' }
                },
                minimalForm: {
                    groups: [
                        { name: group_1.Groups.STEM, fields: ['fieldA1', 'fieldA2', 'fieldA1'] }
                    ]
                },
                description: {}
            }
        };
        const customForms = {
            A: { fields: {} },
            Parent: { fields: {} }
        };
        applyConfig(libraryCategories);
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [], {}, getConfigurationDocument(customForms));
            expect(tools_1.Tree.flatten(pconf.getCategories()).length).toBe(2);
            expect(pconf.getCategory('A').groups[0].fields.length).toBe(2);
            expect(pconf.getCategory('A').groups[0].fields[0].name).toEqual('fieldA1');
            expect(pconf.getCategory('A').groups[0].fields[1].name).toEqual('fieldA2');
        }
        catch (err) {
            fail(err);
        }
        done();
    }));
    it('apply hidden', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            A: {
                fields: {},
                minimalForm: {
                    groups: []
                }
            },
            B: {
                fields: {},
                minimalForm: {
                    groups: []
                }
            },
            C: {
                parent: 'A',
                fields: {},
                minimalForm: {
                    groups: []
                }
            }
        };
        const libraryCategories = {
            A: {
                fields: {
                    fieldA1: { inputType: 'input' },
                    fieldA2: { inputType: 'input' },
                    fieldA3: { inputType: 'input' }
                },
                minimalForm: {
                    groups: [{
                            name: group_1.Groups.STEM,
                            fields: ['fieldA1', 'fieldA2', 'fieldA3', 'relation1']
                        }]
                },
                description: {}
            }
        };
        const customForms = {
            A: {
                fields: {},
                hidden: ['fieldA1', 'fieldA2', 'relation1']
            },
            B: {
                fields: {}
            },
            C: {
                fields: {},
                hidden: ['fieldA3']
            }
        };
        applyConfig(libraryCategories);
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [{ name: 'relation1', domain: ['A:inherit'], range: ['B'], inputType: 'relation' }], {}, getConfigurationDocument(customForms));
            const resultA = pconf.getCategory('A').groups[0];
            expect(resultA.fields[0].name).toEqual('fieldA1');
            expect(resultA.fields[0].visible).toBe(false);
            expect(resultA.fields[0].editable).toBe(false);
            expect(resultA.fields[1].name).toEqual('fieldA2');
            expect(resultA.fields[1].visible).toBe(false);
            expect(resultA.fields[1].editable).toBe(false);
            expect(resultA.fields[2].name).toEqual('fieldA3');
            expect(resultA.fields[2].visible).toBe(true);
            expect(resultA.fields[2].editable).toBe(true);
            expect(resultA.fields[3].name).toEqual('relation1');
            expect(resultA.fields[3].visible).toBe(false);
            expect(resultA.fields[3].editable).toBe(false);
            const resultC = pconf.getCategory('C').groups[0];
            expect(resultC.fields[0].name).toEqual('fieldA1');
            expect(resultC.fields[0].visible).toBe(false);
            expect(resultC.fields[0].editable).toBe(false);
            expect(resultC.fields[1].name).toEqual('fieldA2');
            expect(resultC.fields[1].visible).toBe(false);
            expect(resultC.fields[1].editable).toBe(false);
            expect(resultC.fields[2].name).toEqual('fieldA3');
            expect(resultC.fields[2].visible).toBe(false);
            expect(resultC.fields[2].editable).toBe(false);
            expect(resultC.fields[3].name).toEqual('relation1');
            expect(resultC.fields[3].visible).toBe(false);
            expect(resultC.fields[3].editable).toBe(false);
        }
        catch (err) {
            fail(err);
        }
        done();
    }));
    it('set libraryId', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            A: {
                fields: {},
                minimalForm: {
                    groups: []
                },
                userDefinedSubcategoriesAllowed: true,
                supercategory: true
            },
            B: {
                fields: {},
                minimalForm: {
                    groups: []
                }
            }
        };
        const libraryForms = {
            'B:default': {
                categoryName: 'B',
                groups: [],
                valuelists: {},
                description: {},
                createdBy: '',
                creationDate: ''
            }
        };
        const customForms = {
            A: { fields: {} },
            'B:default': { fields: {} },
            C: { parent: 'A', fields: {} }
        };
        applyConfig({}, libraryForms);
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [], {}, getConfigurationDocument(customForms));
        }
        catch (err) {
            fail(err);
        }
        expect(pconf.getCategory('A').libraryId).toBe('A');
        expect(pconf.getCategory('B').libraryId).toBe('B:default');
        expect(pconf.getCategory('C').libraryId).toBe('C');
        done();
    }));
    it('include all relations', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const builtInCategories = {
            A: {
                fields: {},
                minimalForm: {
                    groups: [
                        { name: 'stem', fields: ['isSimilarTo'] }
                    ]
                },
                supercategory: true
            },
            B: {
                fields: {},
                minimalForm: {
                    groups: [
                        { name: 'stem', fields: ['isSameAs'] }
                    ]
                },
                supercategory: true
            }
        };
        const customForms = {
            'A': { fields: {} },
            'B': { fields: {} }
        };
        applyConfig();
        let pconf;
        try {
            pconf = yield configLoader.go({}, builtInCategories, [
                {
                    name: 'isRecordedIn',
                    domain: ['A'],
                    range: ['B'],
                    editable: false,
                    visible: false,
                    inputType: 'relation'
                },
                {
                    name: 'isSimilarTo',
                    domain: ['A'],
                    range: ['A'],
                    inputType: 'relation'
                },
                {
                    name: 'isSameAs',
                    domain: ['B'],
                    range: ['B'],
                    inputType: 'relation'
                }
            ], {}, getConfigurationDocument(customForms), true);
        }
        catch (err) {
            fail(err);
        }
        expect(pconf.getCategory('A').groups[0].fields.length).toBe(2);
        expect(pconf.getCategory('A').groups[0].fields[0].name).toEqual('isSimilarTo');
        expect(pconf.getCategory('A').groups[0].fields[1].name).toEqual('isRecordedIn');
        expect(pconf.getCategory('B').groups[0].fields.length).toBe(1);
        expect(pconf.getCategory('B').groups[0].fields[0].name).toEqual('isSameAs');
        done();
    }));
});
//# sourceMappingURL=config-loader.spec.js.map