"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get_available_forms_1 = require("../../../src/configuration/boot/get-available-forms");
/**
 * @author Thomas Kleinke
 */
describe('get available forms', () => {
    it('get available forms', () => {
        const builtInFields = {
            builtInField: {
                name: 'builtInField',
                inputType: 'boolean'
            }
        };
        const commonFields = {
            commonField: {
                name: 'builtInField',
                inputType: 'literature'
            }
        };
        const categories = {
            Category1: {
                fields: {
                    field1: {
                        inputType: 'input'
                    }
                },
                minimalForm: {
                    groups: [
                        {
                            name: 'group1',
                            fields: ['builtInField', 'isSameAs']
                        }
                    ]
                }
            },
            Category2: {
                parent: 'Category1',
                fields: {
                    field2: {
                        inputType: 'text'
                    }
                },
                minimalForm: {
                    groups: [
                        {
                            name: 'group1',
                            fields: ['commonField']
                        }
                    ]
                }
            },
            Category3: {
                parent: 'Category1',
                fields: {}
            }
        };
        const libraryForms = {
            'Category2:default': {
                categoryName: 'Category2',
                description: {},
                createdBy: 'Test user',
                creationDate: '07-07-2021',
                groups: [
                    {
                        name: 'group1',
                        fields: ['field1']
                    },
                    {
                        name: 'group2',
                        fields: ['field2']
                    }
                ]
            }
        };
        const relations = [
            {
                name: 'isSameAs',
                domain: [],
                range: [],
                inputType: 'relation'
            }
        ];
        const result = get_available_forms_1.getAvailableForms(categories, libraryForms, builtInFields, commonFields, relations, ['Category1', 'Category2', 'Category3']);
        expect(Object.keys(result).length).toBe(4);
        expect(result['Category1'].name).toBe('Category1');
        expect(result['Category1'].categoryName).toBe('Category1');
        expect(result['Category1'].groups.length).toBe(1);
        expect(result['Category1'].groups[0].name).toBe('group1');
        expect(result['Category1'].groups[0].fields).toEqual(['builtInField', 'isSameAs']);
        expect(Object.keys(result['Category1'].fields).length).toBe(1);
        expect(result['Category1'].fields['builtInField'].inputType).toBe('boolean');
        expect(result['Category2'].name).toBe('Category2');
        expect(result['Category2'].categoryName).toBe('Category2');
        expect(result['Category2'].groups.length).toBe(1);
        expect(result['Category2'].groups[0].name).toBe('group1');
        expect(result['Category2'].groups[0].fields).toEqual(['builtInField', 'isSameAs', 'commonField']);
        expect(Object.keys(result['Category2'].fields).length).toBe(2);
        expect(result['Category2'].fields['builtInField'].inputType).toBe('boolean');
        expect(result['Category2'].fields['commonField'].inputType).toBe('literature');
        expect(result['Category2:default'].name).toBe('Category2:default');
        expect(result['Category2:default'].categoryName).toBe('Category2');
        expect(result['Category2:default'].groups.length).toBe(2);
        expect(result['Category2:default'].groups[0].name).toBe('group1');
        expect(result['Category2:default'].groups[0].fields).toEqual(['builtInField', 'isSameAs', 'field1']);
        expect(result['Category2:default'].groups[1].name).toBe('group2');
        expect(result['Category2:default'].groups[1].fields).toEqual(['field2']);
        expect(Object.keys(result['Category2:default'].fields).length).toBe(4);
        expect(result['Category2:default'].fields['builtInField'].inputType).toBe('boolean');
        expect(result['Category2:default'].fields['commonField'].inputType).toBe('literature');
        expect(result['Category2:default'].fields['field1'].inputType).toBe('input');
        expect(result['Category2:default'].fields['field2'].inputType).toBe('text');
        expect(result['Category3'].name).toBe('Category3');
        expect(result['Category3'].categoryName).toBe('Category3');
        expect(result['Category3'].groups.length).toBe(1);
        expect(result['Category3'].groups[0].name).toBe('group1');
        expect(result['Category3'].groups[0].fields).toEqual(['builtInField', 'isSameAs']);
        expect(Object.keys(result['Category3'].fields).length).toBe(1);
        expect(result['Category1'].fields['builtInField'].inputType).toBe('boolean');
    });
    it('select correct form for parent category when merging groups', () => {
        const categories = {
            Category1: {
                fields: {
                    field1: { inputType: 'input' },
                    field2: { inputType: 'input' }
                },
                minimalForm: {
                    groups: [
                        {
                            name: 'group1',
                            fields: ['field1']
                        }
                    ]
                }
            },
            Category2: {
                parent: 'Category1',
                fields: {},
                minimalForm: {
                    groups: []
                }
            }
        };
        const libraryForms = {
            'Category1:default': {
                categoryName: 'Category1',
                description: {},
                createdBy: 'Test user',
                creationDate: '07-07-2021',
                groups: [
                    {
                        name: 'group1',
                        fields: ['field1', 'field2']
                    }
                ]
            }
        };
        const result = get_available_forms_1.getAvailableForms(categories, libraryForms, {}, {}, [], ['Category1:default', 'Category2']);
        expect(Object.keys(result).length).toBe(3);
        expect(result['Category1'].name).toBe('Category1');
        expect(result['Category1'].categoryName).toBe('Category1');
        expect(result['Category1'].groups.length).toBe(1);
        expect(result['Category1'].groups[0].name).toBe('group1');
        expect(result['Category1'].groups[0].fields).toEqual(['field1']);
        expect(result['Category1:default'].name).toBe('Category1:default');
        expect(result['Category1:default'].categoryName).toBe('Category1');
        expect(result['Category1:default'].groups.length).toBe(1);
        expect(result['Category1:default'].groups[0].name).toBe('group1');
        expect(result['Category1:default'].groups[0].fields).toEqual(['field1', 'field2']);
        expect(result['Category2'].name).toBe('Category2');
        expect(result['Category2'].categoryName).toBe('Category2');
        expect(result['Category2'].groups.length).toBe(1);
        expect(result['Category2'].groups[0].name).toBe('group1');
        expect(result['Category2'].groups[0].fields).toEqual(['field1', 'field2']);
    });
    it('Remove subcategory forms without selected parent forms', () => {
        const categories = {
            Category1: {
                fields: {},
                minimalForm: {
                    groups: []
                }
            },
            Category2: {
                parent: 'Category1',
                fields: {},
                minimalForm: {
                    groups: []
                }
            }
        };
        const result = get_available_forms_1.getAvailableForms(categories, {}, {}, {}, [], []);
        expect(Object.keys(result).length).toBe(1);
        expect(result['Category1'].name).toBe('Category1');
    });
});
//# sourceMappingURL=get-available-forms.spec.js.map