"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const make_category_forest_1 = require("../../../src/configuration/boot/make-category-forest");
const category_form_1 = require("../../../src/model/configuration/category-form");
const field_1 = require("../../../src/model/configuration/field");
const group_1 = require("../../../src/model/configuration/group");
const field_resource_1 = require("../../../src/model/field-resource");
const resource_1 = require("../../../src/model/resource");
const forest_1 = require("../../../src/tools/forest");
const named_1 = require("../../../src/tools/named");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
describe('makeCategoryForest', () => {
    it('makeCategoryForest', () => {
        const A = 'A';
        const P = 'P';
        const categories = {
            A: {
                name: A,
                parent: P,
                fields: { a: { name: 'a', inputType: field_1.Field.InputType.INPUT, visible: true } },
                description: {},
                minimalForm: { groups: [] }
            },
            P: {
                name: P,
                fields: { p: { name: 'p', inputType: field_1.Field.InputType.INPUT, visible: true } },
                description: {},
                minimalForm: { groups: [] }
            }
        };
        const forms = {
            'A:default': {
                name: 'A:default',
                categoryName: A,
                description: {},
                createdBy: '',
                creationDate: '',
                fields: {
                    a: { name: 'a', inputType: field_1.Field.InputType.INPUT, visible: true },
                    p: { name: 'p', inputType: field_1.Field.InputType.INPUT, visible: true }
                },
                groups: [
                    { name: group_1.Groups.STEM, fields: ['a', 'p'] }
                ]
            },
            'P:default': {
                name: 'P:default',
                categoryName: P,
                description: {},
                createdBy: '',
                creationDate: '',
                fields: {
                    p: { name: 'p', inputType: field_1.Field.InputType.INPUT, visible: true }
                },
                groups: [
                    { name: group_1.Groups.STEM, fields: ['p'] }
                ]
            }
        };
        const categoriesMap = named_1.Named.arrayToMap(forest_1.Tree.flatten(make_category_forest_1.makeCategoryForest([], categories)(forms)));
        expect(categoriesMap[P].name).toEqual(P);
        expect(categoriesMap[P].children[0].name).toEqual(A);
        expect(category_form_1.CategoryForm.getFields(categoriesMap[P]).length).toBe(1);
        const categoryA = categoriesMap[P].children[0];
        expect(categoryA.name).toEqual(A);
        expect(category_form_1.CategoryForm.getFields(categoryA).length).toBe(2);
        expect(categoryA.parentCategory.name).toBe(categoriesMap[P].name);
    });
    it('set all children in parent category', () => {
        const A = 'A';
        const B = 'B';
        const P = 'P';
        const categories = {
            A: {
                name: A,
                parent: P,
                fields: {},
                description: {},
                minimalForm: { groups: [] }
            }, P: {
                name: P,
                fields: {},
                description: {},
                minimalForm: { groups: [] }
            }
        };
        const forms = {
            'A:default': {
                name: 'A:default',
                categoryName: A,
                createdBy: '',
                creationDate: '',
                description: {},
                fields: {},
                groups: []
            },
            B: {
                name: B,
                categoryName: B,
                parent: P,
                createdBy: '',
                creationDate: '',
                description: {},
                fields: {},
                groups: []
            },
            'P:default': {
                name: 'P:default',
                categoryName: P,
                createdBy: '',
                creationDate: '',
                description: {},
                fields: {},
                groups: []
            }
        };
        const categoriesMap = named_1.Named.arrayToMap(forest_1.Tree.flatten(make_category_forest_1.makeCategoryForest([], categories)(forms)));
        const categoryA = categoriesMap[P].children.find(category => category.name === A);
        const categoryB = categoriesMap[P].children.find(category => category.name === B);
        expect(categoryA.parentCategory.children.length).toBe(2);
        expect(categoryB.parentCategory.children[0].name).toEqual(A);
        expect(categoryA.parentCategory.children[1].name).toEqual(B);
        expect(categoryB.parentCategory.children.length).toBe(2);
        expect(categoryB.parentCategory.children[0].name).toEqual(A);
        expect(categoryB.parentCategory.children[1].name).toEqual(B);
    });
    it('sort fields in groups', () => {
        const T = 'T';
        const categories = {
            T: {
                name: T,
                description: {},
                fields: {
                    shortDescription: {
                        name: 'shortDescription',
                        inputType: field_1.Field.InputType.INPUT,
                    },
                    identifier: {
                        name: 'identifier',
                        inputType: field_1.Field.InputType.INPUT
                    }
                },
                minimalForm: { groups: [] }
            }
        };
        const forms = {
            'T:default': {
                name: 'T:default',
                categoryName: T,
                description: {},
                createdBy: '',
                creationDate: '',
                fields: {
                    shortDescription: {
                        name: 'shortDescription',
                        inputType: field_1.Field.InputType.INPUT,
                    },
                    identifier: {
                        name: 'identifier',
                        inputType: field_1.Field.InputType.INPUT
                    }
                },
                groups: [
                    { name: group_1.Groups.STEM, fields: ['identifier', 'relation', 'shortDescription'] }
                ]
            }
        };
        const relations = [{
                name: 'relation',
                domain: ['T'],
                range: ['X'],
                inputType: 'relation'
            }];
        const categoriesMap = named_1.Named.arrayToMap(forest_1.Tree.flatten(make_category_forest_1.makeCategoryForest(relations, categories)(forms)));
        expect(categoriesMap[T].groups[0].name).toEqual(group_1.Groups.STEM);
        expect(categoriesMap[T].groups[0].fields[0].name).toEqual(resource_1.Resource.IDENTIFIER);
        expect(categoriesMap[T].groups[0].fields[1].name).toEqual('relation');
        expect(categoriesMap[T].groups[0].fields[2].name).toEqual(field_resource_1.FieldResource.SHORTDESCRIPTION);
    });
    it('put unassigned fields to default groups', () => {
        const categories = {
            T: {
                name: 'T',
                description: {},
                fields: {
                    field1: {
                        name: 'field1',
                        inputType: field_1.Field.InputType.INPUT
                    }
                },
                minimalForm: {
                    groups: [
                        { name: group_1.Groups.STEM, fields: ['field1'] }
                    ]
                }
            }
        };
        const forms = {
            'T:default': {
                name: 'T:default',
                categoryName: 'T',
                description: {},
                createdBy: '',
                creationDate: '',
                fields: {
                    field1: {
                        name: 'field1',
                        inputType: field_1.Field.InputType.INPUT,
                        visible: true
                    },
                    field2: {
                        name: 'field2',
                        inputType: field_1.Field.InputType.INPUT,
                        visible: true
                    }
                },
                groups: [
                    { name: group_1.Groups.STEM, fields: ['field2'] }
                ]
            }
        };
        const relations = [{
                name: 'isBefore',
                domain: ['T'],
                range: ['X'],
                inputType: 'relation'
            }];
        const categoriesMap = named_1.Named.arrayToMap(forest_1.Tree.flatten(make_category_forest_1.makeCategoryForest(relations, categories)(forms)));
        expect(categoriesMap['T'].groups.length).toBe(3);
        expect(categoriesMap['T'].groups[0].name).toEqual(group_1.Groups.STEM);
        expect(categoriesMap['T'].groups[0].fields.length).toBe(1);
        expect(categoriesMap['T'].groups[0].fields[0].name).toEqual('field2');
        expect(categoriesMap['T'].groups[1].name).toEqual(group_1.Groups.OTHER);
        expect(categoriesMap['T'].groups[1].fields.length).toBe(1);
        expect(categoriesMap['T'].groups[1].fields[0].name).toEqual('field1');
        expect(categoriesMap['T'].groups[2].name).toEqual(group_1.Groups.TIME);
        expect(categoriesMap['T'].groups[2].fields.length).toBe(1);
        expect(categoriesMap['T'].groups[2].fields[0].name).toEqual('isBefore');
    });
});
//# sourceMappingURL=make-category-forest.spec.js.map