"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const valuelist_1 = require("../../../../src/model/configuration/valuelist");
/**
 * @author Thomas Kleinke
 */
describe('Valuelist', () => {
    it('apply valuelist extension', () => {
        const extendedValuelist = {
            id: 'list',
            source: 'library',
            values: {
                a: {},
                b: {}
            }
        };
        const extendingValuelist = {
            id: 'extending-list',
            source: 'custom',
            extendedValuelist: 'list',
            values: {
                c: {}
            },
            hidden: ['b']
        };
        const result = valuelist_1.Valuelist.applyExtension(extendingValuelist, extendedValuelist);
        expect(result).toEqual({
            id: 'extending-list',
            source: 'custom',
            extendedValuelist: 'list',
            values: {
                a: {},
                c: {}
            },
            hidden: ['b']
        });
    });
    it('allow overwriting parent values when extending valuelist', () => {
        const extendedValuelist = {
            id: 'list',
            source: 'library',
            values: {
                a: {
                    label: { en: 'Library label A' },
                    description: { en: 'Library description A' }
                },
                b: {
                    label: { en: 'Library label B' },
                    description: { en: 'Library description B' }
                }
            }
        };
        const extendingValuelist = {
            id: 'extending-list',
            source: 'custom',
            extendedValuelist: 'list',
            values: {
                a: {
                    label: { en: 'Custom label A' },
                    description: { en: 'Custom description A' }
                },
                c: {
                    label: { en: 'Custom label C' },
                    description: { en: 'Custom description C' }
                }
            }
        };
        const result = valuelist_1.Valuelist.applyExtension(extendingValuelist, extendedValuelist);
        expect(result).toEqual({
            id: 'extending-list',
            source: 'custom',
            extendedValuelist: 'list',
            values: {
                a: {
                    label: { en: 'Custom label A' },
                    description: { en: 'Custom description A' }
                },
                b: {
                    label: { en: 'Library label B' },
                    description: { en: 'Library description B' }
                },
                c: {
                    label: { en: 'Custom label C' },
                    description: { en: 'Custom description C' }
                }
            }
        });
    });
});
//# sourceMappingURL=valuelist.spec.js.map