"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const pouchdb_node_1 = __importDefault(require("pouchdb-node"));
const datastore_1 = require("../../../src/datastore");
const test_helpers_1 = require("../../test-helpers");
/**
 * @author Sebastian Cuy
 */
xdescribe('SyncService', () => {
    const setup = (port) => __awaiter(void 0, void 0, void 0, function* () {
        console.log('setup');
        const app = express_1.default();
        app.use('/db', require('express-pouchdb')(pouchdb_node_1.default, { mode: 'minimumForPouchDB' }));
        const server = app.listen(port);
        const remoteDb = new pouchdb_node_1.default(`http://localhost:${port}/db/test_remote`);
        try {
            yield remoteDb.put(test_helpers_1.doc('Test Find', 'Find 1', 'Find', '1'));
        }
        catch (err) {
            console.error(err);
        }
        const datastore = new datastore_1.PouchdbDatastore(name => new pouchdb_node_1.default(name), new datastore_1.IdGenerator());
        const localDb = yield datastore.createDb('test_local', { _id: 'project' }, null, true);
        const syncService = new datastore_1.SyncService(datastore);
        return { server, syncService, remoteDb, localDb };
    });
    const tearDown = (server, syncService, remoteDb, localDb) => __awaiter(void 0, void 0, void 0, function* () {
        console.log('tearDown');
        syncService.stopSync();
        server.close();
        yield remoteDb.destroy();
        yield localDb.destroy();
    });
    xit('one-shot sync emits the correct status', (done) => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const { server, syncService, remoteDb, localDb } = yield setup(30001);
            const status = syncService.statusNotifications();
            syncService.init('http://localhost:30001/db', 'test_remote', '', () => __awaiter(void 0, void 0, void 0, function* () { return true; }));
            syncService.startSync();
            let count = 0;
            status.subscribe(s => {
                count++;
                console.log('s1', s);
                if (count === 1)
                    expect(s).toBe(datastore_1.SyncStatus.Pulling);
                if (count === 2) {
                    expect(s).toBe(datastore_1.SyncStatus.InSync);
                    done();
                }
            });
        }
        catch (err) {
            fail(err);
            console.error(err);
        }
    }));
    xit('live sync emits the correct status', (done) => __awaiter(void 0, void 0, void 0, function* () {
        // TODO: does not work as expected
        // stays in status IN_SYNC after putting second Find
        // and keeps producing errors even after syncing is stopped in tearDown()
        try {
            const { server, syncService, remoteDb, localDb } = yield setup(30002);
            const status = syncService.statusNotifications();
            syncService.init('http://localhost:30002/db', 'test_remote', '', () => __awaiter(void 0, void 0, void 0, function* () { return true; }));
            syncService.startSync();
            let count = 0;
            yield new Promise(resolve => status.subscribe(s => {
                count++;
                console.log('s2', s);
                if (count === 2) {
                    expect(s).toBe(datastore_1.SyncStatus.InSync);
                    resolve();
                }
                if (count === 5) {
                    expect(s).toBe(datastore_1.SyncStatus.InSync);
                    tearDown(server, syncService, remoteDb, localDb);
                    done();
                }
            }));
            yield remoteDb.put(test_helpers_1.doc('Another Test Find', 'Find 2', 'Find', '2'));
        }
        catch (err) {
            fail(err);
            console.error(err);
        }
    }));
});
//# sourceMappingURL=sync-service.spec.js.map