"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const custom_language_configurations_1 = require("../../../src/model/custom-language-configurations");
/**
 * @author Thomas Kleinke
 */
describe('CustomLanguageConfigurations', () => {
    const categoryLabel = {
        de: 'Test-Kategorie',
        en: 'Test category'
    };
    const categoryDescription = {
        de: 'Beschreibungstext der Kategorie',
        en: 'Category description text'
    };
    const fieldLabel = {
        de: 'Test-Feld',
        en: 'Test field'
    };
    const fieldDescription = {
        de: 'Beschreibungstext des Feldes',
        en: 'Field description text'
    };
    const groupLabel = {
        de: 'Test-Gruppe',
        en: 'Test group'
    };
    const category = {
        name: 'testCategory',
        label: categoryLabel,
        defaultLabel: categoryLabel,
        categoryLabel: categoryLabel,
        description: categoryDescription,
        defaultDescription: categoryDescription,
        children: [],
        parentCategory: undefined,
        isAbstract: false,
        groups: [],
        mustLieWithin: false,
        color: '#fff'
    };
    const field = {
        name: 'testField',
        label: fieldLabel,
        defaultLabel: fieldLabel,
        description: fieldDescription,
        defaultDescription: fieldDescription,
        inputType: 'text'
    };
    const compositeField = {
        name: 'testCompositeField',
        subfields: [
            {
                name: 'testSubfield',
                label: fieldLabel,
                defaultLabel: fieldLabel,
                description: fieldDescription,
                defaultDescription: fieldDescription,
                inputType: 'text'
            }
        ],
        inputType: 'composite'
    };
    const relation = {
        name: 'testRelation',
        label: fieldLabel,
        defaultLabel: fieldLabel,
        description: fieldDescription,
        defaultDescription: fieldDescription,
        inputType: 'relation'
    };
    const group = {
        name: 'testGroup',
        label: groupLabel,
        defaultLabel: groupLabel,
        fields: []
    };
    it('Add new translations to custom language configurations for field', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Altes Label',
                                description: 'Alte Beschreibung'
                            }
                        }
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Neues Label',
            en: 'New label'
        };
        const editedDescription = {
            de: 'Neue Beschreibung',
            en: 'New description'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, field);
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testField.label)
            .toBe('Neues Label');
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testField.description)
            .toBe('Neue Beschreibung');
        expect(customLanguageConfigurations.en.categories.testCategory.fields.testField.label)
            .toBe('New label');
        expect(customLanguageConfigurations.en.categories.testCategory.fields.testField.description)
            .toBe('New description');
    });
    it('Add new translations to custom language configurations for subfield', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testCompositeField: {
                                subfields: {
                                    testSubfield: {
                                        label: 'Altes Label',
                                        description: 'Alte Beschreibung'
                                    }
                                }
                            }
                        }
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Neues Label',
            en: 'New label'
        };
        const editedDescription = {
            de: 'Neue Beschreibung',
            en: 'New description'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, compositeField, compositeField.subfields[0]);
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testCompositeField.subfields.testSubfield
            .label).toBe('Neues Label');
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testCompositeField.subfields.testSubfield
            .description).toBe('Neue Beschreibung');
        expect(customLanguageConfigurations.en.categories.testCategory.fields.testCompositeField.subfields.testSubfield
            .label).toBe('New label');
        expect(customLanguageConfigurations.en.categories.testCategory.fields.testCompositeField.subfields.testSubfield
            .description).toBe('New description');
    });
    it('Add new translations to custom language configurations for relation', () => {
        const customLanguageConfigurations = {
            de: {
                relations: {
                    testRelation: {
                        label: 'Altes Label',
                        description: 'Alte Beschreibung'
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Neues Label',
            en: 'New label'
        };
        const editedDescription = {
            de: 'Neue Beschreibung',
            en: 'New description'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, relation);
        expect(customLanguageConfigurations.de.relations.testRelation.label).toBe('Neues Label');
        expect(customLanguageConfigurations.de.relations.testRelation.description).toBe('Neue Beschreibung');
        expect(customLanguageConfigurations.en.relations.testRelation.label).toBe('New label');
        expect(customLanguageConfigurations.en.relations.testRelation.description).toBe('New description');
    });
    it('Add new translations to custom language configurations for category', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        label: 'Altes Label',
                        description: 'Alte Beschreibung'
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Neues Label',
            en: 'New label'
        };
        const editedDescription = {
            de: 'Neue Beschreibung',
            en: 'New description'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category);
        expect(customLanguageConfigurations.de.categories.testCategory.label).toBe('Neues Label');
        expect(customLanguageConfigurations.de.categories.testCategory.description).toBe('Neue Beschreibung');
        expect(customLanguageConfigurations.en.categories.testCategory.label).toBe('New label');
        expect(customLanguageConfigurations.en.categories.testCategory.description).toBe('New description');
    });
    it('Add new translations to custom language configurations for group', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {}
            }
        };
        const editedLabel = {
            de: 'Neues Label',
            en: 'New label'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, undefined, undefined, undefined, undefined, group);
        expect(customLanguageConfigurations.de.groups.testGroup).toBe('Neues Label');
        expect(customLanguageConfigurations.en.groups.testGroup).toBe('New label');
    });
    it('Remove deleted translations from custom language configurations for field', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Altes Label',
                                description: 'Alte Beschreibung'
                            }
                        }
                    }
                }
            },
            en: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Old label',
                                description: 'Old description'
                            }
                        }
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Altes Label'
        };
        const editedDescription = {};
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, field);
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testField.label)
            .toBe('Altes Label');
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testField.description)
            .toBeUndefined();
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove deleted translations from custom language configurations for subfield', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testCompositeField: {
                                subfields: {
                                    testSubfield: {
                                        label: 'Altes Label',
                                        description: 'Alte Beschreibung'
                                    }
                                }
                            }
                        }
                    }
                }
            },
            en: {
                categories: {
                    testCategory: {
                        fields: {
                            testCompositeField: {
                                subfields: {
                                    testSubfield: {
                                        label: 'Old label',
                                        description: 'Old description'
                                    }
                                }
                            }
                        }
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Altes Label'
        };
        const editedDescription = {};
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, compositeField, compositeField.subfields[0]);
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testCompositeField.subfields.testSubfield
            .label).toBe('Altes Label');
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testCompositeField.subfields.testSubfield
            .description).toBeUndefined();
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove deleted translations from custom language configurations for relation', () => {
        const customLanguageConfigurations = {
            de: {
                relations: {
                    testRelation: {
                        label: 'Altes Label',
                        description: 'Alte Beschreibung'
                    }
                }
            },
            en: {
                relations: {
                    testRelation: {
                        label: 'Old label',
                        description: 'Old description'
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Altes Label'
        };
        const editedDescription = {};
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, relation);
        expect(customLanguageConfigurations.de.relations.testRelation.label).toBe('Altes Label');
        expect(customLanguageConfigurations.de.relations.testRelation.description).toBeUndefined();
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove deleted translations from custom language configurations for category', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        label: 'Altes Label',
                        description: 'Alte Beschreibung'
                    }
                }
            },
            en: {
                categories: {
                    testCategory: {
                        label: 'Old label',
                        description: 'Old description'
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Altes Label'
        };
        const editedDescription = {};
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category);
        expect(customLanguageConfigurations.de.categories.testCategory.label).toBe('Altes Label');
        expect(customLanguageConfigurations.de.categories.testCategory.description).toBeUndefined();
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove deleted translations from custom language configurations for group', () => {
        const customLanguageConfigurations = {
            de: {
                groups: {
                    testGroup: 'Altes Label'
                }
            },
            en: {
                groups: {
                    testGroup: 'Old label'
                }
            }
        };
        const editedLabel = {
            de: 'Altes Label'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, undefined, undefined, undefined, undefined, group);
        expect(customLanguageConfigurations.de.groups.testGroup).toBe('Altes Label');
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove translations equal to default translation from custom language configurations for field', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Altes Label',
                                description: 'Alte Beschreibung'
                            }
                        }
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Test-Feld'
        };
        const editedDescription = {
            de: 'Beschreibungstext des Feldes'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, field);
        expect(customLanguageConfigurations.de).toBeUndefined();
    });
    it('Remove translations equal to default translation from custom language configurations for subfield', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testCompositeField: {
                                subfields: {
                                    testSubfield: {
                                        label: 'Altes Label',
                                        description: 'Alte Beschreibung'
                                    }
                                }
                            }
                        }
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Test-Feld'
        };
        const editedDescription = {
            de: 'Beschreibungstext des Feldes'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, compositeField, compositeField.subfields[0]);
        expect(customLanguageConfigurations.de).toBeUndefined();
    });
    it('Remove translations equal to default translation from custom language configurations for relation', () => {
        const customLanguageConfigurations = {
            de: {
                relations: {
                    testRelation: {
                        label: 'Altes Label',
                        description: 'Alte Beschreibung'
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Test-Feld'
        };
        const editedDescription = {
            de: 'Beschreibungstext des Feldes'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category, relation);
        expect(customLanguageConfigurations.de).toBeUndefined();
    });
    it('Remove translations equal to default translation from custom language configurations for category', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        label: 'Altes Label',
                        description: 'Alte Beschreibung'
                    }
                }
            }
        };
        const editedLabel = {
            de: 'Test-Kategorie'
        };
        const editedDescription = {
            de: 'Beschreibungstext der Kategorie'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, editedDescription, category);
        expect(customLanguageConfigurations.de).toBeUndefined();
    });
    it('Remove translations equal to default translation from custom language configurations for group', () => {
        const customLanguageConfigurations = {
            de: {
                groups: {
                    testGroup: 'Altes Label'
                }
            }
        };
        const editedLabel = {
            de: 'Test-Gruppe'
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, editedLabel, undefined, undefined, undefined, undefined, group);
        expect(customLanguageConfigurations.de).toBeUndefined();
    });
    it('Remove all translations from custom language configurations for field', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Label 1',
                                description: 'Beschreibung 1'
                            },
                            testField2: {
                                label: 'Label 2',
                                description: 'Beschreibung 2'
                            },
                        }
                    }
                }
            },
            en: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Label',
                                description: 'Description'
                            }
                        }
                    }
                }
            }
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, {}, {}, category, field);
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testField)
            .toBeUndefined();
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testField2.label)
            .toBe('Label 2');
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testField2.description)
            .toBe('Beschreibung 2');
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove all translations from custom language configurations for subfield', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testCompositeField: {
                                subfields: {
                                    testSubfield: {
                                        label: 'Label 1',
                                        description: 'Beschreibung 1'
                                    }
                                }
                            },
                            testCompositeField2: {
                                subfields: {
                                    testSubfield2: {
                                        label: 'Label 2',
                                        description: 'Beschreibung 2'
                                    }
                                }
                            },
                        }
                    }
                }
            },
            en: {
                categories: {
                    testCategory: {
                        fields: {
                            testCompositeField: {
                                subfields: {
                                    testSubfield: {
                                        label: 'Label',
                                        description: 'Description'
                                    }
                                }
                            }
                        }
                    }
                }
            }
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, {}, {}, category, compositeField, compositeField.subfields[0]);
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testCompositeField).toBeUndefined();
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testCompositeField2.subfields.testSubfield2
            .label).toBe('Label 2');
        expect(customLanguageConfigurations.de.categories.testCategory.fields.testCompositeField2.subfields.testSubfield2
            .description).toBe('Beschreibung 2');
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove all translations from custom language configurations for relation', () => {
        const customLanguageConfigurations = {
            de: {
                relations: {
                    testRelation: {
                        label: 'Label 1',
                        description: 'Beschreibung 1'
                    },
                    testRelation2: {
                        label: 'Label 2',
                        description: 'Beschreibung 2'
                    },
                }
            },
            en: {
                relations: {
                    testRelation: {
                        label: 'Label',
                        description: 'Description'
                    }
                }
            }
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, {}, {}, category, relation);
        expect(customLanguageConfigurations.de.relations.testRelation).toBeUndefined();
        expect(customLanguageConfigurations.de.relations.testRelation2.label).toBe('Label 2');
        expect(customLanguageConfigurations.de.relations.testRelation2.description).toBe('Beschreibung 2');
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove all translations from custom language configurations for group', () => {
        const customLanguageConfigurations = {
            de: {
                groups: {
                    testGroup: 'Label 1',
                    testGroup2: 'Label 2'
                }
            },
            en: {
                groups: {
                    testGroup: 'Label'
                }
            }
        };
        custom_language_configurations_1.CustomLanguageConfigurations.update(customLanguageConfigurations, {}, {}, category, undefined, undefined, group);
        expect(customLanguageConfigurations.de.groups.testGroup).toBeUndefined();
        expect(customLanguageConfigurations.de.groups.testGroup2).toBe('Label 2');
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
    it('Remove all translations from custom language configurations for category', () => {
        const customLanguageConfigurations = {
            de: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Label 1',
                                description: 'Beschreibung 1'
                            }
                        }
                    },
                    testCategory2: {
                        fields: {
                            testField: {
                                label: 'Label 2',
                                description: 'Beschreibung 2'
                            }
                        }
                    }
                }
            },
            en: {
                categories: {
                    testCategory: {
                        fields: {
                            testField: {
                                label: 'Label',
                                description: 'Description'
                            }
                        }
                    }
                }
            }
        };
        custom_language_configurations_1.CustomLanguageConfigurations.deleteCategory(customLanguageConfigurations, category);
        expect(customLanguageConfigurations.de.categories.testCategory).toBeUndefined();
        expect(customLanguageConfigurations.de.categories.testCategory2.fields.testField.label)
            .toBe('Label 2');
        expect(customLanguageConfigurations.de.categories.testCategory2.fields.testField.description)
            .toBe('Beschreibung 2');
        expect(customLanguageConfigurations.en).toBeUndefined();
    });
});
//# sourceMappingURL=custom-language-configurations.spec.js.map