"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dimension_1 = require("../../src/model/dimension");
describe('Dimension', () => {
    it('translate back to original state', () => {
        const dim = {
            inputValue: 100,
            inputUnit: 'cm',
            isImprecise: false
        };
        dimension_1.Dimension.addNormalizedValues(dim);
        expect(dim.value).not.toBeUndefined();
        const reverted = dimension_1.Dimension.revert(dim);
        expect(reverted['value']).toBeUndefined();
    });
    it('translate back to original state - range', () => {
        const dim = {
            inputValue: 100,
            inputRangeEndValue: 200,
            inputUnit: 'cm',
            isImprecise: false
        };
        dimension_1.Dimension.addNormalizedValues(dim);
        expect(dim.value).toBeUndefined();
        expect(dim.rangeMin).not.toBeUndefined();
        expect(dim.rangeMax).not.toBeUndefined();
        const reverted = dimension_1.Dimension.revert(dim);
        expect(reverted['rangeMin']).toBeUndefined();
        expect(reverted['rangeMax']).toBeUndefined();
    });
    it('isValid', () => {
        const dim = {
            inputValue: 100,
            inputRangeEndValue: 200,
            inputUnit: 'cm',
            isImprecise: false
        };
        expect(dimension_1.Dimension.isValid(dim)).toBeTruthy();
    });
    it('isValid - not valid', () => {
        const dim = {
            inputRangeEndValue: 200,
            inputUnit: 'cm',
            isImprecise: false
        };
        expect(dimension_1.Dimension.isValid(dim)).toBeFalsy();
    });
    it('isValid - not valid - range with identical values', () => {
        const dim = {
            inputValue: 200,
            inputRangeEndValue: 200,
            inputUnit: 'cm',
            isImprecise: false
        };
        expect(dimension_1.Dimension.isValid(dim)).toBeFalsy();
    });
    it('isValid - not valid - negative values', () => {
        const dim = {
            inputValue: -200,
            inputUnit: 'cm',
            isImprecise: false
        };
        expect(dimension_1.Dimension.isValid(dim)).toBeFalsy();
    });
    it('isValid - not valid - permissive', () => {
        const dim = {
            inputValue: -200,
            inputUnit: 'cm',
            isImprecise: false
        };
        expect(dimension_1.Dimension.isValid(dim, { permissive: true })).toBeTruthy();
    });
});
//# sourceMappingURL=dimension.spec.js.map