"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const document_1 = require("../../src/model/document");
/**
 * @author Daniel de Oliveira
 * @author Thomas Kleinke
 */
describe('Document', () => {
    const buildDocument = () => {
        return {
            _id: '1',
            resource: {
                identifier: '',
                id: '1',
                category: 'a',
                relations: {}
            },
            modified: [],
            created: { user: 'a', date: new Date() }
        };
    };
    it('detect valid documents', () => {
        expect(document_1.Document.isValid(buildDocument())).toBe(true);
        const document = buildDocument();
        delete document.resource.id;
        expect(document_1.Document.isValid(document, true)).toBe(true);
    });
    it('detect invalid documents', () => {
        let document = buildDocument();
        delete document.resource;
        expect(document_1.Document.isValid(document)).toBe(false);
        document = buildDocument();
        delete document.resource.id;
        expect(document_1.Document.isValid(document)).toBe(false);
        document = buildDocument();
        delete document.resource.category;
        expect(document_1.Document.isValid(document)).toBe(false);
        document = buildDocument();
        delete document.resource.relations;
        expect(document_1.Document.isValid(document)).toBe(false);
        document = buildDocument();
        delete document.modified;
        expect(document_1.Document.isValid(document)).toBe(false);
        document = buildDocument();
        delete document.created;
        expect(document_1.Document.isValid(document)).toBe(false);
    });
    it('remove fields', () => {
        const document = buildDocument();
        expect(document.resource.category).not.toBeUndefined();
        const document2 = document_1.Document.removeFields(['category'])(document);
        expect(document2.resource.category).toBeUndefined();
    });
    it('clone object with dates', () => {
        const original = {
            a: {
                a1: new Date(),
                a2: ''
            },
            b: new Date(),
            c: ''
        };
        const cloned = document_1.Document.clone(original);
        expect(cloned.a.a1 instanceof Date).toBeTruthy();
        expect(cloned.a.a2).toEqual('');
        expect(cloned.b instanceof Date).toBeTruthy();
        expect(cloned.c).toEqual('');
    });
    it('clones are independent', () => {
        const original = {
            a: {
                a1: new Date(),
                a2: ''
            },
            b: new Date(),
            c: ''
        };
        const cloned = document_1.Document.clone(original);
        original["a"] = "";
        delete original["b"];
        original["c"] = new Date();
        expect(cloned.a.a1 instanceof Date).toBeTruthy();
        expect(cloned.a.a2).toEqual('');
        expect(cloned.b instanceof Date).toBeTruthy();
        expect(cloned.c).toEqual('');
    });
}); // for some reason /* gets inserted and causes problems without this comment
//# sourceMappingURL=document.spec.js.map