"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const field_1 = require("../../src/model/configuration/field");
/**
 * @author Thomas Kleinke
 */
describe('Field', () => {
    function makeField(inputType) {
        return {
            name: 'field',
            inputType: inputType
        };
    }
    it('validate correct field data', () => {
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.INPUT))).toBe(true);
        expect(field_1.Field.isValidFieldData({ de: 'text1', en: 'text2' }, makeField(field_1.Field.InputType.INPUT))).toBe(true);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.SIMPLE_INPUT))).toBe(true);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.TEXT))).toBe(true);
        expect(field_1.Field.isValidFieldData({ de: 'text1', en: 'text2' }, makeField(field_1.Field.InputType.TEXT))).toBe(true);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.DROPDOWN))).toBe(true);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.RADIO))).toBe(true);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.CATEGORY))).toBe(true);
        expect(field_1.Field.isValidFieldData(['a', 'b'], makeField(field_1.Field.InputType.MULTIINPUT))).toBe(true);
        expect(field_1.Field.isValidFieldData(['a', 'b'], makeField(field_1.Field.InputType.CHECKBOXES))).toBe(true);
        expect(field_1.Field.isValidFieldData(700, makeField(field_1.Field.InputType.UNSIGNEDINT))).toBe(true);
        expect(field_1.Field.isValidFieldData(7.5, makeField(field_1.Field.InputType.UNSIGNEDFLOAT))).toBe(true);
        expect(field_1.Field.isValidFieldData(-7.5, makeField(field_1.Field.InputType.FLOAT))).toBe(true);
        expect(field_1.Field.isValidFieldData(true, makeField(field_1.Field.InputType.BOOLEAN))).toBe(true);
        expect(field_1.Field.isValidFieldData(false, makeField(field_1.Field.InputType.BOOLEAN))).toBe(true);
        expect(field_1.Field.isValidFieldData('31.01.2010', makeField(field_1.Field.InputType.DATE))).toBe(true);
        expect(field_1.Field.isValidFieldData('01.2010', makeField(field_1.Field.InputType.DATE))).toBe(true);
        expect(field_1.Field.isValidFieldData('2010', makeField(field_1.Field.InputType.DATE))).toBe(true);
        expect(field_1.Field.isValidFieldData({ value: 'A', endValue: 'B' }, makeField(field_1.Field.InputType.DROPDOWNRANGE))).toBe(true);
        expect(field_1.Field.isValidFieldData([{ type: 'single', end: { year: 200, inputYear: 200, inputType: 'ce' } }], makeField(field_1.Field.InputType.DATING))).toBe(true);
        expect(field_1.Field.isValidFieldData([{ inputValue: 50, inputUnit: 'cm' }], makeField(field_1.Field.InputType.DIMENSION))).toBe(true);
        expect(field_1.Field.isValidFieldData([{ quotation: 'text' }], makeField(field_1.Field.InputType.LITERATURE))).toBe(true);
        expect(field_1.Field.isValidFieldData({ type: 'Point', coordinates: [0.5, 1.5] }, makeField(field_1.Field.InputType.GEOMETRY))).toBe(true);
        expect(field_1.Field.isValidFieldData({ liesWithin: ['a', 'b'] }, makeField(field_1.Field.InputType.RELATION))).toBe(true);
        expect(field_1.Field.isValidFieldData({ isInstanceOf: ['a', 'b'] }, makeField(field_1.Field.InputType.INSTANCE_OF))).toBe(true);
    });
    it('validate incorrect field data', () => {
        expect(field_1.Field.isValidFieldData(700, makeField(field_1.Field.InputType.INPUT))).toBe(false);
        expect(field_1.Field.isValidFieldData({ de: 'text1', en: 'text2' }, makeField(field_1.Field.InputType.SIMPLE_INPUT)))
            .toBe(false);
        expect(field_1.Field.isValidFieldData(700, makeField(field_1.Field.InputType.TEXT))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.DROPDOWN))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.RADIO))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.CATEGORY))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.MULTIINPUT))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.CHECKBOXES))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.UNSIGNEDINT))).toBe(false);
        expect(field_1.Field.isValidFieldData(-700, makeField(field_1.Field.InputType.UNSIGNEDINT))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.UNSIGNEDFLOAT))).toBe(false);
        expect(field_1.Field.isValidFieldData(-7.5, makeField(field_1.Field.InputType.UNSIGNEDFLOAT))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.FLOAT))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.BOOLEAN))).toBe(false);
        expect(field_1.Field.isValidFieldData({ quotation: 'text' }, makeField(field_1.Field.InputType.DATE))).toBe(false);
        expect(field_1.Field.isValidFieldData('31-01-2010', makeField(field_1.Field.InputType.DATE))).toBe(false);
        expect(field_1.Field.isValidFieldData('31.01.2010.01', makeField(field_1.Field.InputType.DATE))).toBe(false);
        expect(field_1.Field.isValidFieldData('ABC', makeField(field_1.Field.InputType.DATE))).toBe(false);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.DROPDOWNRANGE))).toBe(false);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.DATING))).toBe(false);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.DIMENSION))).toBe(false);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.LITERATURE))).toBe(false);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.GEOMETRY))).toBe(false);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.RELATION))).toBe(false);
        expect(field_1.Field.isValidFieldData('text', makeField(field_1.Field.InputType.INSTANCE_OF))).toBe(false);
    });
});
//# sourceMappingURL=field.spec.js.map