"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const labels_1 = require("../../src/services/labels");
describe('Labels', () => {
    const getLanguages = () => ['de'];
    let projectConfiguration;
    beforeAll(() => {
        projectConfiguration = jasmine.createSpyObj('projectConfiguration', ['getRelations']);
        projectConfiguration.getRelations.and.returnValue([]);
    });
    it('should get field label', () => {
        const category = {
            name: 'T',
            groups: [{
                    name: 'A',
                    fields: [{
                            name: 'aField',
                            label: { de: 'Ein Feld' }
                        }]
                }]
        };
        const labels = new labels_1.Labels(getLanguages, projectConfiguration);
        expect(labels.getFieldLabel(category, 'aField')).toBe('Ein Feld');
    });
    it('should get default field label if not defined', () => {
        const category = {
            name: 'T',
            groups: [{
                    fields: [{
                            name: 'aField'
                        }]
                }]
        };
        const labels = new labels_1.Labels(getLanguages, projectConfiguration);
        expect(labels.getFieldLabel(category, 'aField')).toBe('aField');
    });
    it('should get relation label', () => {
        const relation = {
            name: 'aRelation',
            label: { de: 'Eine Relation' },
            domain: ['T'],
            range: ['T'],
            inputType: 'relation'
        };
        projectConfiguration.getRelations.and.returnValue([relation]);
        const labels = new labels_1.Labels(getLanguages, projectConfiguration);
        expect(labels.getRelationLabel('aRelation')).toBe('Eine Relation');
    });
    it('should get default relation label if not defined', () => {
        const relation = {
            name: 'aRelation',
            domain: ['T'],
            range: ['T'],
            inputType: 'relation'
        };
        projectConfiguration.getRelations.and.returnValue([relation]);
        const labels = new labels_1.Labels(getLanguages, projectConfiguration);
        expect(labels.getRelationLabel('aRelation')).toBe('aRelation');
    });
    it('sort values alphanumerically', () => {
        const valuelist = {
            values: {
                '1': { label: { de: 'B300' } },
                '2': { label: { de: 'A3' } },
                '3': { label: { de: 'B3' } },
                '4': { label: { de: 'A300' } }
            },
            id: '1'
        };
        const labels = new labels_1.Labels(getLanguages, projectConfiguration);
        expect(labels.orderKeysByLabels(valuelist)).toEqual(['2', '4', '3', '1']);
    });
    // TODO move to valuelist-definition.spec
    it('sort values by custom order', () => {
        const valuelist = {
            values: {
                '1': { label: { de: 'A' } },
                '2': { label: { de: 'B' } },
                '3': { label: { de: 'C' } },
                '4': { label: { de: 'D' } },
            },
            order: ['2', '4', '3', '1'],
            id: '1'
        };
        const labels = new labels_1.Labels(getLanguages, projectConfiguration);
        expect(labels.orderKeysByLabels(valuelist)).toEqual(['2', '4', '3', '1']);
    });
});
//# sourceMappingURL=labels.spec.js.map