"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tsfun_1 = require("tsfun");
const project_configuration_1 = require("../../src/services/project-configuration");
const tools_1 = require("../../src/tools");
describe('ProjectConfiguration', () => {
    const projectConfiguration = new project_configuration_1.ProjectConfiguration({
        forms: tools_1.Forest.build([
            [
                { name: 'Image', groups: [] },
                [
                    [
                        { name: 'Drawing', groups: [] },
                        []
                    ]
                ]
            ],
            [
                {
                    name: 'Operation',
                    groups: [{ name: 'default', fields: [{ name: 'geometry' }] }]
                },
                [
                    [
                        {
                            name: 'Trench',
                            groups: [{ name: 'default', fields: [{ name: 'geometry' }] }]
                        },
                        []
                    ]
                ]
            ],
            [
                {
                    name: 'Place',
                    groups: [{ name: 'default', fields: [{ name: 'geometry' }] }]
                },
                []
            ],
            [
                {
                    name: 'Inscription',
                    groups: [{ name: 'default', fields: [{ name: 'description' }] }]
                },
                []
            ],
            [
                {
                    name: 'Type',
                    groups: []
                },
                []
            ],
            [
                {
                    name: 'TypeCatalog',
                    groups: []
                },
                []
            ],
            [
                {
                    name: 'Project',
                    groups: []
                },
                []
            ],
            [
                {
                    name: 'Find',
                    groups: [{ name: 'default', fields: [{ name: 'geometry' }] }]
                },
                []
            ],
            [
                {
                    name: 'Feature',
                    groups: [{ name: 'default', fields: [{ name: 'geometry' }] }]
                },
                [
                    [
                        {
                            name: 'Architecture',
                            groups: [{ name: 'default', fields: [{ name: 'geometry' }] }]
                        },
                        []
                    ]
                ]
            ]
        ]),
        categories: {},
        relations: [],
        commonFields: {},
        valuelists: {},
        projectLanguages: []
    });
    it('isGeometryCategory', () => {
        expect(projectConfiguration.isGeometryCategory('Image')).toBeFalsy();
        expect(projectConfiguration.isGeometryCategory('Drawing')).toBeFalsy();
        expect(projectConfiguration.isGeometryCategory('Type')).toBeFalsy();
        expect(projectConfiguration.isGeometryCategory('TypeCatalog')).toBeFalsy();
        expect(projectConfiguration.isGeometryCategory('Inscription')).toBeFalsy();
        expect(projectConfiguration.isGeometryCategory('Project')).toBeFalsy();
        expect(projectConfiguration.isGeometryCategory('Project')).toBeFalsy();
        expect(projectConfiguration.isGeometryCategory('Operation')).toBeTruthy();
        expect(projectConfiguration.isGeometryCategory('Find')).toBeTruthy();
        expect(projectConfiguration.isGeometryCategory('Feature')).toBeTruthy();
    });
    it('getConcreteFieldCategories', () => {
        expect(tsfun_1.sameset(projectConfiguration.getFieldCategories().map(tools_1.Named.toName), ['Operation', 'Trench', 'Inscription', 'Find', 'Place', 'Feature', 'Architecture'])).toBeTruthy();
    });
    it('getRegularCategoryNames', () => {
        expect(tsfun_1.sameset(projectConfiguration.getRegularCategories().map(tools_1.Named.toName), ['Inscription', 'Find', 'Feature', 'Architecture'])).toBeTruthy();
    });
    it('getImageCategoryNames', () => {
        expect(tsfun_1.sameset(projectConfiguration.getImageCategories().map(tools_1.Named.toName), ['Image', 'Drawing'])).toBeTruthy();
    });
    it('getTypeManagementCategories', () => {
        expect(tsfun_1.sameset(projectConfiguration.getTypeManagementCategories().map(tools_1.Named.toName), ['TypeCatalog', 'Type'])).toBeTruthy();
    });
    it('getOverviewToplevelCategories', () => {
        expect(tsfun_1.sameset(projectConfiguration.getOverviewSupercategories().map(tools_1.Named.toName), ['Operation', 'Place'])).toBeTruthy();
    });
    it('getOverviewConcreteOverviewCategories', () => {
        expect(tsfun_1.sameset(projectConfiguration.getConcreteOverviewCategories().map(tools_1.Named.toName), ['Trench', 'Place'])).toBeTruthy();
    });
    it('getOverviewCategories', () => {
        expect(tsfun_1.sameset(projectConfiguration.getOverviewCategories().map(tools_1.Named.toName), ['Operation', 'Trench', 'Place'])).toBeTruthy();
    });
    it('getFeatureCategories', () => {
        expect(tsfun_1.sameset(projectConfiguration.getFeatureCategories().map(tools_1.Named.toName), ['Feature', 'Architecture'])).toBeTruthy();
    });
});
//# sourceMappingURL=project-configuration.spec.js.map