"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const tsfun_1 = require("tsfun");
const model_1 = require("../../../src/model");
const test_helpers_1 = require("../../test-helpers");
const subsystem_helper_1 = require("../subsystem-helper");
describe('subsystem/relations-manager', () => {
    let app;
    let helpers;
    beforeEach((done) => __awaiter(void 0, void 0, void 0, function* () {
        app = yield subsystem_helper_1.createCoreApp();
        helpers = yield subsystem_helper_1.createHelpers(app);
        done();
    }));
    xit('get - include antescendants', (done) => __awaiter(void 0, void 0, void 0, function* () {
        yield helpers.createDocuments([
            ['tc1', 'TypeCatalog', ['t1']],
            ['t1', 'Type']
        ]);
        // const results = await app.relationsManager.getAntescendents('t1');
        // const lookup = makeDocumentsLookup(results);
        // expect(lookup['tc1'].resource.id).toBe('tc1');
        // expect(lookup['t1'].resource.id).toBe('t1');
        done();
    }));
    xit('getDescendantsCount', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const documentsLookup = yield helpers.createDocuments([
            ['tc1', 'TypeCatalog', ['t1']],
            ['t1', 'Type'],
            ['tc2', 'TypeCatalog', ['t2']],
            ['t2', 'Type']
        ]);
        // expect(await app.relationsManager.getDescendantsCount(documentsLookup['tc1'], documentsLookup['tc2'])).toBe(2);
        done();
    }));
    it('update', (done) => __awaiter(void 0, void 0, void 0, function* () {
        let t1 = test_helpers_1.doc('', 'identifiert1', 'Feature', 't1');
        let t2 = test_helpers_1.doc('', 'identifiert2', 'Feature', 't2');
        t1.resource.relations = { isAfter: ['t2'], isRecordedIn: [] };
        t2.resource.relations = { isBefore: ['t1'], isRecordedIn: [] };
        yield app.datastore.create(t1);
        t2 = (yield app.datastore.create(t2));
        const t2old = model_1.Document.clone(t2);
        t2.resource.relations['isBefore'] = [];
        t2.resource.identifier = 'identifiert2new';
        yield app.relationsManager.update(t2, t2old);
        t1 = (yield app.datastore.get('t1'));
        t2 = (yield app.datastore.get('t2'));
        expect(t2.resource.relations.isBefore).toEqual([]);
        expect(t1.resource.relations.isAfter).toEqual([]);
        expect(t2old.resource.relations.isBefore).toEqual(['t1']);
        done();
    }));
    it('skip image deletion', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const tc1 = test_helpers_1.doc('', 'identifiertc1', 'TypeCatalog', 'tc1');
        const t1 = test_helpers_1.doc('', 'identifiert1', 'Type', 't1');
        const i1 = test_helpers_1.doc('', 'identifieri1', 'Image', 'i1');
        const i2 = test_helpers_1.doc('', 'identifieri2', 'Image', 'i2');
        i1.resource.relations = { depicts: ['tc1'] };
        i2.resource.relations = { depicts: ['t1'] };
        tc1.resource.relations = { isDepictedIn: ['i1'], isRecordedIn: [] };
        t1.resource.relations = { isDepictedIn: ['i2'], isRecordedIn: [], liesWithin: ['tc1'] };
        yield app.datastore.create(tc1);
        yield app.datastore.create(t1);
        yield app.datastore.create(i1);
        yield app.datastore.create(i2);
        expect((yield app.datastore.find({})).documents.length).toBe(4);
        yield app.relationsManager.remove(tc1, { descendants: true });
        const documents = (yield app.datastore.find({})).documents;
        expect(tsfun_1.flatten(documents.map(_ => _.resource.relations.depicts))).toEqual([]);
        yield helpers.expectDocuments('i1', 'i2');
        done();
    }));
    function createTestResourcesForRemoveTests() {
        return __awaiter(this, void 0, void 0, function* () {
            const d1 = test_helpers_1.doc('', 'identifierid1', 'Trench', 'id1');
            const d2 = test_helpers_1.doc('', 'identifierid2', 'Feature', 'id2');
            d2.resource.relations['isRecordedIn'] = ['id1'];
            const d3 = test_helpers_1.doc('', 'identifierid3', 'Find', 'id3');
            d3.resource.relations['isRecordedIn'] = ['id1'];
            d3.resource.relations['liesWithin'] = ['id2'];
            const d4 = test_helpers_1.doc('', 'identifierid4', 'Find', 'id4');
            d4.resource.relations['isRecordedIn'] = ['id1'];
            d4.resource.relations['liesWithin'] = ['id2'];
            d4.resource.relations['isDepictedIn'] = ['id5', 'id6'];
            const d5 = test_helpers_1.doc('', 'identifierid5', 'Image', 'id5');
            d5.resource.relations['depicts'] = ['id4'];
            const d6 = test_helpers_1.doc('', 'identifierid6', 'Image', 'id6');
            d6.resource.relations['depicts'] = ['id4', 'id7'];
            const d7 = test_helpers_1.doc('', 'identifierid7', 'Find', 'id7');
            d7.resource.relations['isRecordedIn'] = ['id1'];
            d7.resource.relations['isDepictedIn'] = ['id6'];
            yield app.datastore.create(d1);
            yield app.datastore.create(d2);
            yield app.datastore.create(d3);
            yield app.datastore.create(d4);
            yield app.datastore.create(d5);
            yield app.datastore.create(d6);
            yield app.datastore.create(d7);
            return [d1, d2, d3, d4, d5];
        });
    }
    it('remove, beginning with Feature', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const [_, d2] = yield createTestResourcesForRemoveTests();
        expect((yield app.datastore.find({})).totalCount).toBe(7);
        yield app.relationsManager.remove(d2, { descendants: true });
        yield helpers.expectDocuments('id1', 'id5', 'id6', 'id7');
        done();
    }));
    it('remove, beginning with Trench', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const [d1, _] = yield createTestResourcesForRemoveTests();
        expect((yield app.datastore.find({}, { includeResourcesWithoutValidParent: true })).totalCount).toBe(7);
        yield app.relationsManager.remove(d1, { descendants: true });
        yield helpers.expectDocuments('id5', 'id6');
        done();
    }));
    it('remove, beginning with Trench - keep a descendant', (done) => __awaiter(void 0, void 0, void 0, function* () {
        const [d1, _, d3] = yield createTestResourcesForRemoveTests();
        expect((yield app.datastore.find({}, { includeResourcesWithoutValidParent: true })).totalCount).toBe(7);
        yield app.relationsManager.remove(d1, { descendants: true, descendantsToKeep: [d3] });
        yield helpers.expectDocuments('id3', 'id5', 'id6');
        done();
    }));
});
//# sourceMappingURL=relations-manager.spec.js.map