"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createHelpers = exports.createCoreApp = exports.makeDocumentsLookup = void 0;
const app_configurator_1 = require("../../src/configuration/app-configurator");
const config_loader_1 = require("../../src/configuration/boot/config-loader");
const config_reader_1 = require("../../src/configuration/boot/config-reader");
const document_converter_1 = require("../../src/datastore/document-converter");
const datastore_1 = require("../../src/datastore/datastore");
const document_cache_1 = require("../../src/datastore/document-cache");
const pouchdb_datastore_1 = require("../../src/datastore/pouchdb/pouchdb-datastore");
const constraint_index_1 = require("../../src/index/constraint-index");
const index_facade_1 = require("../../src/index/index-facade");
const forest_1 = require("../../src/tools/forest");
const tools_1 = require("../../src/tools");
const model_1 = require("../../src/model");
const test_helpers_1 = require("../test-helpers");
const basic_index_configuration_1 = require("../../src/basic-index-configuration");
const PouchDB = require("pouchdb-node");
// TODO remove duplication with import/utils.ts
exports.makeDocumentsLookup = tools_1.makeLookup(['resource', 'id']);
class IdGenerator {
    generateId() {
        return Math.floor(Math.random() * 10000000).toString();
    }
}
function createCoreApp(user = 'testuser', db = 'testdb') {
    return __awaiter(this, void 0, void 0, function* () {
        const pouchdbDatastore = new pouchdb_datastore_1.PouchdbDatastore((name) => new PouchDB(name), new IdGenerator());
        const projectDocument = {
            _id: 'project',
            resource: {
                category: 'Project',
                identifier: db,
                id: 'project',
                coordinateReferenceSystem: 'Eigenes Koordinatenbezugssystem',
                relations: {}
            },
            created: { user: db, date: new Date() },
            modified: [{ user: db, date: new Date() }]
        };
        const configLoader = new config_loader_1.ConfigLoader(new config_reader_1.ConfigReader());
        const template = (yield configLoader.readTemplates())['default'];
        const configurationDocument = {
            _id: 'configuration',
            resource: {
                category: 'Configuration',
                identifier: 'Configuration',
                id: 'configuration',
                forms: template.configuration.forms,
                order: template.configuration.order,
                valuelists: {},
                languages: {},
                projectLanguages: [],
                relations: {}
            },
            created: { user: db, date: new Date() },
            modified: [{ user: db, date: new Date() }]
        };
        yield pouchdbDatastore.createDb(db, projectDocument, configurationDocument, true);
        const documentCache = new document_cache_1.DocumentCache();
        const appConfigurator = new app_configurator_1.AppConfigurator(configLoader);
        const projectConfiguration = yield appConfigurator.go('test', configurationDocument);
        const createdConstraintIndex = constraint_index_1.ConstraintIndex.make(basic_index_configuration_1.basicIndexConfiguration, forest_1.Tree.flatten(projectConfiguration.getCategories()));
        const createdFulltextIndex = {};
        const createdIndexFacade = new index_facade_1.IndexFacade(createdConstraintIndex, createdFulltextIndex, projectConfiguration, false);
        const documentConverter = new document_converter_1.DocumentConverter(projectConfiguration);
        const datastore = new datastore_1.Datastore(pouchdbDatastore, createdIndexFacade, documentCache, documentConverter, projectConfiguration, () => user);
        const relationsManager = new model_1.RelationsManager(datastore, projectConfiguration);
        return {
            datastore,
            relationsManager
        };
    });
}
exports.createCoreApp = createCoreApp;
function createHelpers(app, user = 'testuser') {
    const createDocuments = makeCreateDocuments(app.datastore);
    const expectDocuments = test_helpers_1.makeExpectDocuments(app.datastore);
    return {
        createDocuments,
        expectDocuments
    };
}
exports.createHelpers = createHelpers;
function makeCreateDocuments(datastore) {
    return function create(documents) {
        return __awaiter(this, void 0, void 0, function* () {
            const documentsLookup = test_helpers_1.createDocuments(documents);
            for (const document of Object.values(documentsLookup)) {
                yield datastore.create(document);
            }
            const storedDocuments = [];
            for (const doc of Object.values(documentsLookup)) {
                storedDocuments.push(yield datastore.get(doc.resource.id));
            }
            return exports.makeDocumentsLookup(storedDocuments);
        });
    };
}
//# sourceMappingURL=subsystem-helper.js.map