"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeExpectDocuments = exports.createCategory = exports.createDocuments = exports.doc1 = exports.doc = exports.featureDoc = exports.fieldDoc = exports.createMockProjectConfiguration = void 0;
const tsfun_1 = require("tsfun");
const model_1 = require("../src/model");
const document_1 = require("../src/model/document");
function createMockProjectConfiguration() {
    const projectConfiguration = jasmine.createSpyObj('projectConfiguration', ['getCategory', 'getCategories', 'getTypeCategories']);
    const defaultCategoryConfiguration = {
        name: '',
        groups: [{
                fields: [
                    {
                        name: 'identifier',
                        fulltextIndexed: true
                    },
                    {
                        name: 'shortDescription',
                        fulltextIndexed: true
                    }
                ]
            }]
    };
    projectConfiguration.getCategory.and.callFake(categoryName => {
        return tsfun_1.update('name', categoryName, defaultCategoryConfiguration);
    });
    projectConfiguration.getCategories.and.returnValue([
        { item: tsfun_1.update('name', 'category1', defaultCategoryConfiguration), trees: [] },
        { item: tsfun_1.update('name', 'category2', defaultCategoryConfiguration), trees: [] },
        { item: tsfun_1.update('name', 'category3', defaultCategoryConfiguration), trees: [] },
        { item: tsfun_1.update('name', 'Find', defaultCategoryConfiguration), trees: [] },
        { item: tsfun_1.update('name', 'Type', defaultCategoryConfiguration), trees: [] }
    ]);
    projectConfiguration.getTypeCategories.and.returnValue([{ name: 'Type' }]);
    return projectConfiguration;
}
exports.createMockProjectConfiguration = createMockProjectConfiguration;
const fieldDoc = (sd, identifier, category, id) => exports.doc(sd, identifier, category, id);
exports.fieldDoc = fieldDoc;
const featureDoc = (sd, identifier, category, id) => {
    const newDoc = exports.doc(sd, identifier, category, id);
    newDoc.resource.relations.isContemporaryWith = [];
    newDoc.resource.relations.isBefore = [];
    newDoc.resource.relations.isAfter = [];
    return newDoc;
};
exports.featureDoc = featureDoc;
const doc = (sd, identifier, category, id) => {
    if (!identifier)
        identifier = 'identifer';
    if (!category)
        category = 'Find';
    const newDoc = {
        _id: 'A',
        resource: {
            id: 'A',
            shortDescription: sd,
            identifier: identifier,
            category: category,
            relations: {}
        },
        created: {
            user: 'anonymous',
            date: new Date()
        },
        modified: [
            {
                user: 'anonymous',
                date: new Date()
            }
        ]
    };
    if (id) {
        newDoc._id = id;
        newDoc.resource.id = id;
    }
    else
        delete newDoc.resource.id;
    return newDoc;
};
exports.doc = doc;
const doc1 = (id, identifier, category) => {
    return exports.doc('', identifier, category, id);
};
exports.doc1 = doc1;
function createDocuments(documents, project) {
    const documentsLookup = {};
    const relationsLookup = {};
    for (const [id, type, _] of documents) {
        const d = exports.doc('', 'identifier' + id, type, id);
        if (project)
            d.project = project;
        if (type !== 'Image')
            d.resource.relations = { isRecordedIn: [] };
        relationsLookup[id] = d.resource.relations;
        documentsLookup[id] = d;
    }
    for (const [id, type, targets] of documents) {
        if (targets) {
            if (type === 'Image')
                relationsLookup[id][model_1.Relation.Image.DEPICTS] = targets;
            for (const target of targets) {
                relationsLookup[target][type === 'Image' ? model_1.Relation.Image.ISDEPICTEDIN : model_1.Relation.Hierarchy.LIESWITHIN] = [id];
                if (type === 'Trench') {
                    relationsLookup[target][model_1.Relation.Hierarchy.RECORDEDIN] = [id];
                    delete relationsLookup[target][model_1.Relation.Hierarchy.LIESWITHIN];
                }
            }
        }
    }
    for (const doc of Object.values(documentsLookup)) {
        if (doc.resource.relations['liesWithin']) {
            const target = documentsLookup[doc.resource.relations['liesWithin'][0]];
            if (target.resource.relations['isRecordedIn'] && target.resource.relations['isRecordedIn'].length > 0) {
                doc.resource.relations['isRecordedIn'] = target.resource.relations['isRecordedIn'];
            }
        }
    }
    return documentsLookup;
}
exports.createDocuments = createDocuments;
const createCategory = (name) => ({
    item: {
        name,
        label: {},
        categoryLabel: {},
        isAbstract: false,
        children: [],
        parentCategory: undefined,
        description: {},
        color: '',
        groups: [
            {
                name: 'stem',
                fields: [
                    {
                        name: 'shortDescription',
                        fulltextIndexed: true,
                        inputType: model_1.Field.InputType.INPUT
                    }
                ]
            }
        ],
        mustLieWithin: undefined
    },
    trees: []
});
exports.createCategory = createCategory;
function makeExpectDocuments(datastore) {
    return function expectDocuments(...resourceIds) {
        return __awaiter(this, void 0, void 0, function* () {
            const documents = (yield datastore.find({})).documents;
            expect(tsfun_1.sameset(documents.map(document_1.toResourceId), resourceIds)).toBeTruthy();
        });
    };
}
exports.makeExpectDocuments = makeExpectDocuments;
//# sourceMappingURL=test-helpers.js.map