"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tsfun_1 = require("tsfun");
const forest_1 = require("../../src/tools/forest");
describe('Forest|Tree', () => {
    it('Forest', () => {
        const t = [{ item: 1, trees: [] }];
    });
    it('buildForest', () => {
        expect(tsfun_1.equal(forest_1.Forest.build([[3, [[17, []]]]]), [
            {
                item: 3,
                trees: [
                    {
                        item: 17,
                        trees: []
                    }
                ]
            }
        ])).toBeTruthy();
    });
    it('mapTree', () => {
        const t = forest_1.Tree.build([
            17,
            [
                [1,
                    [
                        [13, []],
                        [14, []],
                    ]
                ],
                [3, []]
            ]
        ]);
        const exp = forest_1.Tree.build([
            34,
            [
                [2, [
                        [26, []],
                        [28, []],
                    ]],
                [6, []]
            ]
        ]);
        const result = forest_1.Tree.map((_) => _ * 2, t);
        expect(tsfun_1.equal(result, exp)).toBeTruthy();
    });
    it('mapForest', () => {
        const t = forest_1.Forest.build([
            [1, [
                    [13, []],
                    [14, []],
                ]],
            [3, []]
        ]);
        const exp = forest_1.Forest.build([
            [2, [
                    [26, []],
                    [28, []],
                ]],
            [6, []]
        ]);
        const result = forest_1.Forest.map((_) => _ * 2, t);
        expect(tsfun_1.equal(result, exp)).toBeTruthy();
    });
    it('mapForests', () => {
        const t = forest_1.Forest.build([
            [1, [
                    [13, []],
                    [14, []],
                ]],
            [3, []]
        ]);
        const exp = forest_1.Forest.build([
            [3, []],
            [1, [
                    [14, []],
                    [13, []],
                ]]
        ]);
        const result = forest_1.Tree.mapTrees(tsfun_1.reverse, t);
        expect(tsfun_1.equal(result, exp)).toBeTruthy();
    });
    it('flatten', () => {
        const a = { a: 1 };
        const t = forest_1.Forest.build([
            [1, [
                    [13, [[a, []]]],
                    [16, []],
                ]],
            [3, []]
        ]);
        const exp = [
            1,
            13,
            a,
            16,
            3
        ];
        expect(tsfun_1.equal(forest_1.Tree.flatten(t), exp)).toBeTruthy();
        expect(exp[2]).toBe(a); // retains original instancesf
    });
    it('flatten - tree', () => {
        const a = { a: 1 };
        const t = forest_1.Tree.build([
            17,
            [
                [1, [
                        [13, [[a, []]]],
                        [16, []],
                    ]],
                [3, []]
            ]
        ]);
        const exp = [
            17,
            1,
            13,
            a,
            16,
            3
        ];
        expect(tsfun_1.equal(forest_1.Tree.flatten(t), exp)).toBeTruthy();
        expect(exp[3]).toBe(a); // retains original instancesf
    });
    it('findInForest', () => {
        const t = forest_1.Forest.build([
            [1, [
                    [13, [[17, []]]],
                    [16, []],
                ]],
            [3, []]
        ]);
        const exp1 = forest_1.Tree.find(t, 13);
        expect(tsfun_1.equal(exp1, forest_1.Tree.build([13, [[17, []]]]))).toBeTruthy();
        const exp2 = forest_1.Tree.find(t, 19);
        expect(tsfun_1.equal(exp2, undefined)).toBeTruthy();
    });
    it('findInForest - tree', () => {
        const t = forest_1.Tree.build([
            17,
            [
                [4, []]
            ]
        ]);
        const exp1 = forest_1.Tree.find(t, 17);
        expect(tsfun_1.equal(exp1, forest_1.Tree.build([17, [[4, []]]]))).toBeTruthy();
        const exp2 = forest_1.Tree.find(t, 15);
        expect(tsfun_1.equal(exp2, undefined)).toBeTruthy();
    });
    it('findInForest with Predicate', () => {
        const a = { a: 3 };
        const t = forest_1.Forest.build([
            [1, [
                    [a, [[17, []]]],
                    [16, []],
                ]],
            [3, []]
        ]);
        const exp1 = forest_1.Tree.find(t, tsfun_1.on('a', tsfun_1.is(3)));
        expect(tsfun_1.equal(exp1, forest_1.Tree.build([{ a: 3 }, [[17, []]]]))).toBeTruthy();
    });
    it('findInForest with Comparator', () => {
        const a = { a: 3 };
        const t = forest_1.Forest.build([
            [1, [
                    [a, [[17, []]]],
                    [16, []],
                ]],
            [3, []]
        ]);
        const exp1 = forest_1.Tree.find(t, { a: 3 }, tsfun_1.on('a'));
        expect(tsfun_1.equal(exp1, forest_1.Tree.build([
            { a: 3 },
            [
                [17, []]
            ]
        ]))).toBeTruthy();
    });
    it('accessForest - first level', () => {
        expect(forest_1.Tree.access(forest_1.Forest.build([
            [
                7,
                []
            ]
        ]), 0)).toEqual(7);
    });
    it('accessForest - second level', () => {
        expect(forest_1.Tree.access(forest_1.Forest.build([
            [
                7,
                [
                    [
                        8,
                        []
                    ]
                ]
            ]
        ]), 0, 0)).toEqual(8);
    });
    it('accessForest - tree', () => {
        expect(forest_1.Tree.access(forest_1.Tree.build([
            7,
            [
                [
                    8,
                    []
                ]
            ]
        ]), 0)).toEqual(8);
    });
    it('accessForest - tree - deeper and wider', () => {
        expect(forest_1.Tree.access(forest_1.Tree.build([
            7,
            [
                [
                    8,
                    [
                        [
                            9,
                            []
                        ],
                        [
                            11,
                            []
                        ]
                    ]
                ]
            ]
        ]), 0, 1)).toEqual(11);
    });
    it('accessForest - tree - root', () => {
        expect(forest_1.Tree.access(forest_1.Tree.build([
            7,
            [
                [
                    8,
                    []
                ]
            ]
        ]))).toEqual(7);
    });
    it('zipForestWith', () => {
        const tl1 = forest_1.Forest.build([[3, []]]);
        const tl2 = forest_1.Forest.build([[76, []]]);
        const result = forest_1.Forest.zip(([item1, item2]) => {
            return item1 + item2;
        }, [tl1, tl2]);
        expect(tsfun_1.equal(result, forest_1.Forest.build([[79, []]]))).toBeTruthy();
    });
    it('zipForestWith - recursive', () => {
        const tl1 = forest_1.Forest.build([[3, [[5, []]]]]);
        const tl2 = forest_1.Forest.build([[76, [[7, []]]]]);
        const result = forest_1.Forest.zip(([item1, item2]) => {
            return item1 + item2;
        }, [tl1, tl2]);
        expect(tsfun_1.equal(result, forest_1.Forest.build([[79, [[12, []]]]]))).toBeTruthy();
    });
    it('zipForestWith - no zipper, recursive', () => {
        const tl1 = forest_1.Forest.build([[3, [[5, []]]]]);
        const tl2 = forest_1.Forest.build([[76, [[7, []]]]]);
        const result = forest_1.Forest.zip([tl1, tl2]);
        expect(tsfun_1.equal(result, forest_1.Forest.build([[[3, 76], [[[5, 7], []]]]]))).toBeTruthy();
    });
});
//# sourceMappingURL=forest.spec.js.map