"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const field_1 = require("../../src/model/configuration/field");
const invalid_data_util_1 = require("../../src/tools/invalid-data-util");
/**
 * @author Thomas Kleinke
 */
describe('InvalidDataUtil', () => {
    let labels;
    beforeAll(() => {
        labels = jasmine.createSpyObj('labels', ['getFromI18NString']);
    });
    it('detect field data as convertible', () => {
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible('true', field_1.Field.InputType.BOOLEAN)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible('True', field_1.Field.InputType.BOOLEAN)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible('false', field_1.Field.InputType.BOOLEAN)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible('False', field_1.Field.InputType.BOOLEAN)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible('value', field_1.Field.InputType.CHECKBOXES)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(['value'], field_1.Field.InputType.DROPDOWN)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(['value'], field_1.Field.InputType.RADIO)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(777, field_1.Field.InputType.INPUT)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(777, field_1.Field.InputType.SIMPLE_INPUT)).toBe(true);
    });
    it('detect field data as non-convertible', () => {
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible('value', field_1.Field.InputType.BOOLEAN)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible({ field: 'value' }, field_1.Field.InputType.CHECKBOXES)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(['value1', 'value2'], field_1.Field.InputType.DROPDOWN)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(['value1', 'value2'], field_1.Field.InputType.RADIO)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible([{ field: 'value' }], field_1.Field.InputType.DROPDOWN)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible([{ field: 'value' }], field_1.Field.InputType.RADIO)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(['value1', 'value2'], field_1.Field.InputType.INPUT)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.isConvertible(['value1', 'value2'], field_1.Field.InputType.SIMPLE_INPUT)).toBe(false);
    });
    it('convert field data', () => {
        expect(invalid_data_util_1.InvalidDataUtil.convert('true', field_1.Field.InputType.BOOLEAN)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.convert('True', field_1.Field.InputType.BOOLEAN)).toBe(true);
        expect(invalid_data_util_1.InvalidDataUtil.convert('false', field_1.Field.InputType.BOOLEAN)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.convert('False', field_1.Field.InputType.BOOLEAN)).toBe(false);
        expect(invalid_data_util_1.InvalidDataUtil.convert('value', field_1.Field.InputType.CHECKBOXES)).toEqual(['value']);
        expect(invalid_data_util_1.InvalidDataUtil.convert(['value'], field_1.Field.InputType.DROPDOWN)).toEqual('value');
        expect(invalid_data_util_1.InvalidDataUtil.convert(['value'], field_1.Field.InputType.RADIO)).toEqual('value');
        expect(invalid_data_util_1.InvalidDataUtil.convert(777, field_1.Field.InputType.INPUT)).toEqual('777');
        expect(invalid_data_util_1.InvalidDataUtil.convert(777, field_1.Field.InputType.SIMPLE_INPUT)).toEqual('777');
    });
    it('generate label for invalid field data', () => {
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel({ field: 'value' }, labels)).toBe('field: value');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel([{ field: 'value1' }, { field: 'value2' }], labels)).toBe('field: value1<hr>field: value2');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel([{ field1: ['value1', 'value2'], field2: ['value3', 'value4'] }], labels)).toBe('field1: value1/value2, field2: value3/value4');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel('value', labels)).toBe('value');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel(7, labels)).toBe('7');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel(['value1', 'value2'], labels)).toBe('value1<hr>value2');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel({}, labels)).toBe('');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel([{}, {}], labels)).toBe('');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel(undefined, labels)).toBe('');
    });
    it('get label from I18N strings when generating label for invalid field data', () => {
        labels.getFromI18NString.and.returnValues(undefined, 'value1');
        expect(invalid_data_util_1.InvalidDataUtil.generateLabel([{ field1: { 'de': 'value1' } }], labels)).toBe('field1: value1');
    });
});
//# sourceMappingURL=invalid-data-util.spec.js.map