"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const named_forest_1 = require("../../src/tools/named-forest");
const forest_1 = require("../../src/tools/forest");
describe('NamedForest', () => {
    function threeLevels() {
        const parent1 = { name: 'P1' };
        const child1 = { name: 'C1' };
        const child2 = { name: 'C2' };
        return forest_1.Forest.build([
            [
                parent1,
                [
                    [
                        child1,
                        [
                            [
                                child2,
                                []
                            ]
                        ]
                    ]
                ]
            ]
        ]);
    }
    it('findInNamedForest', () => {
        const t = threeLevels();
        const result = named_forest_1.findInNamedForest('C1', t);
        expect(result.name).toBe('C1');
    });
    it('isTopLevelItemOrChildThereof', () => {
        const categoryForest = forest_1.Forest.build([
            [
                { name: 'Image' },
                [
                    [
                        { name: 'Drawing' },
                        []
                    ]
                ]
            ],
            [
                { name: 'Operation' },
                []
            ],
            [
                { name: 'Inscription' },
                []
            ],
            [
                { name: 'Type' },
                []
            ],
            [
                { name: 'TypeCatalog' },
                []
            ]
        ]);
        expect(named_forest_1.isTopLevelItemOrChildThereof(categoryForest, 'Image', 'Image')).toBeTruthy();
        expect(named_forest_1.isTopLevelItemOrChildThereof(categoryForest, 'Drawing', 'Image')).toBeTruthy();
        expect(named_forest_1.isTopLevelItemOrChildThereof(categoryForest, 'Image', 'Operation')).toBeFalsy();
        expect(named_forest_1.isTopLevelItemOrChildThereof(categoryForest, 'Drawing', 'Imag')).toBeFalsy();
    });
    it('isTopLevelItemOrChildThereof - more firstLevelItems to match', () => {
        const categoryForest = forest_1.Forest.build([
            [
                { name: 'Image' },
                [
                    [
                        { name: 'Drawing' },
                        []
                    ]
                ]
            ],
            [
                { name: 'Operation' },
                []
            ],
            [
                { name: 'Inscription' },
                []
            ],
            [
                { name: 'Type' },
                []
            ],
            [
                { name: 'TypeCatalog' },
                []
            ],
        ]);
        expect(named_forest_1.isTopLevelItemOrChildThereof(categoryForest, 'Operation', 'Image', 'Type')).toBeFalsy();
        expect(named_forest_1.isTopLevelItemOrChildThereof(categoryForest, 'Drawing', 'Type', 'Image')).toBeTruthy();
    });
    it('removeTrees', () => {
        const categoryForest = forest_1.Forest.build([
            [
                { name: 'Image' },
                [
                    [
                        { name: 'Drawing' },
                        []
                    ]
                ]
            ],
            [
                { name: 'Operation' },
                []
            ],
            [
                { name: 'Inscription' },
                []
            ]
        ]);
        const result0 = named_forest_1.removeTrees(categoryForest, 'Operation', 'Inscription');
        expect(result0.length).toBe(1);
        expect(forest_1.Tree.access(result0, 0).name).toBe('Image');
        expect(forest_1.Tree.access(result0, 0, 0).name).toBe('Drawing');
        const result1 = named_forest_1.removeTrees('Operation', 'Inscription')(categoryForest);
        expect(result1.length).toBe(1);
        expect(forest_1.Tree.access(result1, 0).name).toBe('Image');
        expect(forest_1.Tree.access(result1, 0, 0).name).toBe('Drawing');
        const result2 = named_forest_1.removeTrees('Image')(categoryForest);
        expect(result2.length).toBe(2);
        expect(forest_1.Tree.access(result2, 0).name).toBe('Operation');
        expect(forest_1.Tree.access(result2, 1).name).toBe('Inscription');
        const result3 = named_forest_1.removeTrees(categoryForest, 'Image');
        expect(result3.length).toBe(2);
        expect(forest_1.Tree.access(result3, 0).name).toBe('Operation');
        expect(forest_1.Tree.access(result3, 1).name).toBe('Inscription');
        // typing
        // const result = removeTrees(categoryTreelist);
        // const result = removeTrees()(categoryTreelist);
        // const result: TreeList<Named> = removeTrees('Operation');
    });
    it('filterTrees', () => {
        const categoryForest = forest_1.Forest.build([
            [
                { name: 'Image' },
                [
                    [
                        { name: 'Drawing' },
                        []
                    ]
                ]
            ],
            [
                { name: 'Operation' },
                []
            ],
            [
                { name: 'Inscription' },
                []
            ]
        ]);
        const result0 = named_forest_1.filterTrees(categoryForest, 'Operation');
        expect(result0.length).toBe(1);
        expect(forest_1.Tree.access(result0, 0).name).toBe('Operation');
        const result1 = named_forest_1.filterTrees(categoryForest, 'Operation', 'Inscription');
        expect(result1.length).toBe(2);
        expect(forest_1.Tree.access(result1, 0).name).toBe('Operation');
        expect(forest_1.Tree.access(result1, 1).name).toBe('Inscription');
        const result2 = named_forest_1.filterTrees('Operation', 'Inscription')(categoryForest);
        expect(result2.length).toBe(2);
        expect(forest_1.Tree.access(result2, 0).name).toBe('Operation');
        expect(forest_1.Tree.access(result2, 1).name).toBe('Inscription');
        const result3 = named_forest_1.filterTrees('Operation')(categoryForest);
        expect(result3.length).toBe(1);
        expect(forest_1.Tree.access(result3, 0).name).toBe('Operation');
        // typing
        // const result = filterTrees(categoryTreelist);
        // const result = filterTrees()(categoryTreelist);
        // const result: TreeList<Named> = filterTrees('Operation');
    });
});
//# sourceMappingURL=named-forest.spec.js.map